@@ -380,7 +380,7 @@ KEYS["quick_edit"]["deactivate"]	= 'ESCAPE';
 
 KEYS["mail"] = new Array();
 KEYS["mail"]["save"]	= 'CTRL+S';
-KEYS["mail"]["send"]	= 'ALT+S';
+KEYS["mail"]["send"]	= 'CTRL+ENTER';
 
 KEYS["respond_meeting"] = new Array();
 KEYS["respond_meeting"]["accept"]		= 'ALT+C';
@@ -400,9 +400,18 @@ var DT_EQUIPMENT				= 0x00000008;
 var DT_SEC_DISTLIST				= 0x00000009;
 
 // PR_OBJECT_TYPE values
-var MAPI_MESSAGE				= 5;
-var MAPI_MAILUSER				= 6;
-var MAPI_DISTLIST				= 8;
+var MAPI_STORE			= 1;	// MAPI Store
+var MAPI_ADDRBOOK		= 2;	// MAPI Address Book
+var MAPI_FOLDER			= 3;	// MAPI Folder
+var MAPI_ABCONT			= 4;	// MAPI Address Book Container
+var MAPI_MESSAGE		= 5;	// MAPI Message
+var MAPI_MAILUSER		= 6;	// MAPI Address Book MailUser
+var MAPI_ATTACH			= 7;	// MAPI Attachment
+var MAPI_DISTLIST		= 8;	// MAPI Address Book Distribution List
+var MAPI_PROFSECT		= 9;	// MAPI Profile Section
+var MAPI_STATUS			= 10	// MAPI Status
+var MAPI_SESSION		= 11	// MAPI Session
+var MAPI_FORMINFO		= 12;	// MAPI Form Information
 
 // Task request constants
 
