@@ -304,6 +304,10 @@ Date.prototype.ceilMinutes = function(ceilTimeValue){
 	// when time is XX:00 then there is no need to ceil the time.
 	if(minutes % ceilTimeValue > 0)
 		this.setMinutes((minutes - (minutes % ceilTimeValue)) + ceilTimeValue);
+	//Date and Time values is build using the current time which includes seconds and milliseconds as well
+	//so to roundoff the timestamp value completely, set sec and ms to zero.
+	this.setSeconds(0);
+	this.setMilliseconds(0);
 	return this;
 }
 
