@@ -182,7 +182,6 @@ InputManager.prototype.hasFocus = function(object)
 */
 InputManager.prototype.handleFocus = function(event)
 {
-//console.group("InputManager.prototype.handleFocus");
 	this.resetTimeout();
 
 	switch(event.type)
@@ -234,7 +233,6 @@ InputManager.prototype.changeFocus = function(element){
 	var htmlbody = dhtml.getElementById("html_body");
 	if(htmlbody) {
 		htmlbody.blur();
-		window.focus();
 	}
 	// Change focus
 	this.focusId = objectId;
@@ -467,7 +465,6 @@ InputManager.prototype.hasKeyControlEvent = function(object, eventType, handler)
 
 function eventInputManagerFocusControl(inputmanager, element, event)
 {
-//console.log("eventInputManagerFocusControl: event: "+event.type);
 	return inputmanager.handleFocus(event);
 }
 
@@ -486,7 +483,6 @@ function eventInputTimerLogout()
 function eventInputManagerKeyControlKeyUp(inputmanager, element, event)
 {
 	var isKeyControlEnabled = webclient.settings.get("global/shortcuts/enabled", false);
-	var resultValue = false;
 
 	if (isKeyControlEnabled && !isMenuOpen()){
 		// Get key combination
@@ -498,11 +494,11 @@ function eventInputManagerKeyControlKeyUp(inputmanager, element, event)
 			}
 		}
 		
-		if ((event.keyCode == inputmanager.previousKeyCode) && inputmanager.handleKeyControlEvent(element, event))
-			resultValue = true;
+		if ((event.keyCode == inputmanager.previousKeyCode) && inputmanager.handleKeyControlEvent(element, event)) {
+			if (typeof event.preventDefault != 'undefined') event.preventDefault();
+		}
 
 		inputmanager.previousKeyCode = false;
-		return resultValue;
 	}
 }
 /**
@@ -522,7 +518,6 @@ function eventInputManagerKeyControlKeyDown(inputmanager, element, event)
 		 * if registered then return false, because module wants to handle it.
 		 */
 		var keyCombination = inputmanager.keyStrokes ? inputmanager.keyStrokes.join("+") : '';
-		var returnValue = true;
 		// We want to handle keystrokes on input fields only in dialogs.
 		var handleKeysOnInput = (typeof parentWebclient != "undefined") ? false : true;
 
@@ -531,12 +526,12 @@ function eventInputManagerKeyControlKeyDown(inputmanager, element, event)
 				for (var i in inputmanager.keyControlBindings[type]){
 					var binding = inputmanager.keyControlBindings[type][i];
 
-					if (inputmanager.isKeyRegisteredToObject(binding, keyCombination)) returnValue = false;
+					if (inputmanager.isKeyRegisteredToObject(binding, keyCombination)) {
+						if (typeof event.preventDefault != 'undefined') event.preventDefault();
+					}
 				}
 			}
 		}
-
-		return returnValue;
 	}
 }
 /**
