@@ -89,7 +89,7 @@ function getContactProperties()
 	var properties = new Object();
 	properties["display_name"] = _("Full Name");
 	properties["surname"] =_("Last Name");
-	properties["given_name"] = _("First Nme");
+	properties["given_name"] = _("First Name");
 	properties["title"] = _("Job Title");
 	properties["department_name"] = _("Department");
 	properties["company_name"] = _("Company")	
@@ -146,7 +146,7 @@ function getTaskProperties()
 	properties["startdate"] = _("Start Date");
 	properties["duedate"] = _("End Date");
 	properties["status"] = _("Status");
-	properties["percent_complete"] = _("Precent Complete");
+	properties["percent_complete"] = _("Percent Complete");
 	properties["datecompleted"] = _("Date Completed");
 	properties["totalwork"] = _("Total Work");
 	properties["actualwork"] = _("Actual Work");
@@ -160,4 +160,4 @@ function getTaskProperties()
 	properties["body"] = _("Body");
 
 	return properties;
-}
\ No newline at end of file
+}
