@@ -65,6 +65,7 @@ String.prototype.htmlEntities = function()
 	var tmp = this.replace(/&/g, "&amp;");
 	tmp = tmp.replace(/</g, "&lt;");
 	tmp = tmp.replace(/>/g, "&gt;");
+	tmp = tmp.replace(/\'/g, "&lsquo;");
 	return tmp;
 }
 
@@ -636,7 +637,8 @@ function validateEmailAddress(fieldString, forceSingleAddress, suppressPopupMsg)
 	for(i in data){
 		// check e-mail address
 		var email = data[i].trim();
-		var filter = new RegExp(/^([^<]*<){0,1}(([a-z0-9=_\+\.\-\'\/])+\@(([a-z0-9\-])+\.)+([a-z0-9]{2,5})+)>{0,1}$|^\[[^\]]+\]$/i);
+		// RFC 5322 specifies the format an email address
+		var filter = new RegExp(/^([^<]*<){0,1}(([a-z0-9\.\!\#\$\%\&\'\*\+\-\/\=\?\^\_\`\{\|\}\~])+\@(([a-z0-9\-])+\.)+([a-z0-9]{2,5})+)>{0,1}$|^\[[^\]]+\]$/i);
 		if(email.length > 0 && !filter.test(email)){
 			result += "\n"+email;
 		}
@@ -677,10 +679,16 @@ function parseEmailAddress(address)
 	
 }
 
-function iconIndexToClassName(icon_index,messageClass, isRead)
+function iconIndexToClassName(icon_index,messageClass, isRead, isStub)
 {
+	if(isStub)
+		return "icon_stubbed";
+
 	var className = "";
 	switch(parseInt(icon_index,10)){
+		case 2:
+				className += "icon_stubbed";
+			break;
 		case 261:
 			if (isRead) {
 				className += "icon_mail_replied";
@@ -733,9 +741,21 @@ function iconIndexToClassName(icon_index,messageClass, isRead)
 			break;
 		case 1025:
 			switch(messageClass){
+				case "IPM.Schedule.Meeting.Request":
+					className += "icon_meetingrequest";
+					break;
 				case "IPM.Schedule.Meeting.Canceled":
 					className += "icon_meetingrequest_canceled";
 					break;
+				case "IPM.Schedule.Meeting.Resp.Neg":
+					className += "icon_meetingrequest_neg";
+					break;
+				case "IPM.Schedule.Meeting.Resp.Pos":
+					className += "icon_meetingrequest_pos";
+					break;
+				case "IPM.Schedule.Meeting.Resp.Tent":
+					className += "icon_meetingrequest_tent";
+					break;
 				default:
 					className += "icon_appointment_recurring";
 					break;
@@ -819,9 +839,6 @@ function iconIndexToClassName(icon_index,messageClass, isRead)
 				case "IPM.Note.StorageQuotaWarning":
 					className += "icon_newmail";
 					break;
-				case "IPM.Zarafa.Stub":
-					className += "icon_msg_stub";
-					break;
 				default:
 					if (isRead){
 						className += "icon_mail";
@@ -1708,4 +1725,45 @@ function getTaskRecurrencePattern(recurr)
 
 		return recurtext;
 	}
+}
+
+/**
+ * Funtion recursively scans dom to get text nodes which contain email address so we can replace it with
+ * anchor tag.
+ */
+function scanDOM(node) {
+	for(var i = 0; i < node.childNodes.length; i++) {
+		var cnode = node.childNodes[i];
+		if(cnode.nodeType == 1) { // Tag-node
+			if(cnode.nodeName != 'A') {
+				scanDOM(cnode);
+			}
+		} else if(cnode.nodeType == 3) { // Text-node
+			if(cnode.nodeValue.trim().length > 0) {
+				// check if this text node is email address
+				if(cnode.nodeValue.search(/[a-z0-9_'+*$%\^&!\.\-]+\@(?:[a-z0-9\-]+\.)+[a-z]{2,}/gi) != -1) {
+					addEmailLinks(cnode, node);
+				}
+			}
+		}
+	}
+}
+
+/**
+ * Function will replace text nodes with element nodes which contains anchor tag.
+ */
+function addEmailLinks(node, parentNode) {
+	var clonedTextNode = node.cloneNode(false);
+
+	// Create a new anchor-node.
+	var anchorNode = dhtml.addElement(null, 'a');
+	anchorNode.setAttribute('href', 'mailto: ' + clonedTextNode.nodeValue);
+	anchorNode.setAttribute('target', '_blank');
+	anchorNode.setAttribute('onclick', 'parent.webclient.openWindow(this, "createmail", "index.php?load=dialog&task=createmail_standard&to=' + clonedTextNode.nodeValue + '"); return false;');
+
+	// Add text node to the new anchor node.
+	anchorNode.appendChild(clonedTextNode);
+
+	// Replace the original text node under the parent with the new anchorNode.
+	parentNode.replaceChild(anchorNode, node);
 }
\ No newline at end of file
