@@ -55,6 +55,7 @@
 function WebClient()
 {
 	this.modules = new Object();
+	this.sessionid = false;
 }
 
 /**
@@ -71,7 +72,7 @@ WebClient.prototype.init = function(base_url, modulePrefix, availableModules, se
 	this.base_url = base_url;
 	this.modulePrefix = modulePrefix;
 	this.dialogs = new Object();
-	this.dialogid = 1;
+	this.dialogid = new Date().getTime();
 
 	this.xmlrequest = new XMLRequest(modulePrefix);
 	this.dispatcher = new Dispatcher(availableModules);
@@ -226,13 +227,17 @@ WebClient.prototype.startClient = function()
 		this.handleURLAction(actionUrl);
 	}
 	
-	//check if user is set to out of office, then ask user on login, if user wants to set out of office off?
-	if(webclient.settings.get("outofoffice/set","false") == "true"){
+	/**
+	 * check if user is set to out of office, and check that out of office message
+	 * is not showing again and again in same login session.
+	 * then ask user on login, if user wants to set out of office off?
+	 */
+	var outOfOfficeChangeId = webclient.settings.get("outofoffice_change_id", "false");
+	if(webclient.settings.get("outofoffice/set","false") == "true" && outOfOfficeChangeId != "false" && outOfOfficeChangeId != webclient.sessionid){
 		if(confirm(_("Out of Office currently on. Would you like to turn it off?"))){
 			webclient.settings.set("outofoffice/set","false");
-			webclient.settings.set("outofoffice/subject","");
-			webclient.settings.set("outofoffice/message","");
 		}
+		webclient.settings.set("outofoffice_change_id", webclient.sessionid);
 	}
 }
 
@@ -247,42 +252,49 @@ WebClient.prototype.handleURLAction = function (actionUrl)
 	var keyValuePairs = dhtml.URLToObject(actionUrl);
 
 	// check action type
-	if(typeof keyValuePairs == "object" && keyValuePairs["action"] == "mailto") {
-		// @TODO we can remove most of this code when we support , as email seperator ticket #5274
+	if(typeof keyValuePairs == "object"){
+		if(keyValuePairs["action"] == "mailto") {
+			// @TODO we can remove most of this code when we support , as email seperator ticket #5274
 
-		// if there are more then one email address in TO, CC or BCC field then 
-		// make it semicolon seperated instead of default comma seperated
-		if(typeof keyValuePairs["url"] != "undefined") {
-			// remove 'mailto:' tag from 'url' field
-			keyValuePairs["to"] = keyValuePairs["url"].replace("mailto:", "");
-			keyValuePairs["to"] = keyValuePairs["to"].replace(/,/g, "; ");
-			delete keyValuePairs["url"];
-		} else if(typeof keyValuePairs["to"] != "undefined") {
-			// remove 'mailto:' tag from 'to' field
-			keyValuePairs["to"] = keyValuePairs["to"].replace("mailto:", "");
-			keyValuePairs["to"] = keyValuePairs["to"].replace(/,/g, "; ");
-		}
-
-		// didn't find on internet anything about multiple CC & BCC fields
-		// in mailto links, although its handled here for precaution
-		if(typeof keyValuePairs["cc"] != "undefined") {
-			keyValuePairs["cc"] = keyValuePairs["cc"].replace(/,/g, "; ");
-		}
-
-		if(typeof keyValuePairs["bcc"] != "undefined") {
-			keyValuePairs["bcc"] = keyValuePairs["bcc"].replace(/,/g, "; ");
-		}
-
-		var createmailUrl = "";
-		for(var key in keyValuePairs) {
-			if(key != "action") {
-				// action attribute is not needed in creating createmail dialog URL
-				createmailUrl = createmailUrl + "&" + key + "=" + keyValuePairs[key];
+			// if there are more then one email address in TO, CC or BCC field then 
+			// make it semicolon seperated instead of default comma seperated
+			if(typeof keyValuePairs["url"] != "undefined") {
+				// remove 'mailto:' tag from 'url' field
+				keyValuePairs["to"] = keyValuePairs["url"].replace("mailto:", "");
+				keyValuePairs["to"] = keyValuePairs["to"].replace(/,/g, "; ");
+				delete keyValuePairs["url"];
+			} else if(typeof keyValuePairs["to"] != "undefined") {
+				// remove 'mailto:' tag from 'to' field
+				keyValuePairs["to"] = keyValuePairs["to"].replace("mailto:", "");
+				keyValuePairs["to"] = keyValuePairs["to"].replace(/,/g, "; ");
 			}
-		}
 
-		// open createmail dialog
-		webclient.openWindow(this, "createmail", DIALOG_URL + "task=createmail_standard" + createmailUrl);
+			// didn't find on internet anything about multiple CC & BCC fields
+			// in mailto links, although its handled here for precaution
+			if(typeof keyValuePairs["cc"] != "undefined") {
+				keyValuePairs["cc"] = keyValuePairs["cc"].replace(/,/g, "; ");
+			}
+
+			if(typeof keyValuePairs["bcc"] != "undefined") {
+				keyValuePairs["bcc"] = keyValuePairs["bcc"].replace(/,/g, "; ");
+			}
+
+			var createmailUrl = "";
+			for(var key in keyValuePairs) {
+				if(key != "action") {
+					// action attribute is not needed in creating createmail dialog URL
+					createmailUrl = createmailUrl + "&" + key + "=" + keyValuePairs[key];
+				}
+			}
+
+			// open createmail dialog
+			webclient.openWindow(this, "createmail", DIALOG_URL + "task=createmail_standard" + createmailUrl);
+		}else if(keyValuePairs["action"] == "openmail") {
+
+			// open readmail dialog
+			var uri = DIALOG_URL+"task=readmail_standard&storeid=" + keyValuePairs["storeid"] + "&parententryid=" + keyValuePairs["parententryid"] + "&entryid=" + keyValuePairs["entryid"];
+			webclient.openWindow(this, "openmail", uri);
+		}
 	}
 }
  
@@ -388,6 +400,27 @@ WebClient.prototype.getModulesByName = function(moduleName)
 	return modules;
 }
 
+/**
+ * Function which returns a store from list of MUC store
+ *
+ * @param string storeid the storeid
+ * @return mucStore store object
+ */
+WebClient.prototype.getMUCStore = function(storeid)
+{
+	var mucStore = false;
+
+	if (this.groups && typeof this.groups == "object"){
+		for(var store in this.groups){
+			if(this.groups[store].storeid == storeid) {
+				mucStore = this.groups[store];
+			}
+		}
+	}
+
+	return mucStore;
+}
+
 /**
  * Function which adds a module to the modules list.
  * @param object module module object
@@ -485,7 +518,7 @@ WebClient.prototype.openModalDialog = function(moduleObject, name, url, width, h
 	this.clearDialogs();
 
 	// Make a unique name for the dialog
-	name = name + "_" + this.dialogid;
+	name = window.name + "_" + name + "_" + this.dialogid;
 	this.dialogid++;
 
 	var windowObj = modal(url, name, "toolbar=0,scrollbars=0,location=0,status=1,menubar=0,resizable=0,width=" + width + ",height=" + height + ",dialogWidth=" + width + " px,dialogHeight=" + (height + 50) + " px,top=" + ((screen.height / 2) - (height / 2)) + ",left=" + ((screen.width / 2) - (width / 2)), callback, callbackdata, windowdata);
@@ -663,16 +696,10 @@ function eventWebClientUnload()
 
 function eventBodyMouseDown(moduleObject, element, event)
 {
-	// explicitOriginalTarget is Mozilla-specific property.
-	if(event.explicitOriginalTarget)
-	{
-		var topleft = dhtml.getElementTopLeft(event.explicitOriginalTarget);
-
-		if(event.clientX-topleft[0] > event.explicitOriginalTarget.clientWidth || event.clientY-topleft[1] > event.explicitOriginalTarget.clientHeight) {
-			// Clicking outside viewable area -> must be a click in the scrollbar, allow default action.
-			return true;
-		}
-	}
+	// For FF3.6 only
+	var defaultSelection = eventCheckScrolling(event);
+	if(defaultSelection)
+		return true;
 	// For FF only
 	if(event.forceDefaultAction)
 		return true;
@@ -691,4 +718,4 @@ function forceDefaultActionEvent(moduleObject, element, event)
         // FF code
         event.forceDefaultAction = true;
     }
-}
\ No newline at end of file
+}
