@@ -178,7 +178,7 @@ XMLRequest.prototype.readyStateChange = function()
 				if (typeof (requests[i].status)=="undefined" 
 					|| requests[i].status != 200){
 
-					var message = _("HTTP Error")+":<br>";
+					var message = _("HTTP Error")+": ";
 
 					// unknown error 0: could be "connection lost", so display that
 					if (requests[i].status != 0)
@@ -378,14 +378,14 @@ var keepalive_timer = false;
 function startKeepAlive()
 {
 	if (!window.parentWebclient) { // only send keepalive when we are the main window, not a dialog with a parent webclient
-		keepalive_timer = window.setTimeout("sendKeepAlive()", webclient.settings.get("global/mail_check_timeout", CLIENT_TIMEOUT));
+		keepalive_timer = window.setInterval("sendKeepAlive()", webclient.settings.get("global/mail_check_timeout", CLIENT_TIMEOUT));
 	}
 }
 
 function resetKeepAlive()
 {
 	if (keepalive_timer){
-		window.clearTimeout(keepalive_timer);
+		window.clearInterval(keepalive_timer);
 		keepalive_timer = false;
 	}
 	startKeepAlive();
