@@ -105,8 +105,8 @@
 			$filename = "client/layout/dialogs/" . $type . "/" . $task . ".php";
 			
 			if (!is_readable($filename)){
-				// fallback to IPM.Note if message_class is IPM.Note.* or IPM.Zarafa.Stub
-				if (substr($task,0,4)=="note" || $task=="zarafa_stub"){
+				// fallback to IPM.Note if message_class is IPM.Note.*
+				if (substr($task,0,4)=="note"){
 					$filename = "client/layout/dialogs/" . $type . "/readmail.php";
 				}else{
 					$filename = "client/layout/dialogs/not_implemented.php";
