@@ -217,7 +217,7 @@
 					header("Pragma: public");
 					header("Expires: 0"); // set expiration time
 					header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
-					header("Content-Disposition: " . $openType . "; filename=\"" . $filename . "\"");
+					header("Content-Disposition: " . $openType . "; filename=\"" . browserDependingHTTPHeaderEncode($filename) . "\"");
 					header("Content-Transfer-Encoding: binary");
 					
 					// Set content type header
@@ -280,7 +280,7 @@
 						header("Pragma: public");
 						header("Expires: 0"); // set expiration time
 						header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
-						header("Content-Disposition: " . $openType . "; filename=\"" . $filename . "\"");
+						header("Content-Disposition: " . $openType . "; filename=\"" . browserDependingHTTPHeaderEncode($filename) . "\"");
 						header("Content-Transfer-Encoding: binary");
 						header("Content-Type: application/octet-stream");
 						header("Content-Length: " . filesize($tmpname));
@@ -321,8 +321,6 @@
 		$outputDir="";
 		$fileNames = array();
 
-		$createZipFile->addDirectory($outputDir);
-
 		for($att=0;$att<count($attachNum);$att++){
 			if(is_numeric($attachNum[$att])){
 				$fileContent = openSavedAttachments($storeid, $entryid, $openType, array($attachNum[$att]), $attachCid, true);	
