@@ -87,9 +87,7 @@ function getJavaScript_other(){
 
 function getBody(){ ?>
 	<div class="delegates delegates_info">
-		<label><?=_("Delegates can send items on your behalf. To grant  permissions to others to access
-		your folders without also giving them send-on-behalf-of privileges, go to properties for each
-		folder and change the options on the Permissions tab.")?></label>
+		<label><?=_("Delegates can send items on your behalf, and optionally view or edit items in your store. This is setup by the 'Edit Delegates...' button on the Preferences tab of the Settings window. To enable others to access your folders without giving send-on-behalf-of privileges, is configured on the Permissions tab of the folder Preferences (accessed by right clicking the folder).")?></label>
 	</div>
 	<div class="delegateslist">
 		<div id="delegateslist_container" class="delegates delegateslist_container"></div>
