@@ -114,22 +114,30 @@ function getJavaScript_onload(){ ?>
 							dhtml.addClassName(dhtml.getElementById("monthly_regen_container"), "hideField");
 							dhtml.addClassName(dhtml.getElementById("yearly_regen_container"), "hideField");
 							dhtml.addClassName(dhtml.getElementById("weekly_everyn"), "hideField");
+
+							this.appo_start.setValue(start.getHours() * 3600 + start.getMinutes() * 60);
+							this.appo_end.setValue(end.getHours() * 3600 + end.getMinutes() * 60);
+							
+							// set start & end date range of recurrence as set in parent window.
+							this.range_start.setValue(window.opener.appoint_dtp.getStartValue());
+							this.range_end.setValue(window.opener.appoint_dtp.getEndValue());
+
 						} else {
-							var start = Date.parseDate(window.opener.dhtml.getElementById("text_startdate").value, _("%d-%m-%Y"), true);
-							var end = Date.parseDate(window.opener.dhtml.getElementById("text_duedate").value, _("%d-%m-%Y"), true);
-
+							// Hide Time range block
 							dhtml.addClassName(dhtml.getElementById("time"), "hideField");
-						}
-						
-						this.appo_start.setValue(start.getHours() * 3600 + start.getMinutes() * 60);
-						this.appo_end.setValue(end.getHours() * 3600 + end.getMinutes() * 60);
-						
-						// set start & end date range of recurrence as set in parent window.
-						this.range_start.setValue(window.opener.appoint_dtp.getStartValue());
-						this.range_end.setValue(window.opener.appoint_dtp.getEndValue());
-						
 
-						
+							var start = Date.parseDate(window.opener.dhtml.getElementById("text_commonstart").value, _("%d-%m-%Y"), true);
+							var end = Date.parseDate(window.opener.dhtml.getElementById("text_commonend").value, _("%d-%m-%Y"), true);
+
+							// startdate/duedate may be set
+							if (!start) start = new Date();
+							if (!end) end = new Date();
+
+							// set start & end date range of recurrence as set in parent window.
+							this.range_start.setValue(start.getTime()/1000);
+							this.range_end.setValue(end.getTime()/1000);
+						}
+
 						var day = start.getDay();
 						
 						var dayelems = new Array('weekly_sunday', 'weekly_monday', 'weekly_tuesday', 'weekly_wednesday', 'weekly_thursday', 'weekly_friday', 'weekly_saturday');
