@@ -105,15 +105,15 @@ function getBody(){ ?>
 		<fieldset>
 			<legend><?=_("Sent to")?></legend>
 			<table class="options">
-				<tr><th><label for="cond_sent_to"><?=_("Contact or distributionlist")?></label></th><td><input id="cond_sent_to" type="text" class="inputwidth" /></td><td class="buttonspace"><input type="button" class="addressbookbutton" onclick="getFromAddressBook('cond_sent_to')"></td></tr>
+				<tr><th><label for="cond_sent_to"><?=_("Contact or Distribution List")?></label></th><td><input id="cond_sent_to" type="text" class="inputwidth" /></td><td class="buttonspace"><input type="button" class="addressbookbutton" onclick="getFromAddressBook('cond_sent_to')"></td></tr>
 				<tr><th><label for="cond_sent_to_me"><?=_("Sent only to me")?></label></th><td><input id="cond_sent_to_me" type="checkbox"/></td><td class="buttonspace"></td></tr>
 			</table>
 		</fieldset>
 		<fieldset>
 			<legend><?=_("Perform the following action")?></legend>
 			<table>
-			<tr><th colspan="3"><input type="radio" name="action" id="action_move"/><label for="action_move"><?=_("Move to ")?> <a href="#" onclick="selectFolder('action_move_folder')"><span id="action_move_folder"><?=_("folder")?></span></a></label></th></tr>
-			<tr><th colspan="3"><input type="radio" name="action" id="action_copy"/><label for="action_copy"><?=_("Copy to ")?> <a href="#" onclick="selectFolder('action_copy_folder')"><span id="action_copy_folder"><?=_("folder")?></span></a></label></th></tr>
+			<tr><th colspan="3"><input type="radio" name="action" id="action_move"/><label for="action_move"><?=_("Move to")?> <a href="#" onclick="selectFolder('action_move_folder')"><span id="action_move_folder"><?=_("folder")?></span></a></label></th></tr>
+			<tr><th colspan="3"><input type="radio" name="action" id="action_copy"/><label for="action_copy"><?=_("Copy to")?> <a href="#" onclick="selectFolder('action_copy_folder')"><span id="action_copy_folder"><?=_("folder")?></span></a></label></th></tr>
 			<tr><th colspan="3"><input type="radio" name="action" id="action_delete"/><label for="action_delete"><?=_("Delete the message")?></label></th></tr>
 			<tr><th><input type="radio" name="action" id="action_forward"/><label for="action_forward"><?=_("Forward to")?></th><td><input id="action_forward_address" type="text" class="inputwidth"/></td><td class="buttonspace"><input type="button" class="addressbookbutton" onclick="getFromAddressBook('action_forward_address')"></td></tr>
 			<tr><th colspan="3"><input type="checkbox" id="stop_processing_more_rules"/><label for="stop_processing_more_rules"><?=_("Stop processing more rules")?></label></th></tr>
