@@ -58,10 +58,31 @@ function getDialogTitle() {
 
 function getIncludes(){
 	return array(
-			"client/layout/css/sendMRMailConfirmation.css"
+			"client/layout/css/sendMRMailConfirmation.css",
+			"client/layout/css/occurrence.css"
 	);
 }
 
+function getJavaScript_onload(){ ?>
+	var windowData = typeof window.windowData != "undefined" ? window.windowData : false;
+	var sendMRMailConfirmationEle = dhtml.getElementById("sendMRMailConfirmation");
+	var confirmDeleteEle = dhtml.getElementById("confirmDelete");
+
+	if (windowData) {
+		if (windowData.confirmDelete) {
+			sendMRMailConfirmationEle.style.display = 'none';
+			confirmDeleteEle.style.display = 'block';
+
+			var delete_info_bar = dhtml.getElementById("delete_info_bar");
+			var subjectString = (window.windowData["subject"].length > 30) ? window.windowData["subject"].substr(0, 30)+"..." : window.windowData["subject"];
+			delete_info_bar.innerHTML = _("The meeting \"%s\" was already accepted").sprintf(subjectString);
+		} else {
+			confirmDeleteEle.style.display = 'none';
+		}
+	}
+<?php }
+
+
 function getJavaScript_other(){ ?>
 	function editResponse(){
 		var body = dhtml.getElementById("body");
@@ -82,6 +103,10 @@ function getJavaScript_other(){ ?>
 			window.resultCallBack(dhtml.getElementById('noResponse').checked, window.callBackData);
 		}
 	}
+
+	function sendConfirmDelete() {
+		window.resultCallBack(window.callBackData, dhtml.getElementById('sendResponseAsDelete').checked, window.windowData["basedate"] ? window.windowData["basedate"] : false, window.windowData);
+	}
 <?}
 
 function getBody(){ ?>
@@ -102,7 +127,17 @@ function getBody(){ ?>
 				<input type="radio" name="action" id="noResponse" onclick ="editResponse()"/>
 				<label for="noResponse"><?=_("Don't send a response")?></label>
 			</div>
+			<?=createConfirmButtons("sendMRMailConfirmation(); window.close();")?>
+		</div>
+
+		<div id="confirmDelete">
+			<label id="delete_info_bar"></label>
+			<p>
+			<ul>
+				<li><input type="radio" name="delete" id="sendResponseAsDelete" checked/><label for="sendResponseAsDelete"><?=_("Delete and send a response to the meeting organizer")."."?></label></li>
+				<li><input type="radio" name="delete" id="deletenoResponse"/><label for="deletenoResponse"><?=_("Delete without sending a response")."."?></label></li>
+			</ul>
+			<?=createConfirmButtons("sendConfirmDelete(); window.close();")?>
 		</div>
-		<?=createConfirmButtons("sendMRMailConfirmation(); window.close();")?>
 <?php } // getBody
 ?>
