@@ -72,7 +72,7 @@ function getBody(){ ?>
 			<table>
 				<tr>
 					<th><input type="button" value="<?=_("Name")?>..." onclick="openSelectUserDialog(<?=get("storeid","",true, ID_REGEX)?>);"></th>
-					<td><input type="text" value="" id="username"></td>
+					<td><input type="text" value="" id="username" onchange="userNameChange()"></td>
 				</tr>
 				<tr>
 					<th><legend><?=_("Folder type")?></legend></th>
@@ -87,7 +87,7 @@ function getBody(){ ?>
 					</td>
 				</tr>
 			</table>
-			<?=createConfirmButtons("if(submitSharedFolder()) window.close(); else window.focus();")?>
+			<?=createConfirmButtons("submitSharedFolder()")?>
 		</div>
 <?php } // getBody
 ?>
