@@ -107,6 +107,12 @@ function getDialogTitle(){
 	return _("Settings");
 }
 
+function getJavaScript_onresize(){ 
+	?>
+		resizeBody();
+	<?
+} // getJavaSctipt_onresize	
+
 function getJavaScript_onload(){ 
 	global $tabbar, $tabs;
 	
@@ -120,6 +126,7 @@ function getJavaScript_onload(){
 	}
 	?>
 			webclient.menu.showMenu();
+			resizeBody();
 	<?
 } // getJavaSctipt_onload	
 
@@ -147,6 +154,21 @@ function getJavaScript_other(){
 				settings.set("global/last_settings_tab", webclient.tabbar.getSelectedTab());
 				window.close();
 			}
+
+			function resizeBody() {
+				// Get preferred tab height.
+				var titleElement = dhtml.getElementById("windowtitle");
+				var menubarElement = dhtml.getElementById("menubar");
+				var tabbarElement = dhtml.getElementById("tabbar");
+				var tabHeight = document.documentElement.offsetHeight - titleElement.offsetHeight - menubarElement.offsetHeight - tabbarElement.offsetHeight - 30;
+
+			// Set height of all the tabs to make scrolling work.
+			<?	foreach($tabs as $name=>$title){
+			?>				
+				var tabElement = dhtml.getElementById('<?=$name?>_tab');
+				tabElement.style.height = tabHeight + 'px';
+			<?	} ?>
+			}
 <?	
 }
 
