@@ -55,6 +55,10 @@ function compose_loadSettings(settings){
 	value = settings.get("createmail/mailformat","html");
 	field = dhtml.getElementById("compose_format");
 	field.value = value;
+	// font
+	value = settings.get("createmail/maildefaultfont","arial");
+	field = dhtml.getElementById("compose_font");
+	field.value = value;
 
 	// reply to
 	value = settings.get("createmail/reply_to","");
@@ -133,6 +137,10 @@ function compose_saveSettings(settings){
 	field   = dhtml.getElementById("compose_format");
 	settings.set("createmail/mailformat",field.value);
 
+	// font
+	field = dhtml.getElementById("compose_font");
+	settings.set("createmail/maildefaultfont",field.value);
+
 	// reply to
 	field = dhtml.getElementById("compose_replyto");
 	settings.set("createmail/reply_to",field.value);
@@ -214,4 +222,19 @@ function compose_addCallBack(result) {
 
 function openEditSignatures(){
 	webclient.openModalDialog(-1, 'signatures', DIALOG_URL+'&task=signatures_modal', 710, 550);
+}
+
+function disableFontOption(){
+	var field = dhtml.getElementById("compose_format");
+	for(var i=(field.options.length-1);i>=0;i--){
+		var font_field = dhtml.getElementById("compose_font");
+
+		if(field.options[i].selected && field.options[i].value == "plain"){
+			font_field.disabled = true;
+			font_field.style.background = "#DFDFDF";
+		}else{
+			font_field.disabled = false;
+			font_field.style.background = "#FFFFFF";
+		}
+	}
 }
\ No newline at end of file
