@@ -72,7 +72,7 @@ function compose_settings_html(){ ?>
 			<tr>
 				<th><label for="compose_format"><?=_("Compose mail in this format")?></label></th>
 				<td>
-					<select id="compose_format">
+					<select id="compose_format" onchange="disableFontOption(this)">
 						<option value="html"><?=_("HTML")?></option>
 						<option value="plain"><?=_("Plain text")?></option>
 					</select>
@@ -132,6 +132,20 @@ function compose_settings_html(){ ?>
 					</select>
 				</td>
 			</tr>
+
+			<tr>
+				<th><label for="compose_font"><?=_("Default font")?></label></th>
+				<td>
+					<select id="compose_font">
+						<option value="Arial"><?=_("Arial")?></option>
+						<option value="Comic Sans MS"><?=_("Comic Sans MS")?></option>
+						<option value="Courier New"><?=_("Courier New")?></option>
+						<option value="Tahoma"><?=_("Tahoma")?></option>
+						<option value="Times New Roman"><?=_("Times New Roman")?></option>
+						<option value="Verdana"><?=_("Verdana")?></option>
+					</select>
+				</td>
+			</tr>
 		</table>
 	</fieldset>
 
