@@ -66,9 +66,13 @@ function preferences_settings_html(){ ?>
 				<th><label for="preferences_language"><?=_("Language")?></label></th>
 				<td>
 				<select id="preferences_language">
-<?php 	foreach($GLOBALS["language"]->getLanguages() as $lang=>$title){ 
-?>									<option value="<?=$lang?>"><?=$title?></option>
-<?php   } ?>
+<?php 	
+	function langsort($a, $b) { return strcasecmp($a, $b); } 	
+	$langs = $GLOBALS["language"]->getLanguages();
+	uasort($langs, 'langsort');
+		foreach($langs as $lang=>$title){ 
+?>				<option value="<?=$lang?>"><?=$title?></option>
+<?php	}	?>
 				
 				</select>
 				</td>
@@ -79,8 +83,10 @@ function preferences_settings_html(){ ?>
 				<td>
 				<select id="preferences_theme">
 <?php
-	foreach(preferences_get_themes() as $theme){?>
-					<option value="<?=$theme?>"><?=$theme?></option>
+	foreach(preferences_get_themes() as $theme){
+		// The theme name needs to be converted because otherwise the page will not load.
+?>
+					<option value="<?=$theme['id']?>"><?=u2w($theme['name'])?></option>
 <?php	} ?>
 				</select>
 				</td>
@@ -152,7 +158,7 @@ function preferences_settings_html(){ ?>
 		<legend><?=_("Incoming Mail")?></legend>
 		<table class="options">
 			<tr>
-				<th><label for="preferences_mailcheck"><?=_("New mail check timeout")?></label></th>
+				<th><label for="preferences_mailcheck"><?=_("Check new mail interval")?></label></th>
 				<td>
 				<select id="preferences_mailcheck">
 					<option value="15000">15 <?=_("seconds")?></option>
@@ -213,13 +219,21 @@ function preferences_settings_html(){ ?>
 <?php } 
 
 function preferences_get_themes(){
-	$themes = array("default");
+	$themes = array(
+		array(
+			'id'=>'default',
+			'name'=>_("classic")
+		)
+	);
 	$dir = "client/layout/themes";
 	if (is_dir($dir)){
 		$dh = opendir($dir);
 		while(($entry = readdir($dh))!==false){
 			if (is_dir($dir."/".$entry) && is_file($dir."/".$entry."/theme.css")){
-				$themes[] = $entry;
+				$themes[] = Array(
+					'id' => $entry,
+					'name' => $entry
+				);
 			}
 		}
 	}
