@@ -140,6 +140,10 @@ function getJavaScript_onload(){
 					dhtml.addEvent(false, dhtml.getElementById("html_body"), "contextmenu", forceDefaultActionEvent);
 					dhtml.addEvent(module, dhtml.getElementById("categories"), "blur", eventFilterCategories);
 
+					//explicitly added onchange event on every datepicker object, to validate date entered
+					dhtml.addEvent(false, dhtml.getElementById("text_birthday"), "change", eventDateInputChange);
+					dhtml.addEvent(false, dhtml.getElementById("text_wedding_anniversary"), "change", eventDateInputChange);
+
 <?php	if (isset($_GET["address"])){ ?>
 					var address = parseEmailAddress(decodeURI("<?=get("address", STRING_REGEX)?>"));
 					if (address){
@@ -149,6 +153,7 @@ function getJavaScript_onload(){
 						}
 						if (typeof(address.emailaddress) == "string"){
 							dhtml.getElementById("email_address").value = address.emailaddress;
+							onUpdateEmailAddress();
 						}
 					}
 <?php	} ?>
@@ -157,6 +162,9 @@ function getJavaScript_onload(){
 						module.sendConversionItemData(windowData);
 					}
 
+					// Set focus on display name field.
+					dhtml.getElementById("display_name").focus();
+
 <?php } // getJavaSctipt_onload						
 
 function getJavaScript_other(){
@@ -341,33 +349,57 @@ function getBody() {
 				
 				<table width="100%" border="0" cellpadding="1" cellspacing="0">
 					<tr>
-						<td class="propertynormal propertywidth" valign="top">
-							<input id="address_button" type="button" class="combobutton_main" value="<?=_("Business")?>:" onclick="eventShowDetailAddressDialog(module);"><button type="button" class="combobutton_menu" onclick="eventShowAddressTypeMenu(module, this, event);"><img src="client/layout/img/arrow.gif" /></button>
+						<td class="propertynormal propertywidth">
+							<select id="select_address_combo" class="combobox" onchange="eventOnChangeAddressType(module);">
+								<option value="home"><?=_("Home")?></option>
+								<option value="business" selected><?=_("Business")?></option>
+								<option value="other"><?=_("Other")?></option>
+							</select>
 							<input id="selected_address" type="hidden" value="2">
 						</td>
-						<td rowspan="2">
-							<textarea id="address" onchange="module.parseDetailedInfo(this.value, 'address', false);"></textarea>
-						</td>
-					</tr>
-					<tr>
-						<td class="propertynormal propertywidth" valign="top">
+						<td valign="top">
 							<input id="checkbox_mailing_address" type="checkbox" onchange="onChangeMailingAddress(this);">
 							<label for="checkbox_mailing_address"><?=_("Use this address for mailing")?>.</label>
 						</td>
 					</tr>
-				</table>
-			</fieldset>
-			
-			<fieldset class="contact_fieldset">
-				<legend><?=_("Attachments")?></legend>
-				
-				<table width="100%" border="0" cellpadding="1" cellspacing="0">
 					<tr>
-						<td class="propertynormal propertywidth" valign="top">
-							<input class="button" type="button" value="<?=_("Attachments")?>:" onclick="webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 370, '0');">
+						<td class="propertynormal propertywidth">
+							<?=_("Street")?>:
 						</td>
-						<td valign="top">
-							<div id="itemattachments">&nbsp;</div>
+						<td>
+							<textarea id="address_street" class="contact_address_street"></textarea>
+						</td>
+					</tr>
+					<tr>
+						<td class="propertynormal propertywidth">
+							<?=_("City")?>:
+						</td>
+						<td>
+							<input id="address_city" class="field" type="text">
+						</td>
+					</tr>
+					<tr>
+						<td class="propertynormal propertywidth">
+							<?=_("State/Province")?>:
+						</td>
+						<td>
+							<input id="address_state" class="field" type="text">
+						</td>
+					</tr>
+					<tr>
+						<td class="propertynormal propertywidth">
+							<?=_("ZIP/Postal code")?>:
+						</td>
+						<td>
+							<input id="address_postal_code" class="field" type="text">
+						</td>
+					</tr>
+					<tr>
+						<td class="propertynormal propertywidth">
+							<?=_("Country/Region")?>:
+						</td>
+						<td>
+							<input id="address_country" class="field" type="text">
 						</td>
 					</tr>
 				</table>
@@ -408,7 +440,7 @@ function getBody() {
 							<?=_("Display Name")?>:
 						</td>
 						<td>
-							<input id="email_address_display_name" class="field" type="text">
+							<input id="email_address_display_name" class="field" type="text" onchange="onUpdateEmailAddressDisplayName();">
 						</td>
 					</tr>
 					<tr>
@@ -435,6 +467,22 @@ function getBody() {
 				
 				<textarea id="html_body"></textarea>
 			</fieldset>
+			<div id = "attachfieldcontainer">
+			<fieldset class="contact_fieldset">
+				<legend><?=_("Attachments")?></legend>
+				
+				<table width="100%" border="0" cellpadding="1" cellspacing="0">
+					<tr>
+						<td class="propertynormal propertywidth" valign="top">
+							<input class="button" type="button" value="<?=_("Attachments")?>:" onclick="webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 570, 425, '0');">
+						</td>
+						<td valign="top">
+							<div id="itemattachments">&nbsp;</div>
+						</td>
+					</tr>
+				</table>
+			</fieldset>
+			</div>
 		</div>
 		
 		<div id="categoriesbar">
@@ -577,7 +625,7 @@ function getMenuButtons(){
 				'id'=>"save",
 				'name'=>_("Save"),
 				'title'=>_("Save"),
-				'callback'=>'function(){submitContact()}'
+				'callback'=>'function(){submitContact(module)}'
 			),
 			array(
 				'id'=>"seperator",
@@ -589,15 +637,14 @@ function getMenuButtons(){
 				'id'=>"attachment",
 				'name'=>"",
 				'title'=>_("Add Attachments"),
-				'callback'=>"function(){webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 370, '0');}"
+				'callback'=>"function(){webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 570, 425, '0');}"
 			),
-/* Disable Attach item
 			array(
 				'id'=>"attach_item",
 				'name'=>"",
 				'title'=>_("Attach item"),
 				'callback'=>"function(){webclient.openModalDialog(module, 'attachitem', DIALOG_URL+'task=attachitem_modal&storeid=' + module.storeid + '&entryid=' + module.parententryid +'&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 480, false, false, {module : module});}"
-			), */
+			),
 			array(
 				'id'=>"seperator",
 				'name'=>"",
