@@ -287,6 +287,49 @@ function getJavaScript_onload(){ ?>
 						dhtml.getElementById("to").value = window.windowData["emails"];
 						dhtml.getElementById("subject").focus();
 					}
+					
+					
+					// Checks if creatmail dialog is called with an attachmentid in URL, this is the case when a 
+					// document is send as attachment via any openOffice application
+					var attachment_id = decodeURIComponent("<?=rawurlencode(get("attachment_id"))?>").trim();
+					if(attachment_id){
+						
+						
+						var newattachments = new Array();
+					<?
+						// check for the uploaded document in session variable to display it in the createmail dialog
+						if(isset($_SESSION["files"]) && isset($_SESSION["files"][$_GET["attachment_id"]])) {
+							if(count($_SESSION["files"][$_GET["attachment_id"]]) == 1){
+								foreach($_SESSION["files"][$_GET["attachment_id"]] as $tmpname => $file)
+					?>			
+								{
+									var attachment = new Object();
+									attachment["attach_num"] = "<?=$tmpname?>";
+									attachment["name"] = "<?=$file["name"]?>";
+									attachment["size"] = <?=$file["size"]?>;
+									attachment["filetype"] = "<?=$file["type"]?>";
+									newattachments.push(attachment);
+											
+								}
+								
+								/**
+								 * As every dialog has a unique dialog_attachmentid with the help of which is 
+								 * refers its uploaded attachments, here to handle differnt types of attachments 
+								 * like manually  attached items or from the url, in the same defined way;
+								 * we,assign the unique attachid  value recived in the url to dialog_attachments
+								 */ 
+								dhtml.getElementById("dialog_attachments").value = attachment_id;
+					<?
+							}else{
+								// if the createmail dialog is refresh the session files should not contain the uploaded attachments
+								$_SESSION["files"][$_GET["attachment_id"]] = array();
+							}
+						}
+					?>
+						module.setAttachmentData(newattachments);
+						module.setAttachments();
+					}
+				
 <?php } // getJavaScript_onload
 
 function getJavaScript_other(){
@@ -338,6 +381,10 @@ function getJavaScript_other(){
 				}
 
 				editorInstance.Events.AttachEvent( 'OnSelectionChange', setFCKMessageChanged ) ;
+
+				//set the default font-family for editorarea
+				var font_family = parentWebclient.settings.get("createmail/maildefaultfont","Arial");
+				document.fckEditor.EditorDocument.body.style.fontFamily = font_family;
 				
 				// set content of body if it is passed in URL
 				<? if(isset($_GET["body"])) { ?>
@@ -369,10 +416,6 @@ function getJavaScript_other(){
 					editorInstance.EditorDocument.attachEvent("onkeydown", IE_tracCursorInEditor);
 					editorInstance.EditorDocument.attachEvent("onmousedown", IE_tracCursorInEditor);
 
-					// Blur event in fckEditor creates problem in IE6 and IE8
-					if (!window.BROWSER_IE8 && !window.BROWSER_IE6)
-						editorInstance.EditorWindow.attachEvent("onblur", IE_tracCursorInEditor);
-
 					// Save initial selection in editor.
 					IE_tracCursorInEditor();
 
@@ -502,7 +545,7 @@ function getBody(){
 				</tr>
 				<tr>
 					<td class="propertynormal propertywidth" valign="top">
-						<input class="button" type="button" value="<?=_("Attachments")?>:" onclick="webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 370, '0');">
+						<input class="button" type="button" value="<?=_("Attachments")?>:" onclick="webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 570, 425, '0');">
 					</td>
 					<td valign="top">
 						<div id="itemattachments">&nbsp;</div>
@@ -546,15 +589,14 @@ function getMenuButtons(){
 				'id'=>"attachment",
 				'name'=>"",
 				'title'=>_("Add Attachments"),
-				'callback'=>"function(){setMessageChanged();webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 370, '0');}"
+				'callback'=>"function(){setMessageChanged();webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 570, 425, '0');}"
 			),
-/* Disable Attach item
 			array(
 				'id'=>"attach_item",
 				'name'=>"",
 				'title'=>_("Attach item"),
 				'callback'=>"function(){webclient.openModalDialog(module, 'attachitem', DIALOG_URL+'task=attachitem_modal&storeid=' + module.storeid + '&entryid=' + module.parententryid +'&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 480, false, false, {module : module});}"
-			), */
+			),
 			array(
 				'id'=>"seperator",
 				'name'=>"",
@@ -625,7 +667,7 @@ function getMenuButtons(){
 				'id'=>"flag_status_red",
 				'name'=>"",
 				'title'=>_("Flag"),
-				'callback'=>"function(){webclient.openModalDialog(module, 'flag', DIALOG_URL+'task=flag_modal&store_values=true', 350, 180);}"
+				'callback'=>"function(){webclient.openModalDialog(module, 'flag', DIALOG_URL+'task=flag_modal&store_values=true', 350, 210);}"
 			)
 		);
 }  // getMenuButtons
