@@ -102,6 +102,9 @@ function getJavaScript_onload(){
 					dhtml.addEvent(false, dhtml.getElementById("fileas"), "contextmenu", forceDefaultActionEvent);
 					dhtml.addEvent(false, dhtml.getElementById("html_body"), "contextmenu", forceDefaultActionEvent);
 					dhtml.addEvent(module, dhtml.getElementById("categories"), "blur", eventFilterCategories);
+
+					// Set focus on fileas field.
+					dhtml.getElementById("fileas").focus();
 <?php } // getJavaSctipt_onload						
 
 function getJavaScript_onresize(){ ?>
