@@ -192,7 +192,7 @@ function getBody(){ ?>
 				<table width="100%" cellpadding="2" cellspacing="0">
 					<tr id="meetingrequest_startdate_row">
 						<td class="propertybold propertywidth">
-							<?=_("Startdate")?>:
+							<?=_("Start date")?>:
 						</td>
 						<td>
 							<div id="startdate"></div>
@@ -200,7 +200,7 @@ function getBody(){ ?>
 					</tr>
 					<tr id="meetingrequest_duedate_row">
 						<td class="propertybold propertywidth">
-							<?=_("Enddate")?>:
+							<?=_("End date")?>:
 						</td>
 						<td>
 							<div id="duedate"></div>
@@ -278,14 +278,14 @@ function getMenuButtons(){
 			),
 			array(
 				'id'=>"proposenewtime",
-				'name'=>_("Propose new time"),
+				'name'=>_("Propose New Time"),
 				'title'=>_("Propose New Time"),
 				'callback'=>"function(){proposeNewTime();}"
 			),
 			array(
 				'id'=>"removefromcalendar",
-				'name'=>_("Remove from calendar"),
-				'title'=>_("Remove from calendar"),
+				'name'=>_("Remove from Calendar"),
+				'title'=>_("Remove from Calendar"),
 				'callback'=>"function(){window.module.removeFromCalendar();window.close();}"
 			),
 			array(
