@@ -190,7 +190,36 @@ function getJavaScript_onload(){
 						suggestlistTO = new suggestionList("taskrequest", dhtml.getElementById("to"), suggestEmailModule);
 						suggestEmailModule.addSuggestionList(suggestlistTO);
 					}
+					setChangeHandlers(dhtml.getElementById("to"));
+					setChangeHandlers(dhtml.getElementById("subject"));
+					setChangeHandlers(dhtml.getElementById("text_commonend"));
+					setChangeHandlers(dhtml.getElementById("text_commonstart"));
+					setChangeHandlers(dhtml.getElementById("select_status"));
+					setChangeHandlers(dhtml.getElementById("select_priority"));
+					setChangeHandlers(dhtml.getElementById("text_percent_complete"));
+					setChangeHandlers(dhtml.getElementById("text_datecompleted"));
+					setChangeHandlers(dhtml.getElementById("text_datecompleted"));
+					setChangeHandlers(dhtml.getElementById("text_totalwork"));
+					setChangeHandlers(dhtml.getElementById("mileage"));
+					setChangeHandlers(dhtml.getElementById("text_actualwork"));
+					setChangeHandlers(dhtml.getElementById("billinginformation"));
+					setChangeHandlers(dhtml.getElementById("companies"));
 					
+					//explicitly added onchange event on status selection list
+					dhtml.addEvent(false, dhtml.getElementById("select_status"), "change", onChangeStatus);
+
+					//explicitly added onchange event on every datepicker object, to validate date entered
+					dhtml.addEvent(false, dhtml.getElementById("text_commonend"), "change", eventDateInputChange);
+					dhtml.addEvent(false, dhtml.getElementById("text_commonstart"), "change", eventDateInputChange);
+					dhtml.addEvent(false, dhtml.getElementById("text_datecompleted"), "change", eventDateInputChange);
+					dhtml.addEvent(false, dhtml.getElementById("text_reminderdate"), "change", eventDateInputChange);
+
+					// Set focus on subject or recipient selection field.
+					if(window.taskrequest == "true")
+						dhtml.getElementById("to").focus();
+					else
+						dhtml.getElementById("subject").focus();
+
 <?php } // getJavaSctipt_onload
 
 function getJavaScript_other(){
@@ -209,6 +238,19 @@ function getJavaScript_other(){
 			selectionElement.focus();
 		}
 
+		function setChangeHandlers(element)
+		{
+			if (element){
+				dhtml.addEvent(-1, element, "change", setMessageChanged);
+				dhtml.addEvent(-1, element, "keypress", setMessageChanged);
+			}
+		}
+
+		function setMessageChanged()
+		{
+			dhtml.getElementById("messagechanged").value = 1;
+		}
+
 <?php }
 function getBody() {
 	global $tabbar, $tabs;
@@ -240,6 +282,7 @@ function getBody() {
 		<input id="commonstart" type="hidden" value="">
 		<input id="commonend" type="hidden" value="">
 		<input id="commonassign" type="hidden" value="0">
+		<input id="messagechanged" type="hidden" value="0">
 
 		<input id="taskstate" type="hidden" value="1">
 		<input id="taskhistory" type="hidden" value="0">
@@ -318,7 +361,7 @@ function getBody() {
             			<?=_("Status")?>:
                 	</td>
                 	<td colspan="4">
-                		<select id="select_status" class="comboboxwidth" style="width:100%;" onchange="onChangeStatus();">
+                		<select id="select_status" class="comboboxwidth" style="width:100%;">
                 			<option value="0"><?=_("Not Started")?></option>
                             <option value="1"><?=_("In Progress")?></option>
                             <option value="2"><?=_("Complete")?></option>
@@ -420,7 +463,7 @@ function getBody() {
 			<table width="99%" border="0" cellpadding="1" cellspacing="0">
 				<tr>
 					<td class="propertynormal propertywidth" valign="top">
-						<input class="button" type="button" value="<?=_("Attachments")?>:" onclick="webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 370, '0');">
+						<input class="button" type="button" value="<?=_("Attachments")?>:" onclick="webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 570, 425, '0');">
 					</td>
 					<td valign="top">
 						<div id="itemattachments">&nbsp;</div>
@@ -645,15 +688,14 @@ function getMenuButtons(){
 				'id'=>"attachment",
 				'name'=>"",
 				'title'=>_("Add Attachments"),
-				'callback'=>"function(){webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 370, '0');}"
+				'callback'=>"function(){webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 570, 425, '0');}"
 			),
-/* Disable Attach item
 			array(
 				'id'=>"attach_item",
 				'name'=>"",
 				'title'=>_("Attach item"),
 				'callback'=>"function(){webclient.openModalDialog(module, 'attachitem', DIALOG_URL+'task=attachitem_modal&storeid=' + module.storeid + '&entryid=' + module.parententryid +'&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 480, false, false, {module : module});}"
-			), */
+			),
 			array(
 				'id'=>"checknames",
 				'name'=>"",
@@ -670,7 +712,7 @@ function getMenuButtons(){
 				'id'=>"recurrence",
 				'name'=>_("Recurrence"),
 				'title'=>_("Recurrence"),
-				'callback'=>"function(){webclient.openModalDialog(module, 'recurrence', DIALOG_URL+'task=recurrence_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value + '&taskrecurrence=true', 550, 370, callBackTaskRecurrence);}"
+				'callback'=>"function(){webclient.openModalDialog(module, 'recurrence', DIALOG_URL+'task=recurrence_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value + '&taskrecurrence=true', 550, 405, callBackTaskRecurrence);}"
 			),
 			array(
 				'id'=>"seperator",
