@@ -100,6 +100,7 @@
 
 	includeFiles("js", array(
 							"client/core/constants.js",
+							"client/core/fixedsettings.js",
 							"client/core/utils.js",
 							"client/views/view.js",
 							"client/views/table.view.js",
@@ -255,8 +256,12 @@
 					dialoghelper = new dialogmodule();
 					var dialoghelperID = webclient.addModule(dialoghelper);
 					dialoghelper.init(dialoghelperID);
-<?php if(function_exists('getModuleName')) { ?>
-					module = new <?=getModuleName()?>();
+<?php 
+	if(function_exists('getModuleName')) { 
+		$moduleName = getModuleName();
+		$GLOBALS['PluginManager']->triggerHook("server.dialog.general.setup.getmodulename", array( "task" => $task, 'plugin' => $plugin, "moduleName" => &$moduleName ));
+	?>
+					module = new <?=$moduleName?>();
 					var moduleID = webclient.addModule(module);
 <?php } // if function_exists ?>
 
