@@ -93,6 +93,9 @@ function advFindAddColumns(moduleObject, properties) {
 					// default value for string column width
 					if(property["length"] == false) {
 						property["length"] = 150;
+					} else if(property["length"] == PERCENTAGE) {
+						// tablewidget doesn't use PERCENTAGE for variable width columns instead it uses false for it
+						property["length"] = false;
 					}
 					break;
 			}
@@ -368,31 +371,31 @@ function advFindRenderRowColumnData(moduleObject, itemData, properties) {
 						value = _("Important");
 						break;
 					case 2:
-						value = _("Work");
+						value = _("Business");
 						break;
 					case 3:
 						value = _("Personal");
 						break;
 					case 4:
-						value = _("Holiday");
+						value = _("Vacation");
 						break;
 					case 5:
-						value = _("Required");
+						value = _("Must Attend");
 						break;
 					case 6:
 						value = _("Travel Required");
 						break;
 					case 7:
-						value = _("Prepare Required");
+						value = _("Needs Preparation");
 						break;
 					case 5:
 						value = _("Birthday");
 						break;
 					case 8:
-						value = _("Special date");
+						value = _("Anniversary");
 						break;
 					case 9:
-						value = _("Phone Interview");
+						value = _("Phone Call");
 						break;
 					default:
 						value = NBSP;
@@ -447,8 +450,9 @@ function advFindRenderRowColumnData(moduleObject, itemData, properties) {
  * @param		Object			moduleObject		advanced find module object
  * @param		Array			items				item XMLNodes to add in table widget
  * @param		Array			properties			column data
+ * @param		Boolean			sortingFlag			flag to check if user explicity is sorting or not
  */
-function advFindSetRowColumnData(moduleObject, items, properties) {
+function advFindSetRowColumnData(moduleObject, items, properties, sortingFlag) {
 	if(items.length == 0) {
 		return false;
 	}
@@ -463,21 +467,25 @@ function advFindSetRowColumnData(moduleObject, items, properties) {
 		// add rendered row data to table data
 		var item = advFindRenderRowColumnData(moduleObject, itemData, properties);
 		tableData.push(item);
-	}
-
-	if(tableData.length > 0) {
-		// register row event listeners
+	}	
+	
+	// register row event listeners
+	if(!moduleObject.advFindTableWidget.hasRowListener("dblclick"))
 		moduleObject.advFindTableWidget.addRowListener(moduleObject.eventAdvFindRowDblClick, "dblclick", moduleObject);
+	if(!moduleObject.advFindTableWidget.hasRowListener("contextmenu"))
 		moduleObject.advFindTableWidget.addRowListener(moduleObject.eventAdvFindRowContextMenu, "contextmenu", moduleObject);
+			
+	// register column event listeners
+	if(!moduleObject.advFindTableWidget.hasColumnListener("click"))
+		moduleObject.advFindTableWidget.addColumnListener(moduleObject.eventAdvFindColumnClick, "click", moduleObject);
 
-		// hide loading message in table widget
-		moduleObject.advFindTableWidget.hideLoader();
-		moduleObject.advFindTableWidget.generateTable(tableData);
+	// hide loading message in table widget
+	moduleObject.advFindTableWidget.hideLoader();
+	moduleObject.advFindTableWidget.generateTable(tableData, moduleObject.sort);
 
-		return true;
-	}
-
-	return false;
+	return true;
+	
+	
 }
 
 /**
