@@ -86,7 +86,25 @@ function initAppointment()
 	// Reminder Minutes Before Start
 	var minutes = parseInt(dhtml.getElementById("reminder_minutes").value);
 	if(minutes >= 0) {
-		dhtml.setValue(dhtml.getElementById("select_reminder_minutes"), minutes);
+		var reminderMinElem = dhtml.getElementById("select_reminder_minutes");
+		var result = dhtml.setValue(reminderMinElem, minutes);
+
+		// If no value has been set find the closed bigger value and select that option
+		if(!result){
+			var closeValueFound = false;
+			for(var i = 0; i < reminderMinElem.options.length; i++){
+				// If the listed reminder time is bigger than use that value and break out of the loop
+				if(reminderMinElem.options[i].value > minutes){
+					reminderMinElem.options[i].selected = true;
+					closeValueFound = true;
+					break;
+				}
+			}
+			// If no value has been found, so select the biggest value from the list, which is the last one
+			if(!closeValueFound){
+				reminderMinElem.options[reminderMinElem.options.length-1].selected = true;
+			}
+		}
 	}
 	
 	// Private
@@ -97,8 +115,9 @@ function initAppointment()
 	// Importance
 	setImportance(parseInt(dhtml.getElementById("importance").value));
 
+	var responseStatus = parseInt(dhtml.getElementById("responsestatus").value);
+
 	if(dhtml.getElementById("basedate").value.length > 0) {
-		var responseStatus = parseInt(dhtml.getElementById("responsestatus").value);		
 		meetingRequestSetup(responseStatus);
 
 		// Exception, turn off recurrence button
@@ -110,7 +129,8 @@ function initAppointment()
 		dhtml.getElementById("categories").disabled =true;
 		dhtml.getElementById("checkbox_private").disabled =true;
 	} else if(dhtml.getElementById("to").value.length > 0 || dhtml.getElementById("cc").value.length > 0 || dhtml.getElementById("bcc").value.length > 0) {
-		var responseStatus = parseInt(dhtml.getElementById("responsestatus").value);		
+		meetingRequestSetup(responseStatus);
+	} else if(responseStatus == olResponseOrganized && dhtml.getElementById("meeting").value == olMeeting) {
 		meetingRequestSetup(responseStatus);
 	} else {
 		meetingRequestSetup(mrSetupNormal);
@@ -207,11 +227,11 @@ function initAppointment()
 		// Set info text about number of attendees that proposed a new time and create list of proposed new times
 		if(numProposingAttendees > 0){
 			var meetingrequestResponseElement = dhtml.getElementById("meetingrequest_responses");
-			var textMeetingrequestResponse = numProposingAttendees + " ";
+			var textMeetingrequestResponse = "";
 			if(numProposingAttendees == 1){
-				textMeetingrequestResponse += _("attendee proposed a new time for this meeting. Click the Scheduling tab for details.");
+				textMeetingrequestResponse += _("%d attendee proposed a new time for this meeting. Click the Scheduling tab for details.").sprintf(numProposingAttendees);
 			}else{
-				textMeetingrequestResponse += _("attendees proposed a new time for this meeting. Click the Scheduling tab for details.");
+				textMeetingrequestResponse += _("%d attendees proposed a new time for this meeting. Click the Scheduling tab for details.").sprintf(numProposingAttendees);
 			}
 			meetingrequestResponseElement.style.display = "block";
 			dhtml.addTextNode(meetingrequestResponseElement, textMeetingrequestResponse);
@@ -380,6 +400,10 @@ function syncRecipientFields(newRecipsInFields){
 	fields.to.value      = recips.to.length == 0? "" :recips.to.join("; ") + "; ";
 	fields.cc.value      = recips.cc.length == 0? "" :recips.cc.join("; ") + "; ";
 	fields.bcc.value     = recips.bcc.length == 0? "" :recips.bcc.join("; ") + "; ";
+
+	// if location is set then check wheather resource is present in recpients field or not
+	if(fb_module && fb_module.hasResource && recips.bcc.length == 0)
+		dhtml.getElementById('location').value = '';
 }
 
 
@@ -406,6 +430,7 @@ function submitAppointment(send, requestStatus)
 	if(tabbarControl.getSelectedTab() == "scheduling"){
 		module.setStartTime(fb_module.getStartMeetingTime());
 		module.setEndTime(fb_module.getEndMeetingTime());
+		module.setLocation(fb_module.getResource());
 		module.setUserList(fb_module.getUserList());
 	}
 
@@ -505,11 +530,13 @@ function submitAppointment(send, requestStatus)
 			// Check whether there are any recepients in MR or not.
 			if( endtime>(new Date().getTime()) && recepientsList.length > 0) {
 				send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
+
+				if (!send) return false;
 			}
 		}
 	} else if (recepientsList.length == 0) {
 		// If there is no recpients in MR than confirm with user whether he wants to send MR or not.
-		if(!confirm(_("This meeting cannot be sent because there are no recipients added. Would you like to save and close this meeting instead.")))
+		if(!confirm(_("This meeting request cannot be sent since it has no recipients. Would you like to save and close this meeting instead?")))
 			return;
 	}
 
@@ -517,10 +544,16 @@ function submitAppointment(send, requestStatus)
 		var props = getPropsFromDialog();
 
 		if(module.isMeeting && validateEmailAddress(dhtml.getElementById("toccbcc").value, false, module.resolveForSendingMR?false:true)){
-			dhtml.getElementById("meeting").value = "1";
-			if(!module.itemProps.entryid || (module.itemProps.responsestatus && module.itemProps.responsestatus==1))
-				dhtml.getElementById("responsestatus").value = "1";
-		
+			dhtml.getElementById("meeting").value = olMeeting;
+			props["meeting"] = olMeeting;
+
+			if(!module.itemProps.entryid || (module.itemProps.responsestatus && module.itemProps.responsestatus == olResponseOrganized)) {
+				dhtml.getElementById("responsestatus").value = olResponseOrganized;
+				props["responsestatus"] = olResponseOrganized;
+
+				if(!send) props["requestsent"] = "0";
+			}
+
 			var recipients = new Object();
 			recipients["recipient"] = createCompatibleRecipientList(recepientsList);
 
@@ -660,13 +693,15 @@ function onChangeReminder()
 	if(checkbox_reminder) {
 		var reminder = dhtml.getElementById("reminder");
 		var select_reminder_minutes = dhtml.getElementById("select_reminder_minutes");
+		// if item is alldayevent then its reminder times should be set to 18hrs
+		var alldayevent_reminder_minutes = "1080";
 		
 		if(checkbox_reminder.checked) {
 			select_reminder_minutes.disabled = false;
 			select_reminder_minutes.style.background = "#FFFFFF";
 			// if reminder is checked and is all day then set reminder time to 18hours 
 			if(dhtml.getElementById("checkbox_alldayevent").checked){
-				select_reminder_minutes.value = "1080";
+				select_reminder_minutes.value = alldayevent_reminder_minutes;
 			}
 			reminder.value = "1";
 		} else {
@@ -687,7 +722,8 @@ function onChangeAllDayEvent(forceFlag)
 	var checkbox_alldayevent = dhtml.getElementById("checkbox_alldayevent");
 	var text_startdate_time = dhtml.getElementById("text_startdate_time");
 	var text_duedate_time = dhtml.getElementById("text_duedate_time");
-
+	// if item is alldayevent then its reminder times should be set to 18hrs
+	var alldayevent_reminder_minutes = "1080";
 	// the flag will be passed for forcefully selecting the appointment as allday event.
 	if(forceFlag)
 		dhtml.getElementById("checkbox_alldayevent").checked = true;
@@ -698,7 +734,7 @@ function onChangeAllDayEvent(forceFlag)
 		dhtml.setValue(dhtml.getElementById("select_busystatus"), "0");
 		// when an allday event is created, if the default reminder is on in setting, we need to set reminder time to 18hrs and if not to default value.
 		if(dhtml.getElementById("checkbox_reminder").checked){
-			dhtml.setValue(dhtml.getElementById("select_reminder_minutes"), "1080");
+			dhtml.setValue(dhtml.getElementById("select_reminder_minutes"), alldayevent_reminder_minutes);
 		}else{
 			dhtml.setValue(dhtml.getElementById("select_reminder_minutes"), parentWebclient.settings.get("calendar/reminder_minutes",15));
 		}
@@ -732,11 +768,17 @@ function meetingRequestSetup(level) {
 	var tentativebutton = dhtml.getElementById("tentative");
 	var declinebutton = dhtml.getElementById("decline");
 	var proposenewtimebutton = dhtml.getElementById("proposenewtime");
+	var printButton = dhtml.getElementById("print");
 	var inviteattendeesbutton = dhtml.getElementById("inviteattendees");
 	var cancelinviteattendeesbutton = dhtml.getElementById("cancelinviteattendees");
 	var checknames = dhtml.getElementById("checknames");
 	var seperator1 = dhtml.getElementById("seperator1");
 	
+	if(module.itemProps && module.itemProps['entryid']) {
+		// Show print button for saved appointments and MRs
+		printButton.style.display = "block";
+	}
+
 	if(level == 0) { // normal
 		meetingrequest_recipient.style.display = "none";
 		meetingrequest_organiser.style.display = "none";
@@ -839,7 +881,11 @@ function onAppointmentTabChange(newTab,oldTab)
 		//update the meetingtime in freebusy tab
 		fb_module.setStartMeetingTime(module.getStartTime());
 		fb_module.setEndMeetingTime(module.getEndTime());
-		fb_module.updatePicker();
+		var recurring = dhtml.getElementById("recurring").value;
+		var basedate = dhtml.getElementById("basedate").value;
+		if(recurring != 1 || basedate) {
+			fb_module.updatePicker();
+		}
 		syncTrackingTab();
 	}
 	if(newTab == "scheduling"){
@@ -870,7 +916,12 @@ function onAppointmentTabChange(newTab,oldTab)
 				if(organizerStore.emailaddress && organizerStore.emailaddress != webclient.username){
 					organizer = organizerStore.username;
 				}else{
-					organizer = webclient.username;
+					var mucStore = parentWebclient.getMUCStore(module.storeid);
+					if(mucStore.emailaddress && mucStore.emailaddress != webclient.username){
+						organizer = mucStore.username;
+					}else{
+						organizer = webclient.username;
+					}
 				}
 			}
 			fb_module.initView(1, organizer, module.getUserList());
@@ -892,16 +943,23 @@ function onAppointmentTabChange(newTab,oldTab)
 					fb_module.enablePicker();
 				}
 			}
-		}
+			//set autoChangeResourceRecipient flag to false whenever a saved appointment is opened and is switched to FBview
+			if (module.itemProps && module.itemProps.entryid != undefined)
+				fb_module.autoChangeResourceRecipient = false;
+		}	
 		else{
-			fb_module.resize();
+			fb_module.resize();	
 			fb_module.setUserList(module.getUserList());
 		}
 		// Case in which schedule tab is selected after tracking tab.
 		if(oldTab == "tracking") {
 			fb_module.setStartMeetingTime(module.getStartTime());
 			fb_module.setEndMeetingTime(module.getEndTime());
-			fb_module.updatePicker();
+			var recurring = dhtml.getElementById("recurring").value;
+			var basedate = dhtml.getElementById("basedate").value;
+			if(recurring != 1 || basedate) {
+				fb_module.updatePicker();
+			}
 		}
 	}
 	if(oldTab == "scheduling"){
@@ -930,7 +988,10 @@ function onAppointmentTabChange(newTab,oldTab)
 			else{
 				meetingRequestSetup(mrSetupNormal);
 			}
+			module.setLocation(fb_module.getResource());
 			module.setUserList(fbUserlist);
+			//set autoChangeResourceRecipient flag to true as user as switched to Fb view
+			fb_module.autoChangeResourceRecipient = false;
 		}
 	}
 	if(newTab == "tracking"){
@@ -1078,6 +1139,8 @@ function showRecurrence()
 		if(fb_module) fb_module.enablePicker();
 
 	}
+	// Adjust body textarea according to available client area.
+	resizeBody();
 }
 
 function categoriesCallBack(categories) {
@@ -1481,7 +1544,7 @@ function eventAppointmentDialogProposeNewTimeClick(moduleObject)
 	webclient.openWindow(-1, 'appointmentitem_proposenewtimedialog', DIALOG_URL+'task=advprompt_modal', 325,250, true, appointmentdialogProposenewtime_dialog_callback, {
 			moduleObject: moduleObject
 		}, {
-			windowname: _("Propose new time"),
+			windowname: _("Propose New Time"),
 			fields: [{
 				name: "combineddatetimepicker",
 				label_start: _("Start time"),
@@ -1634,13 +1697,14 @@ function sendConfirmationDeleteAppointmentItem(moduleObject, subject, basedate)
  * this function decides whether to send response to organizer that attendee has deleted item.
  * 
  *@param object moduleObject module object
- *@param boolean noResponse true if attendee doesn't want to send response on deletion else false
+ *@param boolean sendResponse true if attendee wants to send response on deletion,
+ * on false it won't semd delete response mail.
  *@param integer basedate basedate if it an occurrence
  */
-function appointmentItemSendMRMailConfirmation_callback(moduleObject, noResponse, basedate)
+function appointmentItemSendMRMailConfirmation_callback(moduleObject, sendResponse, basedate)
 {
-	if (!noResponse) {
-		moduleObject.sendDeclineMeetingRequest(noResponse, basedate);
+	if (sendResponse) {
+		moduleObject.sendDeclineMeetingRequest(false, basedate);
 	} else {
 
 		if (basedate) {
