@@ -408,31 +408,31 @@ function attachItemRenderRowColumnData(moduleObject, itemData, properties) {
 						value = _("Important");
 						break;
 					case 2:
-						value = _("Work");
+						value = _("Business");
 						break;
 					case 3:
 						value = _("Personal");
 						break;
 					case 4:
-						value = _("Holiday");
+						value = _("Vacation");
 						break;
 					case 5:
-						value = _("Required");
+						value = _("Must Attend");
 						break;
 					case 6:
 						value = _("Travel Required");
 						break;
 					case 7:
-						value = _("Prepare Required");
+						value = _("Needs Preparation");
 						break;
 					case 5:
 						value = _("Birthday");
 						break;
 					case 8:
-						value = _("Special date");
+						value = _("Anniversary");
 						break;
 					case 9:
-						value = _("Phone Interview");
+						value = _("Phone Call");
 						break;
 					default:
 						value = NBSP;
