@@ -60,8 +60,10 @@ var uploadedFiles = 0;
  */
 function initUploadObject(enable)
 {
-	// Create Settings array for SWFUpload Object.
-	var uploadObjSettings = {
+	// Create SWFUpload object with required settings.
+	if(enable) {
+		// Create Settings array for SWFUpload Object.
+		var uploadObjSettings = {
 					upload_url: BASE_URL + "index.php?load=upload_attachment",
 					flash_url : "client/widgets/swfupload/swfupload.swf",
 
@@ -105,8 +107,6 @@ function initUploadObject(enable)
 					 */
 				};
 
-	// Create SWFUpload object with required settings.
-	if(enable) {
 		uploadObj = new SWFUpload(uploadObjSettings);
 	} else {
 		// SWF upload not enabled, which is the same as the initialization failing. Trigger
@@ -229,11 +229,14 @@ function fileQueuedErrorHandlerFunction(file, errorCode, errorMessage) {
 		case -100: // More no of files than FILE_UPLOAD_LIMIT at a time.
 			alert(_("You cannot upload more than %s files at once.").sprintf(FILE_UPLOAD_LIMIT));
 		break;
-		case -110: // Zero Byte files.
-		case -120: // More than max upload size files.
+		case -110: // More than max upload size files.
 			if (file && file.name)
 				fileUploadMazSizeErrorArray.push(file.name);
 		break;
+		case -120: // Zero Byte files.
+			if (file && file.name)
+				alert(_("The file named %s is 0 bytes, so will not be attached.").sprintf(file.name));
+		break;
 	}
 }
 
@@ -246,7 +249,7 @@ function queueCompletedHandlerFunction(file)
 {
 	// All files are uploaded now refresh the dialog to update the list of files.
 	if(fileUploadHTTPErrorArray.length > 0)
-		alert(_("Below file(s) are not uplooaded because of some HTTP error.\n" + fileUploadHTTPErrorArray.join(", ")));
+		alert(_("The file(s) below could not be uploaded due to an HTTP error.")+"\n" + fileUploadHTTPErrorArray.join(", "));
 	fileUploadHTTPErrorArray = [];
 	location.reload();
 }
@@ -265,7 +268,7 @@ function fileDialogCompleteHandlerFunction(numFilesSelected, numFilesQueued, num
 	totalFiles += numFilesQueued;
 	showUploadInfo();
 	if(fileUploadMazSizeErrorArray.length > 0)
-		alert(_("Below file(s) exceeds allowed file size limit. So unable to upload these files.\n" + fileUploadMazSizeErrorArray.join(", ")));
+		alert(_("The file(s) below exceed(s) the allowed file size limit and were therefore not uploaded.") + "\n" + fileUploadMazSizeErrorArray.join(", "));
 	fileUploadMazSizeErrorArray = [];
 }
 
@@ -280,3 +283,21 @@ function showUploadInfo()
 	dhtml.deleteAllChildren(progressMsgElem);
 	dhtml.addTextNode(progressMsgElem, Msgstring);
 }
+
+/**
+ * Function will be called after non swf file upload dialog closed.
+ */
+function onChangeAttachment()
+{
+	var attachment = dhtml.getElementById('attachment');
+	var maxfiles = Math.min(FILE_UPLOAD_LIMIT, FILE_QUEUE_LIMIT);
+
+	if(attachment && attachment.files && maxfiles != 0 && attachment.files.length > maxfiles) {
+		alert(_("You cannot upload more than %s files at once.").sprintf(maxfiles));
+		dhtml.getElementById('upload').reset()
+		return false;
+	} else
+		return dhtml.getElementById('upload').submit();
+
+}
+
