@@ -64,33 +64,37 @@ function initContact()
 	}
 	
 	// Default: Business Address
-	var address = dhtml.getElementById("business_address").value;
+	var addressType = "business";
 	switch(mailing_address)
 	{
 		// Home
 		case "1":
-			address = dhtml.getElementById("home_address").value;
+			var addressType = "home";
 			break;
 		// Other
 		case "3":
-			address = dhtml.getElementById("other_address").value;
+			var addressType = "other";
 			break;
 	}
 	
-	var address_button_value = _("Business") + ":";
+	var address_button_value = "business";
 	switch(mailing_address)
 	{
 		case "1":
-			address_button_value = _("Home") + ":";
+			address_button_value = "home";
 			break;
 		case "3":
-			address_button_value = _("Other") + ":";
+			address_button_value = "other";
 			break;
 	}
-	dhtml.getElementById("address_button").value = address_button_value;
+	dhtml.getElementById("select_address_combo").value = address_button_value;
 
 	dhtml.getElementById("selected_address").value = mailing_address;
-	dhtml.getElementById("address").value = address;
+	dhtml.getElementById("address_street").value = dhtml.getElementById(addressType + "_address_street").value;
+	dhtml.getElementById("address_city").value = dhtml.getElementById(addressType + "_address_city").value;
+	dhtml.getElementById("address_state").value = dhtml.getElementById(addressType + "_address_state").value;
+	dhtml.getElementById("address_postal_code").value = dhtml.getElementById(addressType + "_address_postal_code").value;
+	dhtml.getElementById("address_country").value = dhtml.getElementById(addressType + "_address_country").value;
 
 	// set values for telephone input boxes
 	dhtml.getElementById("telephone_number_1").value = dhtml.getElementById("office_telephone_number").value;
@@ -110,7 +114,7 @@ function initContact()
 	}
 }
 
-function submitContact()
+function submitContact(moduleObject)
 {
 	//A Contact item does not have the timezone property set by default so,
 	var timezone = false;
@@ -127,11 +131,6 @@ function submitContact()
 				webclient.dialogs[dialogname].window.focus();
 				return false;
 			}
-		} else if(dialogname.match("contactitem_detailaddressdialog") != null && !window.BROWSER_IE) {
-			if(typeof webclient.dialogs[dialogname].window == "undefined" || webclient.dialogs[dialogname].window.closed == false) {
-				webclient.dialogs[dialogname].window.focus();
-				return false;
-			}
 		}
 	}
 
@@ -154,20 +153,15 @@ function submitContact()
 	
 	// Current Address
 	var selected_address = dhtml.getElementById("selected_address");
-	var address = dhtml.getElementById("address");
-	
-	var address_element_id = "business";
-	switch(selected_address.value)
-	{
-		case "1":
-			address_element_id = "home";
-			break;
-		case "3":
-			address_element_id = "other";
-			break;
-	}
-	
-	dhtml.getElementById(address_element_id + "_address").value = address.value;
+
+	data = new Object();
+	data["street"] = dhtml.getElementById("address_street").value;;
+	data["city"] = dhtml.getElementById("address_city").value;
+	data["state"] = dhtml.getElementById("address_state").value;
+	data["zip"] = dhtml.getElementById("address_postal_code").value;
+	data["country"] = dhtml.getElementById("address_country").value;
+
+	moduleObject.storeDetailedInfo(data, "address", false);
 
 	// update phone number input fields
 	updatePhoneNumberFields();
@@ -320,6 +314,18 @@ function onChangeEmailAddress()
 	email_address_display_name.value = dhtml.getElementById("email_address_display_name_" + selected_email_address.value).value;
 }
 
+/**
+ * Function is called when value of email_address_display_name is changed.
+ * if email_address_x is set then don't allow email_address_display_name to set empty.
+ */
+function onUpdateEmailAddressDisplayName() {
+	var email_address = dhtml.getElementById("email_address");
+	var email_address_display_name = dhtml.getElementById("email_address_display_name");
+
+	if(email_address_display_name.value == "" && email_address.value != "")
+		onUpdateEmailAddress();
+}
+
 function onUpdateEmailAddress()
 {
 	var email_address = dhtml.getElementById("email_address");
@@ -332,13 +338,11 @@ function onUpdateEmailAddress()
 	}
 }
 
-function onChangeAddress()
+function onChangeAddress(moduleObject)
 {
-	var address_button = dhtml.getElementById("address_button");
 	var selected_address = dhtml.getElementById("selected_address");
 	var mailing_address = dhtml.getElementById("mailing_address");
 	var checkbox_mailing_address = dhtml.getElementById("checkbox_mailing_address");
-	var address = dhtml.getElementById("address");
 
 	var address_element_id = "business";
 	switch(selected_address.value)
@@ -350,8 +354,15 @@ function onChangeAddress()
 			address_element_id = "other";
 			break;
 	}
-	
-	dhtml.getElementById(address_element_id + "_address").value = address.value;
+
+	data = new Object();
+	data["street"] = dhtml.getElementById("address_street").value;;
+	data["city"] = dhtml.getElementById("address_city").value;
+	data["state"] = dhtml.getElementById("address_state").value;
+	data["zip"] = dhtml.getElementById("address_postal_code").value;
+	data["country"] = dhtml.getElementById("address_country").value;
+
+	moduleObject.storeDetailedInfo(data, "address", false);
 
 	if(typeof module.selectedMenuItem == "undefined") {
 		var selectedMenuItem = "business";
@@ -370,7 +381,12 @@ function onChangeAddress()
 			break;
 	}
 
-	address.value = dhtml.getElementById(selectedMenuItem + "_address").value
+	dhtml.getElementById("address_street").value = dhtml.getElementById(selectedMenuItem + "_address_street").value;
+	dhtml.getElementById("address_city").value = dhtml.getElementById(selectedMenuItem + "_address_city").value;
+	dhtml.getElementById("address_state").value = dhtml.getElementById(selectedMenuItem + "_address_state").value;
+	dhtml.getElementById("address_postal_code").value = dhtml.getElementById(selectedMenuItem + "_address_postal_code").value;
+	dhtml.getElementById("address_country").value = dhtml.getElementById(selectedMenuItem + "_address_country").value;
+
 	if(selected_address.value == mailing_address.value) {
 		dhtml.setValue(checkbox_mailing_address, true);
 	} else {
@@ -582,96 +598,6 @@ function contactitemDetailphonenumber_dialog_callback(result, callbackData) {
 	}
 }
 
-/**
- * Function will create an advprompt dialog for detailed address
- * @param object moduleObject
- */
-function eventShowDetailAddressDialog(moduleObject) {
-	if(!moduleObject.contactDialogOpen)
-		return false;
-	// check dialog is already opened or not (only for FF)
-	/*
-	 * IE doesn't return webclient.dialogs[dialogname].window object so it will be always undefined,
-	 * but since this fix is only needed for FF we have to remove this checking in IE
-	 * in FF
-	 * if user first time opens detailed dialog then window object will be undefined, in this case allow to show detailed dialog
-	 * if user has opened and closed detailed dialog then window object will be defined so we have to check property window.closed for actual state of the dialog
-	 * if detailed dialog is already open then window.closed will be false so don't show new detailed dialog
-	 */
-	for(var dialogname in webclient.dialogs) {
-		if(dialogname.match("contactitem_detailaddressdialog") != null && !window.BROWSER_IE) {
-			if(typeof webclient.dialogs[dialogname].window == "undefined" || webclient.dialogs[dialogname].window.closed == false) {
-				webclient.dialogs[dialogname].window.focus();
-				return false;
-			}
-		}
-	}
-
-	var result = moduleObject.parseDetailedInfo(dhtml.getElementById("address").value, "address", true);
-
-	webclient.openModalDialog(moduleObject.id, 'contactitem_detailaddressdialog', DIALOG_URL+'task=advprompt_modal', 325,300, contactitemDetailaddress_dialog_callback, {
-			moduleObject: moduleObject
-		}, {
-			windowname: _("Check Address"),
-			dialogtitle: _("Address details"),
-			fields: [{
-				name: "street",
-				label: _("Street") + ":",
-				type: "textarea",
-				required: false,
-				value: result["street"]
-			},
-			{
-				name: "city",
-				label: _("City") + ":",
-				type: "input",
-				required: false,
-				value: result["city"]
-			},
-			{
-				name: "state",
-				label: _("State/Province") + ":",
-				type: "input",
-				required: false,
-				value: result["state"]
-			},
-			{
-				name: "zip",
-				label: _("ZIP/Postal code") + ":",
-				type: "input",
-				required: false,
-				value: result["zip"]
-			},
-			{
-				// @TODO make select box
-				name: "country",
-				label: _("Country/Region") + ":",
-				type: "input",
-				required: false,
-				value: result["country"]
-			},
-			{
-				name: "setting",
-				label: _("Show this again when address is incomplete or unclear"),
-				type: "checkbox",
-				required: false,
-				value: result["setting"]
-			}]
-		}
-	);
-}
-
-/**
- * Callback Function to store details of address entered in advprompt dialog
- * @param array result[element id] => value
- * @param object callbackdata
- */
-function contactitemDetailaddress_dialog_callback(result, callbackData) {
-	if(callbackData.moduleObject){
-		callbackData.moduleObject.storeDetailedInfo(result, "address", true);
-	}
-}
-
 /**
  * Function will show phone selection menu
  * @param object moduleObject
@@ -734,28 +660,6 @@ function eventOnChangePhoneType(moduleObject, element, event) {
 	}
 }
 
-/**
- * Function will show address selection menu
- * @param object moduleObject
- * @param htmlElement element which called this function
- * @param event event information
- */
-function eventShowAddressTypeMenu(moduleObject, element, event) {
-	var items = new Array();
-	var selected = "not_selected";
-	for(var key in moduleObject.address_type) {
-		if(dhtml.getElementById(key + "_address").value != "") {
-			selected = "selected";
-		} else {
-			selected = "not_selected";
-		}
-		items.push(webclient.menu.createMenuItem(selected + " " + key, moduleObject.address_type[key], false, eventOnChangeAddressType, false, false, key));
-	}
-
-	// show context menu
-	webclient.menu.buildContextMenu(moduleObject.id, element.id, items, element.offsetLeft + element.offsetWidth, element.offsetTop);
-}
-
 /**
  * Function will be executed when you select an address type from menu
  * @param object moduleObject
@@ -763,20 +667,13 @@ function eventShowAddressTypeMenu(moduleObject, element, event) {
  * @param event event information
  */
 function eventOnChangeAddressType(moduleObject, element, event) {
-	dhtml.getElementById("address_button").value = element.innerHTML + ":";
-
 	// name of the selected address type is stored in data variable of element
-	moduleObject.selectedMenuItem = element["data"];
+	moduleObject.selectedMenuItem = dhtml.getElementById("select_address_combo").value;
 
-	onChangeAddress();
+	onChangeAddress(moduleObject);
 
 	// set focus to the address textarea
-	dhtml.getElementById("address").focus();
-
-	// remove context menu
-	if(dhtml.getElementById("contextmenu")) {
-		dhtml.deleteElement(dhtml.getElementById("contextmenu"));
-	}
+	dhtml.getElementById("address_street").focus();
 }
 
 /**
@@ -846,7 +743,7 @@ function eventContactItemKeyCtrlSave(moduleObject, element, event, keys)
 	switch(event.keyCombination)
 	{
 		case keys["save"]:
-			submitContact();
+			submitContact(moduleObject);
 			break;
 	}
 }
@@ -857,8 +754,15 @@ function eventContactItemKeyCtrlSave(moduleObject, element, event, keys)
  */
 function eventDatePickerInputChange()
 {
-	var oldValue = dhtml.getElementById("text_birthday").value;
-	var valueArr = oldValue.trim().split("-"); // get the values as dd - mm - yyyy
+	var oldValue = dhtml.getElementById("text_birthday").value.trim();
+	/**
+	 * Split date string in to sub parts to get value
+	 * German language  ->		dd.mm.yyyy
+	 * English US language ->	dd/mm/yyyy
+	 * Other languages  ->		dd-mm-yyyy
+	 */
+	var valueArr = oldValue.split(/[-.//]/);
+
 	if(valueArr.length > 0 && valueArr[0] != ""){	
 		var result = checkDateValidation(valueArr[0], valueArr[1], valueArr[2]);
 		if(result){
