@@ -1118,6 +1118,11 @@ Calendar._keyEvent = function(ev) {
  *  (RE)Initializes the calendar to the given date and firstDayOfWeek
  */
 Calendar.prototype._init = function (firstDayOfWeek, date) {
+	date.setHours(12);
+	date.setMinutes(0);
+	date.setSeconds(0);
+	date.setMilliseconds(0);
+	console.trace();
 	var today = new Date(),
 		TY = today.getFullYear(),
 		TM = today.getMonth(),
@@ -1495,7 +1500,7 @@ Calendar.prototype.setTtDateFormat = function (str) {
 Calendar.prototype.parseDate = function(str, fmt) {
 	if (!fmt)
 		fmt = this.dateFormat;
-	this.setDate(Date.parseDate(str, fmt));
+	this.setTime(Date.parseDate(str, fmt).getTime() + 12 * 60 * 60 * 1000); // Use midday to make sure we don't hit DST changes
 };
 
 Calendar.prototype.hideShowCovered = function () {
@@ -1615,6 +1620,9 @@ Date.HOUR   = 60 * Date.MINUTE;
 Date.DAY    = 24 * Date.HOUR;
 Date.WEEK   =  7 * Date.DAY;
 
+Date.minYear   = 1901; // least year to consider (supported at serverside)
+Date.maxYear   = 2038; // most year to consider (supported at serverside)
+
 // utc specifies that date string is UTC time string
 Date.parseDate = function(str, fmt, utc, failunparsable) {
 	var today = new Date();
@@ -1626,23 +1634,29 @@ Date.parseDate = function(str, fmt, utc, failunparsable) {
 	var i = 0, j = 0;
 	var hr = 0;
 	var min = 0;
+	//always check the failunparsable so the if the parse fails we return false
+	if(typeof failunparsable == "undefined") failunparsable = true;
+
 	for (i = 0; i < a.length; ++i) {
 		if (!a[i])
 			continue;
 		switch (b[i]) {
 		    case "%d":
 		    case "%e":
-			d = parseInt(a[i], 10);
+			//set d to 0 if the day value while parsing is invalid according to format
+			d = parseInt(a[i], 10) > 31 ? 0 : parseInt(a[i], 10);
 			break;
 
 		    case "%m":
-			m = parseInt(a[i], 10) - 1;
+			//set m to -1 if the month value while parsing is invalid according to format
+			m = parseInt(a[i], 10) > 12 ? -1 : parseInt(a[i], 10) - 1;
 			break;
 
 		    case "%Y":
 		    case "%y":
 			y = parseInt(a[i], 10);
 			(y < 100) && (y += (y > 29) ? 1900 : 2000);
+			y = (y < this.minYear || y > this.maxYear) ? -1 : y;
 			break;
 
 		    case "%b":
@@ -1677,13 +1691,14 @@ Date.parseDate = function(str, fmt, utc, failunparsable) {
 	if (isNaN(d)) d = today.getDate();
 	if (isNaN(hr)) hr = today.getHours();
 	if (isNaN(min)) min = today.getMinutes();
-	if (y != 0 && m != -1 && d != 0) {
+	if (y > 0 && m != -1 && d != 0) {
+		failunparsable = false;
 		if(utc)
 			return new Date(Date.UTC(y, m, d, hr, min, 0));
 		else
 			return new Date(y, m, d, hr, min, 0);
 	}
-	y = 0; m = -1; d = 0;
+	m = -1; d = 0;
 	for (i = 0; i < a.length; ++i) {
 		if (a[i].search(/[a-zA-Z]+/) != -1) {
 			var t = -1;
@@ -1707,7 +1722,13 @@ Date.parseDate = function(str, fmt, utc, failunparsable) {
 	}
 	if (y == 0)
 		y = today.getFullYear();
-	if (m != -1 && d != 0) {
+	/**
+	 * here we also need to check the date range before getting the date.
+	 * Actually its kins of a HACK as Date Object works well enven if date value is more 
+	 * then 31 days it just add the extra days to next month and gives the output
+	 */
+	if (y > 0 && m != -1 && d != 0 && d <= 31) {
+		failunparsable = false;
 		if(utc) 
 			return new Date(Date.UTC(y, m, d, hr, min, 0));
 		else
