@@ -325,7 +325,7 @@ function submit_task(send) {
 
 		var props = getPropsFromDialog();
 
-		// check for precent complete value
+		// check for percent complete value
 		var text_percent_complete = props["text_percent_complete"];
 
 		if(text_percent_complete.indexOf("%") >= 0) {
@@ -357,13 +357,13 @@ function submit_task(send) {
 
 					// User cannot send a task request himself/herself.
 					if (recipientList[i]["address"] == webclient.emailaddress) {
-						alert(_("You cannot sent a task request to yourself."));
+						alert(_("You cannot send a task request to yourself."));
 						return false;
 					}
 
 					// Prompt that task updates will not be mentained if more than one assignee
 					if ((recipientList[i]["address"] && filter.test(recipientList[i]["address"].trim())) || multipleRecips > 1) {
-						if (!confirm(_("This task is addressed to more than one recipient. Your copy of task will not be updated.")))
+						if (!confirm(_("This task is addressed to more than one recipient, therefore your copy of the task will not be updated.")))
 							return false;
 						props['taskmultrecips'] = true;
 					}
@@ -625,7 +625,7 @@ function checkNamesCallBack(resolveObj, fireChangeEvent)
 			dhtml.getElementById(i).value = newString;
 
 			// also fire change event if change event is happen on to, cc, bcc fields (growing fields) of createmail
-			if(typeof fireChangeEvent != "undefined" && fireChangeEvent) {
+			if(fireChangeEvent) {
 				dhtml.executeEvent(dhtml.getElementById(i), "change");
 			}
 		}
@@ -1003,4 +1003,39 @@ function insertAtCursor(textArea, value) {
 		textArea.value += value;
 	}
 	
+}
+
+/**
+ * Function which validates the input text is a valid date or not
+ * This function is pretty much same as that in datepicker widget.
+ * its duplicated here coz we do not use datepicker widgets every where 
+ * while using the Calendar(Date) object.
+ */
+function eventDateInputChange(moduleObject, element, event)
+{
+	var oldValue = element.value;
+	if(element.value.toLowerCase() != _("None").toLowerCase()) {
+		var newValue = Date.parseDate(element.value.trim(),_("%d-%m-%Y"), true);
+		if(!newValue){
+			alert(_("You must specify a valid date and/or time. Check your entries in this dialog box to make sure they represent a valid date and/or time."));
+			element.value = _("None");
+			if(element.onchange)
+				element.onchange(element);
+		}else{
+			element.value = newValue.print(_("%d-%m-%Y")); 
+			if(element.onchange)
+				element.onchange(element);
+		}
+	}
+}
+
+/**
+ * Change the title of the dialog
+ * @param name String New name to be shown as title
+ */
+function setDialogTitle(name){
+	// Set title of browser window
+	window.document.title = name;
+	// Set the inline dialog title
+	dhtml.getElementById("windowtitle").innerHTML = name;
 }
\ No newline at end of file
