@@ -73,8 +73,8 @@ function proposeNewTime(moduleObject)
 	webclient.openWindow(-1, 'previewreadmailitem_proposenewtimedialog', DIALOG_URL+'task=advprompt_modal', 325,250, true, proposeNewTime_readmaildialog_callback, {
 			moduleObject: module ? module : {}
 		}, {
-			windowname: _("Propose new time"),
-			dialogtitle: _("Propose new time"),
+			windowname: _("Propose New Time"),
+			dialogtitle: _("Propose New Time"),
 			fields: [{
 				name: "combineddatetimepicker",
 				label_start: _("Start time"),
