@@ -84,9 +84,9 @@ function submitRecurrence()
 	var submitResult = false;
     if(dhtml.getElementById("end_by").checked){
 		if(startDate == endDate){
-    		alert(_("Start date and End date for range of recurrence can not be same."));  
+    		alert(_("The start date and end date for the range of recurrence can not be same."));  
 		}else if(endDate < currentDate){
-			if(confirm(_("All instances of this recurring appointment occur in the past.") + "\n" + _("would you like to continue?")))
+			if(confirm(_("All occurrences of this recurring appointment are scheduled in the past.\nWould you like to continue?")))
 				submitResult = true;
 		}else if(startDate > endDate){
     		alert(_("The recurrence pattern is not valid."));
