@@ -68,7 +68,7 @@ function restore_selected_items(){
 				displaynames.push(tableWidget.getDataByRowID(rowId).display_name.innerHTML);
 			}
 		}
-		var send = confirm(_("Would you like to restore selected items?"));
+		var send = confirm(_("Would you like to restore the selected items?"));
 		if(send) {
 			var data = createRequestObject(module, action_type, entryIds, displaynames);
 	
@@ -101,7 +101,7 @@ function permanent_delete_items(){
 			var rowId = tableWidget.getSelectedRowID(i);
 			entryIds.push(tableWidget.getDataByRowID(rowId).entryid);
 		}
-		var send = confirm(_("Would you like to delete selected items permanently, after that you will not be able to restore them anyway?"));
+		var send = confirm(_("Would you like to delete the selected items permanently (items will not be recoverable)?"));
 		if(send) {
 			var data = createRequestObject(module, action_type, entryIds);
 			webclient.xmlrequest.showLoader();
@@ -109,7 +109,7 @@ function permanent_delete_items(){
 			webclient.xmlrequest.sendRequest();
 		}
 	}else{
-		alert(_("Please select a row first to delete"));
+		alert(_("Please first select a row to delete."));
 	}
 }
 
@@ -132,7 +132,7 @@ function permanent_delete_all(){
 			webclient.xmlrequest.sendRequest();
 		}
 	}else{
-		alert(_("There are no items in list to Delete"));
+		alert(_("There are no items in the list to delete."));
 	}
 }
 
@@ -186,7 +186,7 @@ function initRestoreItems(data, type){
 			{id:"folder_icon_index",name:"","title":"Icon","sort":false,"visibility":true,"order":0,"width":30},
 			{id:"display_name",name:_("Name"),"title":"Folder Name","sort":true,"visibility":true,"order":1,"width":300},
 			{id:"deleted_on",name:_("Deleted on"),"title":"Deleted on","sort":true,"visibility":true,"order":2,"width":200},
-			{id:"content_count",name:_("Itemcount"),"title":"Item Count","sort":true,"visibility":true,"order":3,"width":""}
+			{id:"content_count",name:_("Item count"),"title":"Item Count","sort":true,"visibility":true,"order":3,"width":""}
 		]; 	
 	} 
 
