@@ -81,26 +81,22 @@ function initSharedFolder() {
 
 	dhtml.addEvent(-1, foldertype, "change", sharedFolderOnChangeFolderType);
 }
+
 function submitSharedFolder(){
-    var username = dhtml.getElementById("username").value.trim();
-    
-    if (username==""){
+
+    if (dhtml.getElementById("username").value.trim()==""){
         alert(_("You must specify a username!"));
         return;
-    }
-
-    var folder = dhtml.getElementById("foldertype").value;
-    var subfolders = dhtml.getElementById("subfolders_checkbox").checked;
-
-    var result = new Object;
-    result.username = username;
-    result.folder = folder;
-    result.subfolders = String(subfolders);
-
-    return window.resultCallBack(result, window.callBackData);
+    }else if(window.usernamefromAB === true){
+		submitSharedFolderWithResolvedName();
+	}else{
+		checkNames(checkNamesCallBackForSharedFolder);
+	}
 }
 
 function addressBookCallBack(userdata) {
+
+	window.usernamefromAB = true;
     dhtml.getElementById('username').value = userdata.value;
 }
 
@@ -109,7 +105,6 @@ function openSelectUserDialog(storeid){
 	windowData["hide_users"] = ["contact"];
 	windowData["hide_groups"] = ["dynamic", "normal", "everyone", "security"];
 	windowData["hide_companies"] = true;
-
     webclient.openModalDialog(module, 'addressbook', DIALOG_URL+'task=addressbook_modal&storeid='+storeid+'&type=username_single&source=gab', 800, 500, addressBookCallBack, false, windowData);
 }
 
@@ -122,4 +117,68 @@ function sharedFolderOnChangeFolderType(moduleObject, element, event) {
 		dhtml.getElementById("subfolders_checkbox").disabled = false;
 		dhtml.removeClassName(dhtml.getElementById("subfolders_label"), "disabled_text");
 	}
+}
+
+/**
+ * Function which call resolvename module
+ * @param function callBackFunction which will return the resolved name
+ */
+function checkNames(callBackFunction){
+	if(dhtml.getElementById("username").value.trim() == "")
+		return;
+	
+	var resolveQue = new Object();
+	/**
+	 * This is sort of Hack. 
+	 * As currently the resolvename module is very tightly bounded with recipients fields.
+	 * So, if u want to resolve any names you need to create an object with to,cc,bcc fields
+	 */ 
+	resolveQue["to"] = dhtml.getElementById("username").value;
+	resolveQue["cc"] = '';
+	parentWebclient.resolvenames.resolveNames(resolveQue, callBackFunction, true);
+}
+
+/**
+ * Function is a CallBack function which will return reslved name
+ * @param Object resolveObj it has the list of resolved names
+ */
+function checkNamesCallBackForSharedFolder(resolveObj)
+{
+	for(var i in resolveObj){
+
+		//replace unresolved name
+		var unResolved = dhtml.getElementById("username").value.trim();
+		for(var keyword in resolveObj[i]){
+			if(unResolved == keyword)
+				unResolved = resolveObj[i][keyword]["username"];
+		}
+	}	
+	dhtml.getElementById("username").value = unResolved ;
+	submitSharedFolderWithResolvedName();
+}
+
+/**
+ * Function is to submit the OpenSharedfolder dialog with resolved username
+ * this will return the username, folder, subfolder data to the callback.
+ */
+function submitSharedFolderWithResolvedName(){
+	var username = dhtml.getElementById("username").value;
+    var folder = dhtml.getElementById("foldertype").value;
+    var subfolders = dhtml.getElementById("subfolders_checkbox").checked;
+
+    var result = new Object;
+    result.username = username;
+    result.folder = folder;
+    result.subfolders = String(subfolders);
+		
+	window.close();
+	return window.resultCallBack(result, window.callBackData);	
+}
+
+/**
+ * Function which is called if username textbox is edited.
+ * this sets the global usernamefromAB's value
+ */
+function userNameChange(){
+	window.usernamefromAB = false;
 }
\ No newline at end of file
