@@ -164,10 +164,12 @@ function mucalendarDialog_addusertogroup_addCallBack(result, callbackData) {
 				}
 				users.push(userData);
 			}
+			// newUser array is create which has the list of all new user being added to group
+			var newUser = new Array();
 			if(result.multiple){
 				for(var key in result){
 					if(key != "multiple" && key != "value"){
-						users.push({
+						newUser.push({
 							userentryid: result[key].entryid,
 							username: result[key].fileas,
 							display_name: result[key].display_name,
@@ -176,14 +178,26 @@ function mucalendarDialog_addusertogroup_addCallBack(result, callbackData) {
 					}
 				}
 			}else{
-				users.push({
+				newUser.push({
 					userentryid: result.entryid,
 					username: result.fileas,
 					display_name: result.display_name,
 					emailaddress: result.email_address
 				});
 			}
-			
+			// here we check for the duplicate data, by comparing the two userlist and 
+			// newUserlist to check if user already exist.
+			if(newUser && newUser.length > 0){
+				for(var i=0; i<newUser.length; i++){
+					for(var j=0; j<users.length; j++){
+						if(compareEntryIds(newUser[i].userentryid, users[j].userentryid))
+							newUser[i] = false;
+					}
+					if(newUser[i])
+						users.push(newUser[i]);
+				}
+			}
+
 			webclient.xmlrequest.addData(module, "savegroup", {users: users, group_entry_id: callbackData.groupEntryID});
 			webclient.xmlrequest.addData(module, "getgroupusers", {group_entry_id: callbackData.groupEntryID});
 			setTimeout(function(){
