@@ -252,13 +252,16 @@ AdvancedFindListModule.prototype.messageList = function(action)
 	// add columns in table widget that is fetched from XML response
 	advFindAddColumns(this, this.properties);
 
+	//flag to check if user is explicity sorting or not
+	var sortingFlag = dhtml.getXMLValue(action, "has_sorted_results", false);
+	
 	var items = action.getElementsByTagName("item");
 	if(items.length > 0) {
 		// store properties of messages
 		this.getItemPropsFromXML(items);
-
+		
 		// create row column data and pass it to table widget to create layout
-		this.tableGenerated = advFindSetRowColumnData(this, items, this.properties);
+		this.tableGenerated = advFindSetRowColumnData(this, items, this.properties, sortingFlag);
 	}
 
 	this.paging(action);
@@ -445,12 +448,31 @@ AdvancedFindListModule.prototype.search = function()
 		}
 
 		data["restriction"]["start"] = this.rowstart;
-
+		
 		data["subfolders"] = this.searchSubfolders;
 
 		// search folder should be used or not
 		data["use_searchfolder"] = this.useSearchFolder;
 
+		if(this.sort) {
+			data["sort"] = new Object();
+			data["sort"]["column"] = this.sort;
+			data["sort_result"] = true;
+		}else{
+			//by default set it to sort on subject in asc order
+			this.sort = new Array();
+			var column = new Object();
+			column["attributes"] = new Object();
+			column["attributes"]["direction"] = "asc";
+			column["_content"] = "subject";
+			// push column in a sortColumns array
+			this.sort.push(column);
+
+			data["sort"] = new Object();
+			data["sort"]["column"] = this.sort;
+			data["sort_result"] = false;
+		}
+
 		webclient.xmlrequest.addData(this, "search", data);
 		webclient.xmlrequest.sendRequest();
 
@@ -619,7 +641,7 @@ AdvancedFindListModule.prototype.clearSearch = function()
 		clearTimeout(this.timeoutId);
 		this.timeoutId = false;
 	}
-
+	this.sort = false;
 	this.searchInProgress = false;
 	this.searchFolderEntryID = false;
 	this.tableGenerated = false;
@@ -744,6 +766,66 @@ AdvancedFindListModule.prototype.checkForChangedValues = function()
 	}
 }
 
+/**
+ * Function will be called when user clicks on a header column of table widget 
+ * for sort the results on bases of the click column.This also set the sorting
+ * column for the list
+ * @param		Object			tblWidget		table widget object
+ * @param		String			type			type of event
+ * @param		HexString		columnId		columnId of element row
+ * @param		EventObject		event			event object
+ */
+AdvancedFindListModule.prototype.eventAdvFindColumnClick = function(tblWidget, type, columnId, event) {
+	if(typeof columnId != "undefined" && columnId) {
+
+		//get the old columns on which the result were sorted
+		var old_sortDirection = tblWidget.sortDirection;
+		var old_sortColumn = tblWidget.sortColumn;
+
+		var sortColumn = columnId.id.substring(columnId.id.indexOf("_") + 1);
+		if(columnId.id.indexOf("sort") > 0) {
+			sortColumn = columnId.id.substring(columnId.id.indexOf("_") + 1, columnId.id.indexOf("sort") - 1);
+		}
+		
+		var sortDirection = "";
+		// change direction only when you click the already sorted column
+		if (sortColumn == old_sortColumn){
+			sortDirection = old_sortDirection == "desc"? "asc" : "desc";
+		}else{
+			sortDirection = old_sortDirection;
+		}
+		
+		if(!sortDirection)
+			sortDirection = "asc";
+		
+		var sortSaveList = Object();
+		sortSaveList[sortColumn] = sortDirection
+		
+		/**
+		 * flag status column value depends on values of flag_status and flag_icon properties,
+		 * so do sorting on both properties.
+		 */
+		if(sortColumn == "flag_icon")
+			sortSaveList["flag_status"] = sortDirection;
+			
+		var sortColumns = new Array();
+		var column = new Object();
+		column["attributes"] = new Object();
+		column["attributes"]["direction"] = sortDirection;
+		column["_content"] = sortColumn;
+		// push column in a sortColumns array
+		sortColumns.push(column);
+
+		// If sortColumns is not available then return false otherwise return sortColumns.
+		if(sortColumns.length <= 0){
+			this.sort = false;
+		}else{
+			this.sort = sortColumns;
+		}
+		this.search();
+	}
+}
+
 /**
  * Function will be called when user double clicks on a message in table widget
  * @param		Object			tblWidget		table widget object
@@ -1027,9 +1109,9 @@ function eventAdvFindChangeMessageType(moduleObject, element, event) {
 		moduleObject.container_class = container_class;
 
 		// also change value of selectedFolders variable
-		for(var key in moduleObject.selectedFolders) {
+		for(var index = 0; index < moduleObject.selectedFolders.length; index++) {
 			// remove previous values
-			delete moduleObject.selectedFolders[key];
+			delete moduleObject.selectedFolders[index];
 		}
 
 		// add new values
