@@ -117,6 +117,24 @@ appointmentitemmodule.prototype.setEndTime = function(unixtime)
 	dhtml.getElementById("commonend").setAttribute("unixtime",unixtime);
 	appoint_dtp.setEndValue(unixtime);
 }
+/**
+ * Function will set the location of the meeting in the appointment
+ * @param string resource
+ */
+appointmentitemmodule.prototype.setLocation = function(resource)
+{
+	if(resource){
+		var location = dhtml.getElementById("location").value;
+		if(!location){
+			dhtml.getElementById("location").value = resource;
+		}else if (location != resource){
+			if(confirm(_("Do you want to update the location '%s' with new location '%s'").sprintf(location, resource)))
+				dhtml.getElementById("location").value = resource;
+			else
+				dhtml.getElementById("location").value = location;
+		}
+	}
+}
 
 appointmentitemmodule.prototype.getStartTime = function()
 {
@@ -323,7 +341,9 @@ appointmentitemmodule.prototype.deleteMessage = function (basedate)
 	var send = false;
 	var meeting = parseInt(this.itemProps["meeting"], 10);
 	var recurring = parseInt(this.itemProps["recurring"], 10);
-	var isMeetingOrganized = parseInt(this.itemProps["responsestatus"], 10) == olResponseOrganized;
+	var responseStatus = parseInt(this.itemProps["responsestatus"], 10);
+	var isMeetingOrganized = responseStatus == olResponseOrganized;
+	var isMeetingAttendee = responseStatus != olResponseNone && responseStatus != olResponseOrganized;
 
 	if(basedate) {
 		//occurrence end date
@@ -333,11 +353,11 @@ appointmentitemmodule.prototype.deleteMessage = function (basedate)
 		if (meeting !== 0 && (endtime.getTime() > (new Date().getTime()))) {
 			/**
 			 * if occurrence is later then send confirmation message for cancellation message.
-			 * Check whether there are any recepients in MR or not.
+			 * Check whether there are any recepients/resource in MR or not.
 			 */
-			if (isMeetingOrganized && !(this.itemProps.requestsent && this.itemProps.requestsent != "1")) {
+			if (isMeetingOrganized && this.itemProps.requestsent && this.itemProps.requestsent == "1") {
 				send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
-			} else {
+			} else if (!isMeetingOrganized){
 				sendConfirmationDeleteAppointmentItem(this, this.itemProps["subject"], basedate);
 				return true;
 			}
@@ -383,9 +403,9 @@ appointmentitemmodule.prototype.deleteMessage = function (basedate)
 		// if recurrence is later then send confirmation message for cancellation message.
 		if(meeting !== 0 && endtime.getTime() > (new Date().getTime())) {
 			// Check whether there are any recepients in MR or not.
-			if (isMeetingOrganized && !(this.itemProps.requestsent && this.itemProps.requestsent != "1")) {
+			if (isMeetingOrganized && this.itemProps.requestsent && this.itemProps.requestsent == "1" ) {
 				send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
-			} else {
+			} else if (isMeetingAttendee){
 				sendConfirmationDeleteAppointmentItem(this, this.itemProps["subject"]);
 				return true;
 			}
@@ -449,7 +469,6 @@ appointmentitemmodule.prototype.execute = function (type, action)
 	}
 }
 
-
 /**
  * Function which saves an item.
  * @param object props the properties to be saved
@@ -462,9 +481,9 @@ appointmentitemmodule.prototype.save = function(props, send, recipients, dialog_
 		data["store"] = this.storeid;
 	}
 
-	if(this.isMeeting == true && props["entryid"] == ""){
+	if(this.isMeeting == true){
 		// Add human readable BODY Text.
-		props["body"] = this.addMeetingTimeInfoToBody(props["body"], props['startdate'], props['duedate'], props['location'], props["recurring"] ? props["recurring_pattern"] : false);
+		props["meetingTimeInfo"] = this.addMeetingTimeInfoToBody(props["body"], props['startdate'], props['duedate'], props['location'], props["recurring"] ? props["recurring_pattern"] : false);
 	}
 
 	if(this.parententryid)
@@ -565,7 +584,16 @@ appointmentitemmodule.prototype.messageSaved = function(action)
 				alert(_("Meeting was not scheduled."));
 				break;
 		}
+	}else if(dhtml.getXMLValue(action, "remindertime", false)){
+		var errorMessageString = dhtml.getXMLValue(action, "error_message", false);
+		if(errorMessageString)
+			alert(errorMessageString);
+	}else if(dhtml.getXMLValue(action, "proposetime", false)){
+		var errorMessageString = dhtml.getXMLValue(action, "error_message", false);
+		if (errorMessageString) 
+			alert(errorMessageString);
 	}
+
 	module.saving = false;
 	module.savingMeetingRequest = false;
 }
\ No newline at end of file
