@@ -120,15 +120,15 @@ createmailitemmodule.prototype.execute = function(type, action)
 			window.close();
 			break;
 
-		case "convert_item":
-			this.setBodyFromItemData(action);
-			break;
-
 		// will built attachment items while composing mail
 		case "attach_items":		
 			webclient.menu.showMenu();
 			this.setAttachItemData(action);
-			break;		
+			break;
+			
+		case "convert_item":
+			this.setBodyFromItemData(action);
+			break;
 		case "getAttachments":		// Uploaded Attachment list.
 			this.attachmentsList(action);
 			break;
@@ -270,6 +270,12 @@ createmailitemmodule.prototype.item = function(action)
 				this.setSubjectBody(message, _("FW"));
 				this.setAttachments(message);
 				break;
+			case "edit":
+				this.setRecipients(message);
+				this.setSubjectBody(message, false);
+				this.setAttachments(message);
+				this.setBody(message, false, true);
+				break;
 			default:
 				this.setRecipients(message);
 				this.setBody(message, false, true);
@@ -436,7 +442,7 @@ createmailitemmodule.prototype.setSubjectBody = function(message, type)
 	var subjectElement = dhtml.getElementById("subject");
 	if(subject && subject.firstChild) {
 		var subjectValue = subject.firstChild.nodeValue;
-		if(subject.firstChild.nodeValue.indexOf(type) < 0) {
+		if(type && subject.firstChild.nodeValue.indexOf(type) < 0) {
 			subjectValue = type + ": " + subjectValue;
 		}
 		
@@ -466,7 +472,8 @@ createmailitemmodule.prototype.setBody = function(message, isReply, isConcept, a
 		var reply_seperator = "";
 		var contentprefix = "";
 		var contentpostfix = "";
-		var signature_seperator = "";
+		var signature_seperator_start = "";
+		var signature_seperator_end = "";
 		
 		var htmlFormat = use_html.value == "true" ? true : false;
 
@@ -501,7 +508,7 @@ createmailitemmodule.prototype.setBody = function(message, isReply, isConcept, a
 					isMailPrefix = webclient.settings.get("createmail/on_message_replies", "add_prefix");
 
 				if(htmlFormat) {
-					reply_seperator = "<p>&nbsp;<br/>&nbsp;</p>";
+					reply_seperator = "<p><br/>&nbsp;</p>";
 					if(isMailPrefix == "add_prefix") {
 						contentprefix = "<blockquote style='border-left: 2px solid #325FBA; padding-left: 5px;margin-left:5px;'>";
 						contentpostfix = "</blockquote>";
@@ -547,25 +554,27 @@ createmailitemmodule.prototype.setBody = function(message, isReply, isConcept, a
 					if(!htmlFormat) {
 						// no conversion
 						signature = signatureData["content"];
-						signature_seperator = "\n\n";
+						signature_seperator_start = "\n\n";
 					} else {
 						// convert plain signature to html format
 						signature = convertPlainToHtml(signatureData["content"]);
-						signature_seperator = "<p><br/></p>";
+						signature_seperator_start = "<p><br/>";
+						signature_seperator_end = "</p>";
 					}
 				} else {
 					// signature is stored in html format
 					if(!htmlFormat) {
 						//convert html signature to plain text format
 						signature = convertHtmlToPlain(signatureData["content"]);
-						signature_seperator = "\n\n";
+						signature_seperator_start = "\n\n";
 					} else {
 						// no conversion
 						signature = signatureData["content"];
-						signature_seperator = "<p><br/></p>";
+						signature_seperator_start = "<p><br/>";
+						signature_seperator_end = "</p>";
 					}
 				}
-				signature = signature_seperator + signature;
+				signature = signature_seperator_start + signature + signature_seperator_end;
 			}
 		}
 
