@@ -240,7 +240,7 @@ delegatesmodule.prototype.getSelectedDelegates = function ()
 function eventAddDelegate(moduleObject, element, event)
 {
 	var windowData = new Object();
-	windowData["hide_groups"] = ["dynamic", "normal", "everyone", "security"];
+	windowData["hide_groups"] = ["dynamic", "normal", "everyone"];
 	windowData["hide_companies"] = true;
 
 	parentWebclient.openModalDialog(-1, 'addressbook', DIALOG_URL+'task=addressbook_modal&storeid='+ moduleObject.storeid +'&type=username_single&source=gab', 800, 500, delegatesFromABCallBack, false, windowData);
