@@ -62,6 +62,7 @@ function freebusymodule(startTime)
 	this.zoom = 1;
 	this.freezeScrollbar = false;
 	this.pickerDisabled = false;
+	this.hasResource = false;
 
 	var endDtp = new DateTimePicker(dhtml.getElementById("fbenddate"),_("End time"));
 	var startDtp = new DateTimePicker(dhtml.getElementById("fbstartdate"),_("Start time"));
@@ -79,6 +80,10 @@ function freebusymodule(startTime)
 	this.startViewDate.setMinutes(0);
 	this.startViewDate.setSeconds(0);
 	this.startViewDate = new Date(this.startViewDate.getTime()-ONE_DAY*this.daysBefore);
+
+	// This flag is set when fb_module is initialized for the first time, so that we can keep the track
+	// of wheather we can change the resource recipient when we switch between view while create meetings
+	this.autoChangeResourceRecipient = true;
 }
 
 freebusymodule.prototype.dtpOnchange = function()
@@ -197,8 +202,7 @@ freebusymodule.prototype.initView = function(zoom,user,recips)
 			}
 			user = new Array();
 			// if any user is organiser then not add him in userList as he is already added as c_user.
-			if (((parseInt(recips[i]["recipient_flags"],10) & recipOrganizer) != recipOrganizer)
-				&& recips[i]['fullname'] != this.user) {
+			if (((parseInt(recips[i]["recipient_flags"],10) & recipOrganizer) != recipOrganizer)){
 				user['resolvename'] = recips[i]['fullname'];
 				user['recipienttype'] = recips[i]['recipienttype'];
 				user['recipient_flags'] = recips[i]['recipient_flags'];
@@ -266,9 +270,17 @@ freebusymodule.prototype.addBusyInfo = function(inputUserList)
 			this.userList[clientuser]["entryid"] =      dhtml.getTextNode(inputUserList[i].getElementsByTagName("entryid")[0],"");
 			this.userList[clientuser]["username"] =     dhtml.getTextNode(inputUserList[i].getElementsByTagName("username")[0],"");
 			this.userList[clientuser]["emailaddress"] = dhtml.getTextNode(inputUserList[i].getElementsByTagName("email")[0], this.userList[clientuser]["emailaddress"]);
-			// only set this property when we are adding user for the first time
-			if(typeof this.userList[clientuser] != "undefined" && typeof this.userList[clientuser]["recipienttype"] == "undefined") {
-				this.userList[clientuser]["recipienttype"] = parseInt(dhtml.getXMLValue(inputUserList[i], "recipienttype"), 10);
+			//set this when we are adding user for the first time
+			if(!this.autoChangeResourceRecipient){
+				if(typeof this.userList[clientuser] != "undefined" && typeof this.userList[clientuser]["recipienttype"] == "undefined") {
+					this.userList[clientuser]["recipienttype"] = parseInt(dhtml.getXMLValue(inputUserList[i], "recipienttype"), 10);
+				}
+			}else{//validate recipient from server data
+				if(typeof this.userList[clientuser] != "undefined" &&  this.userList[clientuser]["objecttype"] && typeof (dhtml.getXMLValue(inputUserList[i], "recipienttype")) != "undefined") {
+					this.userList[clientuser]["recipienttype"] = parseInt(dhtml.getXMLValue(inputUserList[i], "recipienttype"), 10);
+				}else{
+					this.userList[clientuser]["recipienttype"] = MAPI_TO;
+				}
 			}
 
 			//put the items in the "userList"
@@ -848,6 +860,20 @@ freebusymodule.prototype.getEndMeetingTime = function()
 	return this.dtp.getEndValue();
 }
 
+/**
+ * Use this function to get the resource
+ * @return string location
+ */
+freebusymodule.prototype.getResource = function()
+{	
+	for(var userid in this.userList){
+		if(this.userList[userid].recipienttype == MAPI_BCC){
+			this.hasResource = true;
+			return this.userList[userid].fullname;
+		}
+	}
+}
+
 /**
  * Function will return the selected users
  * @return Array[]->entryid
