@@ -67,6 +67,8 @@ hierarchymodule.prototype.init = function(id, element)
 	this.openedFolders = new Object();
 	this.getOpenedFolders();
 	this.selectedFolder = false;
+	// this flag is set when selected folder is same as selectedContextFolder
+	this.selectedFolderFlag = false;
 
 	this.folderIndex = 0;
 	this.folderEvents = new Object();
@@ -269,10 +271,13 @@ hierarchymodule.prototype.execute = function(type, action)
 							if(folderobject["parent_entryid"] != changedFolder["parent_entryid"]) {
 								// selected parentFolder
 								var parentFolder = dhtml.getElementById(this.stores[i].tree.getNode(dhtml.getTextNode(entryid,"")).parentid);
+								this.selectedFolderFlag = (this.selectedFolder == this.selectedContextFolder)? false : true; 
 								if(parentFolder){
 									parentFolder = parentFolder.childNodes[1];
 									eventHierarchySelectFolder(this, parentFolder, false);
-									eventHierarchyChangeFolder(this, parentFolder, false);
+									//change folder if the selected folder is not same as parent folder of deleted folder
+									if(!this.selectedFolderFlag)
+										eventHierarchyChangeFolder(this, parentFolder, false);
 								}
 								changeType = "move";
 							}
@@ -660,7 +665,12 @@ hierarchymodule.prototype.changeFolder = function(treeObject, type, folder)
 					}
 				}else if (Number(folder["content_unread"]) > 0){
 					node["extra"] = new Object();
-					node["extra"]["class"] = "unread_count";
+					// if selected folder is updated with unread count we have to 
+					// set the correct font color while building the hierarchy tree.
+					if(compareEntryIds(this.selectedFolder, node["id"]))
+						node["extra"]["class"] = "selectedfolder_unread_count" ;
+					else
+						node["extra"]["class"] = "unread_count" ;
 					node["extra"]["text"] = "("+folder["content_unread"]+")";
 				}
 				
@@ -793,6 +803,7 @@ hierarchymodule.prototype.deleteFolder = function(folder)
 		folder = this.getFolder(this.selectedFolder);
 	}
 
+
 	if(folder) {
 		if(confirm(_("Are you sure you want to delete") + " " + folder["display_name"] + '?')) {
 			var data = new Object();
@@ -909,7 +920,7 @@ hierarchymodule.prototype.getStore = function(entryid)
 	for(var i = 0; i < this.stores.length; i++) {
 		/**
 		 * Opened delegate folders have storeids like storeid_calendar,
-		 * storeid_contact etc., so remove that string part from the storeid.
+		 * [STOREID]_contact etc., so remove that string part from the storeid.
 		 */
 		var tmpEntryid = this.stores[i].id;
 		tmpEntryid = (tmpEntryid.indexOf('_') > 0) ? tmpEntryid.substr(0, tmpEntryid.indexOf('_')) : tmpEntryid;;
@@ -1069,6 +1080,11 @@ hierarchymodule.prototype.showSharedFolderActions = function()
 {
 	this.sharedFoldersElement.style.display = "block";
 	this.resize(); // TODO: via LayoutManager
+
+	// Set selected folder at the center in hierachy 
+	var openedFolderElement = dhtml.getElementById(this.selectedFolder);
+	if(openedFolderElement)
+		this.contentElement.scrollTop = openedFolderElement.offsetTop - this.contentElement.clientHeight/2;
 }
 
 hierarchymodule.prototype.openSharedFolder = function(username, foldertype, subfolders)
@@ -1199,14 +1215,18 @@ function eventHierarchySelectFolder(moduleObject, element, event)
 		event = new Object();
 	}
 
-	if(event.button == 0 || event.button == 1 || !event.button) {
-		if(moduleObject.selectedFolder) {
+	if(event.button == 0 || event.button == 1 || !event.button && !moduleObject.selectedFolderFlag) {
+		if( moduleObject.selectedFolder){
 			var folder = dhtml.getElementById(moduleObject.selectedFolder);
 			if(folder) {
 				var folderIcon = folder.getElementsByTagName("div")[1];
 				var folderName = folderIcon.getElementsByTagName("span")[0];
 				dhtml.removeClassName(folderName, "folder_title_selected");
 				dhtml.addClassName(folderName, "folder_title");
+				// reset the unread_count font color to default as per theme when a folder is selected
+				dhtml.removeClassName(folderName.getElementsByTagName("span")[0], "selectedfolder_unread_count");
+				dhtml.addClassName(folderName.getElementsByTagName("span")[0], "unread_count");
+
 			}
 		}
 		moduleObject.selectedFolder = element.parentNode.id;
@@ -1214,6 +1234,9 @@ function eventHierarchySelectFolder(moduleObject, element, event)
 		dhtml.removeClassName(folderName, "folder_title");
 		dhtml.removeClassName(folderName, "folder_title_context");
 		dhtml.addClassName(folderName, "folder_title_selected");
+		// this will set the unread_count font color to white, only when a folder is selected
+		dhtml.removeClassName(folderName.getElementsByTagName("span")[0], "unread_count");
+		dhtml.addClassName(folderName.getElementsByTagName("span")[0], "selectedfolder_unread_count");
 	}
 }
 
