@@ -512,7 +512,8 @@ ItemModule.prototype.setBody = function(message, isReply, isConcept, addAsText)
 				content += data[key].label + ":\t" + data[key].value + "\n";
 			}
 		}
-		insertAtCursor(html_body, content);
+		if(html_body)
+			insertAtCursor(html_body, content);
 	}
 }
 
@@ -834,325 +835,6 @@ ItemModule.prototype.createMailTemplate= function(message, htmlFormat)
 	return result;
 }
 
-/**
- * Function which build the appointment template with labels and value 
- * @param object message the action tag  
- * @param boolean htmlFormat tells wheather build content is HTML format or not
- * @return object result contains all the values.
- */ 
-ItemModule.prototype.createAppointmentTemplate= function(message, htmlFormat)
-{
-	var properties = getAppointmentProperties();
-	var result = new Object;
-	for(var tagName in properties)
-	{
-		var xmlValue = dhtml.getXMLValue(message, tagName, -1);
-		if(xmlValue !== -1){
-			switch(tagName){
-				case "busystatus":
-					switch(parseInt(xmlValue, 10))
-					{
-						case fbFree:
-							xmlValue = _("Free");
-							break;
-						case fbTentative:
-							xmlValue = _("Tentative");
-							break;
-						case fbBusy:
-							xmlValue = _("Busy");
-							break;
-						case fbOutOfOffice:
-							xmlValue = _("Out of Office");
-							break;
-						default:
-							xmlValue = NBSP;
-							break;
-					}
-					break;
-				case "importance":
-					switch(parseInt(xmlValue, 10)) {
-						case IMPORTANCE_LOW:
-							xmlValue = _("Low");
-							break;
-						case IMPORTANCE_HIGH:
-							xmlValue = _("High");
-							break;
-						case IMPORTANCE_NORMAL:
-						default:
-							xmlValue = NBSP;
-							break;
-						}
-					break;
-				case "meeting":
-					// first check that we are really dealing with a meeting and not an appointment
-					var meetingStatus = parseInt(xmlValue, 10);
-					if(!isNaN(meetingStatus) && meetingStatus !== olNonMeeting) {
-						var responseStatus = parseInt(dhtml.getXMLValue(message, "responsestatus", olResponseNone), 10);
-						switch(responseStatus)
-						{
-							case olResponseNone:
-								xmlValue = _("No Response");
-								break;
-							case olResponseOrganized:
-								xmlValue = _("Meeting Organizer");
-								break;
-							case olResponseTentative:
-								xmlValue = _("Tentative");
-								break;
-							case olResponseAccepted:
-								xmlValue = _("Accepted");
-								break;
-							case olResponseDeclined:
-								xmlValue = _("Declined");
-								break;
-							case olResponseNotResponded:
-								xmlValue = _("Not Yet Responded");
-								break;
-						}
-						result["required_attendee"] = new Object;
-						result["required_attendee"].label = _("Required Attendee");
-						result["required_attendee"].value = this.generateRecipientStringFromXML(message, "to");
-
-					} else {
-						xmlValue = NBSP;
-					}
-					break;
-				case "recurring":
-					var xmlValue = parseInt(xmlValue, 10);
-					if(!isNaN(xmlValue)) {
-						var recurring_type = parseInt(dhtml.getXMLValue(message, "recur_type"),10);
-						switch(recurring_type)
-						{
-							case olRecursDaily:
-								xmlValue = _("Daily");
-								break;
-							case olRecursWeekly:
-								xmlValue = _("Weekly");
-								break;
-							case olRecursMonthly:
-							case olRecursMonthNth:
-								xmlValue = _("Monthly");
-								break;
-							case olRecursYearly:
-							case olRecursYearNth:
-								xmlValue = _("Yearly");
-								break;
-						}
-
-						var recurring_pattern = dhtml.getXMLValue(message, "recurring_pattern", "");
-						result["recurring_pattern"] = new Object;
-						result["recurring_pattern"].label = _("Recurring Pattern");
-						result["recurring_pattern"].value = recurring_pattern;
-					}else{
-						xmlValue = _("None");
-					}
-					break;
-				case "startdate":
-				case "duedate":
-					xmlValue = strftime(_("%a %x %X"), xmlValue);
-					break;
-			}			
-			// add data in result
-			result[tagName] = new Object;
-			result[tagName].label = properties[tagName];
-			result[tagName].value = xmlValue;
-		}
-	}
-	return result;
-}
-
-/**
- * Function which build the contact template with labels and value 
- * @param object message the action tag  
- * @param boolean htmlFormat tells wheather build content is HTML format or not
- * @return object result contains all the values.
- */ 
-ItemModule.prototype.createContactTemplate= function(message, htmlFormat)
-{
-	var properties = getContactProperties();
-	var result = new Object;
-	for(var tagName in properties)
-	{
-		var xmlValue = dhtml.getXMLValue(message, tagName, -1);
-		if(xmlValue !== -1){
-			switch(tagName){
-				case "birthday":
-				case "wedding_anniversary":
-					xmlValue = strftime(_("%a %x %X"), xmlValue);
-					break;
-			}
-			// add data in result
-			result[tagName] = new Object;
-			result[tagName].label = properties[tagName];
-			result[tagName].value = xmlValue;
-		}
-	}
-	return result;
-}
-
-
-/**
- * Function which build the stickyNote template with labels and value 
- * @param object message the action tag  
- * @param boolean htmlFormat tells wheather build content is HTML format or not
- * @return object result contains all the values.
- */  
-ItemModule.prototype.createStickyNoteTemplate= function(message, htmlFormat)
-{
-	var result = new Object;
-		// add data in result
-		result["body"] = new Object;
-		result["body"].label = _("Body");
-		result["body"].value = dhtml.getXMLValue(message, "body", "");
-	
-	return result;
-}
-
-
-/**
- * Function which build the task template with labels and value 
- * @param object message the action tag  
- * @param boolean htmlFormat tells wheather build content is HTML format or not
- * @return object result contains all the values.
- */ 
-ItemModule.prototype.createTaskTemplate= function(message, htmlFormat)
-{
-	var properties = getTaskProperties();
-	var result = new Object;
-	for(var tagName in properties)
-	{
-		var xmlValue = dhtml.getXMLValue(message, tagName, -1);
-		if(xmlValue !== -1){
-			switch(tagName){
-				case "startdate":
-				case "duedate":
-				case "datecompleted":
-					xmlValue = strftime(_("%a %x"), xmlValue);
-					break;
-				case "totalwork":
-				case "actualwork":
-					xmlValue = (parseInt(xmlValue, 10)/60)+ "hours";
-					break;
-				case "status":
-					switch(xmlValue)
-					{
-						case olTaskNotStarted:
-							xmlValue = _("Not Started");
-							break;
-						case olTaskInProgress:
-							xmlValue = _("In Progress");
-							break;
-						case olTaskComplete:
-							xmlValue = _("Complete");
-							break;
-						case olTaskWaiting:
-							xmlValue = _("Waiting");
-							break;
-						case olTaskDeferred:
-							xmlValue = _("Deferred");
-							break;
-					}
-					break;
-				case "percent_complete":
-					xmlValue = xmlValue *100 +"%";
-					break;
-			}
-			// add data in result
-			result[tagName] = new Object;
-			result[tagName].label = properties[tagName];
-			result[tagName].value = xmlValue;
-		}
-	}
-	return result;
-}
-
-/**
- * Function which build the mail template with labels and value 
- * @param object message the action tag  
- * @param boolean htmlFormat tells wheather build content is HTML format or not
- * @return object result contains all the values.
- */ 
-ItemModule.prototype.createMailTemplate= function(message, htmlFormat)
-{
-	var properties = getMailProperties();
-	var result = new Object;
-	for(var tagName in properties)
-	{
-		var xmlValue = dhtml.getXMLValue(message, tagName, -1);
-		if(xmlValue !== -1){
-			switch(tagName){
-				case "message_delivery_time":
-					xmlValue = strftime(_("%a %x %X"), xmlValue);
-					break;
-				case "sent_representing_email_address":
-					xmlValue = nameAndEmailToString(dhtml.getXMLValue(message, "sent_representing_name", ""), xmlValue, MAPI_MAILUSER , htmlFormat);;
-					break;
-				case "attachment":
-					xmlValue = this.generateAttachmentStringFromXML(message);
-					break;
-				case "body":
-					var isHTML = dhtml.getXMLValue(message, "isHTML", false);
-					var content = xmlValue;
-					// HTML reply with a HTML email
-					if(isHTML && htmlFormat){
-						// Get index of the start of the body content
-						var bodyOpenIndex = content.search(/<body/gi);
-						if(bodyOpenIndex > 0){
-							// Fetch index after body tag
-							bodyOpenIndex = content.indexOf(">", bodyOpenIndex) + 1;
-						}else{
-							bodyOpenIndex = 0;
-						}
-						// Get index of the end of the body content
-						var bodyCloseIndex = content.search(/<\/body/gi);
-						if(bodyCloseIndex == -1){
-							bodyCloseIndex = content.length;
-						}
-						// Extract body content
-						content = content.slice(bodyOpenIndex, bodyCloseIndex);
-
-						// Remove some more tags
-						content = removeTagFromSource(content, "head", true, true);
-						content = removeTagFromSource(content, "style", true);
-						content = removeTagFromSource(content, "script", false);
-						content = removeTagFromSource(content, "title", true);
-						content = removeTagFromSource(content, "meta", false);
-						content = removeTagFromSource(content, "base", false);
-						content = removeTagFromSource(content, "link", false);
-
-						// HACK: Remove newlines to fix HTML
-						content = content.replace(/\n/g, " ");
-						content = content.replace(/\r/g, " ");
-					}
-
-					if (!isHTML && htmlFormat){
-						// please note that currently all replies and forwards are plain text!
-						content = content.replace(/&/g, "&amp;");
-						content = content.replace(/</g, "&lt;");
-						content = content.replace(/>/g, "&gt;");
-						content = content.replace(/ {2}/g, " &nbsp;");
-					}
-					xmlValue = content;
-					break;
-			}
-			var recipients = this.generateRecipientStringFromXML(message, false, htmlFormat);
-			if (recipients){
-				for(var type in recipients){
-					result[type] = new Object;
-					result[type].label = type;
-					result[type].value = recipients[type];
-				}
-			}
-
-			// add data in result
-			result[tagName] = new Object;
-			result[tagName].label = properties[tagName];
-			result[tagName].value = xmlValue;
-		}
-	}
-	return result;
-}
-
 /**
  * Function which sets the From field
  * @param object message the action tag  
@@ -1209,6 +891,7 @@ ItemModule.prototype.setData = function(storeid, parententryid)
 ItemModule.prototype.open = function(entryid, rootentryid, attachNum)
 {
 	if(entryid) {
+		entryid = (entryid.indexOf('_') > 0) ? entryid.substr(0, entryid.indexOf('_')) : entryid;
 		this.messageentryid = entryid;
 		
 		if(rootentryid) {
@@ -1343,7 +1026,7 @@ ItemModule.prototype.setRecipients = function(message, actionType)
 		for(var i = 0; i < recipients.length; i++)
 		{
 			var recipient = recipients[i];
-			if(dhtml.getXMLValue(recipient, "pr_recipient_flags", false)!= 3){
+			if(dhtml.getXMLValue(recipient, "recipient_flags", false)!= 3){
 				var display_name = dhtml.getXMLValue(recipient, "display_name", "");
 				var email_address = dhtml.getXMLValue(recipient, "email_address", "").toLowerCase();
 				var type = dhtml.getXMLValue(recipient, "type", "");
@@ -1352,13 +1035,13 @@ ItemModule.prototype.setRecipients = function(message, actionType)
 
 				if (!(actionType && actionType == "replyall" && compareEntryIds(entryid,webclient.userEntryid))){
 					if(type && email_address) {
-					    if(typeof(elemdata[type]) == "undefined") elemdata[type] = new Array();
-
-                        elemdata[type].push(nameAndEmailToString(display_name,email_address,objecttype,false));
+						if(typeof(elemdata[type]) == "undefined") elemdata[type] = new Array();
+						elemdata[type].push(nameAndEmailToString(display_name,email_address,objecttype,false));
 					} else if(type && display_name) {
 						// if unresolved email address
 						var element = dhtml.getElementById(type);
 						if(element){
+							if(typeof(elemdata[type]) == "undefined") elemdata[type] = new Array();
 							elemdata[type].push(display_name);
 						}
 					}
@@ -1366,9 +1049,11 @@ ItemModule.prototype.setRecipients = function(message, actionType)
 			}else{
 				this.owner = new Object;
 				this.owner["display_name"] = dhtml.getXMLValue(recipient, "display_name", false);
+				this.owner["fullname"] = dhtml.getXMLValue(recipient, "display_name", false);
 				this.owner["email_address"] = dhtml.getXMLValue(recipient, "email_address", false);
 				this.owner["type"] = dhtml.getXMLValue(recipient, "type", false);
-				this.owner["recipienttype"] = dhtml.getXMLValue(recipient, "entryid", false);
+				this.owner["entryid"] = dhtml.getXMLValue(recipient, "entryid", false);
+				this.owner["recipienttype"] = dhtml.getXMLValue(recipient, "recipienttype", false);
 				this.owner["recipient_flags"] = dhtml.getXMLValue(recipient, "recipient_flags", 1);
 			}
 		}
@@ -1470,13 +1155,13 @@ ItemModule.prototype.sendDeclineTaskRequest = function()
 ItemModule.prototype.sendAcceptMeetingRequest = function(tentative, noResponse, basedate, body)
 {
 	// Adding human readable body text that holds the start/duedate and location information.
-	body = this.addMeetingTimeInfoToBody(body, this.itemProps['startdate'], this.itemProps['duedate'], this.itemProps['location']);
+	var meetingTimeInfo = this.addMeetingTimeInfoToBody(body, this.itemProps['startdate'], this.itemProps['duedate'], this.itemProps['location']);
 
 	var req = new Object;
 	req['entryid'] = this.messageentryid;
 	req['store'] = this.storeid;
 	req['tentative'] = tentative;
-	req['body'] = body;
+	req['meetingTimeInfo'] = meetingTimeInfo;
 
 	if (typeof basedate != 'undefined' && basedate !== "false" && basedate)
 		req['basedate'] = basedate;
@@ -1500,7 +1185,7 @@ ItemModule.prototype.sendAcceptMeetingRequest = function(tentative, noResponse,
 ItemModule.prototype.sendProposalMeetingRequest = function(start, end, body, basedate)
 {
 	// Adding the newly proposed time information to the body.
-	body += "\n\n\n-----------\n" + _("New Meeting Time Proposed") + " :\n" +
+	var meetingTimeInfo = body + "\n\n\n-----------\n" + _("New Meeting Time Proposed") + " :\n" +
 					strftime(_("%A, %B %e, %Y %H:%M"), start) + " - " +
 					strftime(_("%A, %B %e, %Y %H:%M"), end);
 
@@ -1516,7 +1201,7 @@ ItemModule.prototype.sendProposalMeetingRequest = function(start, end, body, bas
 	req['proposed_endtime'] = end;
 	req['proposed_duration'] = 1;
 	req['counter_proposal'] = true;
-	req['body'] = (body)?body:null;
+	req['meetingTimeInfo'] = (meetingTimeInfo)?meetingTimeInfo:null;
 
 	if (typeof basedate != 'undefined' && basedate)
 		req['basedate'] = basedate;
@@ -1534,12 +1219,12 @@ ItemModule.prototype.sendProposalMeetingRequest = function(start, end, body, bas
 ItemModule.prototype.sendDeclineMeetingRequest = function(noResponse, basedate, body)
 {
 	// Adding human readable body text that holds the start/duedate and location information.
-	body = this.addMeetingTimeInfoToBody(body, this.itemProps['startdate'], this.itemProps['duedate'], this.itemProps['location']);
+	var meetingTimeInfo = this.addMeetingTimeInfoToBody(body, this.itemProps['startdate'], this.itemProps['duedate'], this.itemProps['location']);
 
 	var req = new Object;
 	req['entryid'] = this.messageentryid;
 	req['store'] = this.storeid;
-	req['body'] = body;
+	req['meetingTimeInfo'] = meetingTimeInfo;
 
 	if (typeof basedate != 'undefined' && basedate !== "false" && basedate)
 		req['basedate'] = basedate;
@@ -1569,19 +1254,19 @@ ItemModule.prototype.sendDeclineMeetingRequest = function(noResponse, basedate,
  */
 ItemModule.prototype.addMeetingTimeInfoToBody = function(msg_body, start, due, location, recurring_pattern){
 	location = location || "";
-	var body = _("When") + ": ";
+	var meetingTimeInfo = _("When") + ": ";
 	
 	if (recurring_pattern) {
-		body += recurring_pattern + "\n";
+		meetingTimeInfo += recurring_pattern + "\n";
 	} else {
-		body += strftime(_("%A, %B %e, %Y %H:%M"), start) + " - ";
-		body += strftime(_("%A, %B %e, %Y %H:%M"), due) + "\n";
+		meetingTimeInfo += strftime(_("%A, %B %e, %Y %H:%M"), start) + " - ";
+		meetingTimeInfo += strftime(_("%A, %B %e, %Y %H:%M"), due) + "\n";
 	}
 
-	body += _("Where") + ": "  + location + "\n\n";
-	body += "*~*~*~*~*~*~*~*~*~*\n\n" + (msg_body||"");
+	meetingTimeInfo += _("Where") + ": "  + location + "\n\n";
+	meetingTimeInfo += "*~*~*~*~*~*~*~*~*~*\n\n" + (msg_body||"");
 
-	return body;
+	return meetingTimeInfo;
 }
 
 
