@@ -68,9 +68,11 @@ maillistmodule.prototype.init = function(id, element, title, data)
 	this.menuItems.push(webclient.menu.createMenuItem("forward", _("Forward"), _("Forward"), eventMailListForwardMessage));
 	this.menuItems.push(webclient.menu.createMenuItem("seperator", ""));
 	this.menuItems.push(webclient.menu.createMenuItem("search", _("Search"), _("Quick Search"), eventMailListSearchBar, "S", true));
-	this.menuItems.push(webclient.menu.createMenuItem("seperator", ""));
-	this.menuItems.push(webclient.menu.createMenuItem("rules", _("Rules"), _("Edit e-mail rules"), eventMailListRules));
-
+	//check weather selected folder is public; if so don't display rules options
+	if(typeof data["storeid"] != "undefined" && !webclient.hierarchy.isPublicStore(data["storeid"])) {
+		this.menuItems.push(webclient.menu.createMenuItem("seperator", ""));
+		this.menuItems.push(webclient.menu.createMenuItem("rules", _("Rules"), _("Edit e-mail rules"), eventMailListRules));
+	}
 	this.menuItems.push(webclient.menu.createMenuItem("seperator", ""));
 	this.menuItems.push(webclient.menu.createMenuItem("send_receive", _("Send/Receive"), _("Send or Receive mails") , eventSendReceiveItems));
 
@@ -78,6 +80,7 @@ maillistmodule.prototype.init = function(id, element, title, data)
 	
 	var items = new Array();
 	items.push(webclient.menu.createMenuItem("open", _("Open"), false, eventListContextMenuOpenMessage));
+	items.push(webclient.menu.createMenuItem("save_email", _("Save Email As a File"), false, eventListContextMenuSaveEmailMessage));
 	items.push(webclient.menu.createMenuItem("print", _("Print"), false, eventListContextMenuPrintMessage));
 	items.push(webclient.menu.createMenuItem("edit", _("Edit as New Message"), false, eventListContextMenuEditMessage));
 	items.push(webclient.menu.createMenuItem("seperator", ""));
@@ -88,8 +91,7 @@ maillistmodule.prototype.init = function(id, element, title, data)
 	items.push(webclient.menu.createMenuItem("markread", _("Mark Read"), false, eventMailListContextMenuMessageFlag));
 	items.push(webclient.menu.createMenuItem("markunread", _("Mark Unread"), false, eventMailListContextMenuMessageFlag));
 	items.push(webclient.menu.createMenuItem("categories", _("Categories")+"...", false, eventListContextMenuCategoriesMessage));
-	/* Disable Attach Item
-	items.push(webclient.menu.createMenuItem("forward_items", _("Forward Items"), false, eventListContextMenuForwardMultipleItems)); */
+	items.push(webclient.menu.createMenuItem("forward_items", _("Forward Items"), false, eventListContextMenuForwardMultipleItems));
 	items.push(webclient.menu.createMenuItem("seperator", ""));
 	items.push(webclient.menu.createMenuItem("flag_status_red", _("Red Flag"), false, eventMailListContextMenuRedFlag));
 	items.push(webclient.menu.createMenuItem("flag_status_complete", _("Flag Complete"), false, eventMailListContextMenuFlagComplete));
@@ -99,7 +101,7 @@ maillistmodule.prototype.init = function(id, element, title, data)
 	items.push(webclient.menu.createMenuItem("delete", _("Delete"), false, eventListContextMenuDeleteMessage));
 	//items.push(webclient.menu.createMenuItem("copy", _("Copy/Move Message"), false, eventListContextMenuCopyMessage));
 	items.push(webclient.menu.createMenuItem("seperator", ""));
-	items.push(webclient.menu.createMenuItem("task", _("Convert to Task"), false, eventListContextMenuTask));
+	items.push(webclient.menu.createMenuItem("task", _("Create a task from email"), false, eventListContextMenuTask));
 	items.push(webclient.menu.createMenuItem("seperator", ""));
 	items.push(webclient.menu.createMenuItem("options", _("Options")+"...", false, eventListContextMenuMessageOptions));
 
@@ -209,12 +211,12 @@ maillistmodule.prototype.convertSelectedMeetingItem = function(action)
 		//show an error message for dragged meeting requests which do not have correct privileges set
 		if(messageClass == "IPM.Schedule.Meeting.Request"){
 			if(delegator){
-				alert(_("Cannot copy this item. Cannot open calendar for user %s Access Denied.").sprintf(delegator));
+				alert(_("Cannot copy this item. Cannot open calendar for user %s: Access Denied.").sprintf(delegator));
 			}else if(meetingType){
-				alert(_("You received a more recent update to this meeting. This meeting request is out of date. You cannot respond this request"));
+				alert(_("You received a more recent update to this meeting. This meeting request is out of date. You cannot respond this request."));
 			}else if(responseStatus == olResponseNotResponded){
 				this.sendConfirmationAcceptFromMailList(entryid);
-				alert(_("The meeting has been accepted and moved to your calendar. A response has been sent to the meeting organiser"));
+				alert(_("The meeting has been accepted and moved to your calendar. A response has been sent to the meeting organiser."));
 			}
 
 		}else{
@@ -428,7 +430,7 @@ maillistmodule.prototype.initSearchBar = function()
 	(dhtml.addElement(filterTarget, "option", false, false,_("Sender"))).value = "sender_name sender_email sent_representing_name sent_representing_email";
 	(dhtml.addElement(filterTarget, "option", false, false,_("Body"))).value = "body";
 	(dhtml.addElement(filterTarget, "option", false, false,_("Subject or Sender"))).value = "subject sender_name sender_email sent_representing_name sent_representing_email";
-	(dhtml.addElement(filterTarget, "option", false, false,_("To or cc"))).value = "to cc";
+	(dhtml.addElement(filterTarget, "option", false, false,_("To or Cc"))).value = "to cc";
 
 	var defaultTarget = webclient.settings.get("folders/entryid_"+this.entryid+"/searchbar/target", "0");
 	filterTarget.selectedIndex = defaultTarget;
@@ -467,7 +469,7 @@ maillistmodule.prototype.initSearchBar = function()
 	dhtml.addEvent(this, searchFilterInputBox, "blur", eventMailListSearchBarFilterFocus);
 	dhtml.addEvent(this, searchFilterInputBox, "keydown", eventMailListSearchBarFilterKey);
 	dhtml.addEvent(this, searchFilterInputBox, "selectstart", eventMailListSearchBarFilterMouseMove);
-	dhtml.addEvent(this, filterTarget, "mousedown", function(){event.stopPropagation()});
+	dhtml.addEvent(this, filterTarget, "mousedown", function(module,element,event){event.stopPropagation()});
 
 	this.searchBarContainer.appendChild(searchFilterInputBox);
 	this.searchBarContainer.searchFilterInputBox = searchFilterInputBox; // add reference to DOM
@@ -586,6 +588,34 @@ function eventMailListForwardMessage(moduleObject, element, event)
 	}
 }
 
+/**
+ * Sends request to server to download email in '.eml' format.
+ * @param moduleObject object maillist module object
+ * @param element object HTML element object on which event is fired
+ * @param event object event type object
+ */
+function eventListContextMenuSaveEmailMessage(moduleObject, element, event)
+{
+	// Hide Context menu.
+	if (element && element.parentNode)
+		element.parentNode.style.display = "none";
+
+	/**
+	 * Get selected Message's entryid and pass it to server and
+	 * set 'emailAsAttachment' option to true to save email.
+	 * This will save email in eml format.
+	 */
+	var selectedMessage = moduleObject.getSelectedMessages();
+	var messegeEntryId = moduleObject.entryids[selectedMessage[0]];
+	var action = webclient.base_url + "index.php?load=download_message&fileType=eml&store=" + moduleObject.storeid + "&entryid=" + messegeEntryId;
+
+	var iframe = dhtml.getElementById("iframedownload");
+
+	// Open download attahcment dialog.
+	if (!iframe) iframe = dhtml.addElement(document.body, "iframe", "iframeDownload", "iframedownload");
+	iframe.contentWindow.location = action;
+}
+
 function eventMailListContextMenuReply(moduleObject, element, event)
 {
 	element.parentNode.style.display = "none";
