@@ -110,11 +110,11 @@ previewreadmailitemmodule.prototype.initializeView = function()
 	var meetingrequestData = "<div id='meetingrequest_data'>";
 	meetingrequestData += "<table border='0' cellpadding='0' cellspacing='0'>";
 	meetingrequestData += "	<tr id='meetingrequest_data_startdate_row'>";
-	meetingrequestData += "		<td class='property' width='40' nowrap>" + _("Startdate") + ": </td>";
+	meetingrequestData += "		<td class='property' width='40' nowrap>" + _("Start date") + ": </td>";
 	meetingrequestData += "		<td><div id='meetingrequest_startdate' class='property_data'></div></td>";
 	meetingrequestData += "	</tr>";
 	meetingrequestData += "	<tr id='meetingrequest_data_duedate_row'>";
-	meetingrequestData += "		<td class='property' width='40' nowrap>" + _("Enddate") + ": </td>";
+	meetingrequestData += "		<td class='property' width='40' nowrap>" + _("End date") + ": </td>";
 	meetingrequestData += "		<td><div id='meetingrequest_duedate' class='property_data'></div></td>";
 	meetingrequestData += "	</tr>";
 	meetingrequestData += "	<tr id='meetingrequest_data_when_row'>";
@@ -176,12 +176,12 @@ previewreadmailitemmodule.prototype.initializeView = function()
 		this.element.innerHTML += "<iframe id='html_body' frameborder='0'></iframe>";
 	}	
 
-	accept = dhtml.addElement(dhtml.getElementById("meetingrequest"), "span", "menubutton icon icon_accept", "accept", _("Accept"));
-	tentative = dhtml.addElement(dhtml.getElementById("meetingrequest"), "span", "menubutton icon icon_tentative" , "tentative", _("Tentative"));
-	decline = dhtml.addElement(dhtml.getElementById("meetingrequest"), "span", "menubutton icon icon_decline" , "decline", _("Decline"));
-	removefromcalendar = dhtml.addElement(dhtml.getElementById("meetingrequest"), "span", "menubutton icon icon_removefromcalendar" , "removefromcalendar", _("Remove from calendar"));
-	proposenewtime = dhtml.addElement(dhtml.getElementById("meetingrequest"), "span", "menubutton icon icon_proposenewtime" , "proposenewtime", _("Propose New Time"));
-	notcurrent = dhtml.addElement(dhtml.getElementById("meetingrequest"), "span", "menubutton icon icon_not_current", "notcurrent", _("Not Current"));
+	var accept = dhtml.addElement(dhtml.getElementById("meetingrequest"), "span", "menubutton icon icon_accept", "accept", _("Accept"));
+	var tentative = dhtml.addElement(dhtml.getElementById("meetingrequest"), "span", "menubutton icon icon_tentative" , "tentative", _("Tentative"));
+	var decline = dhtml.addElement(dhtml.getElementById("meetingrequest"), "span", "menubutton icon icon_decline" , "decline", _("Decline"));
+	var removefromcalendar = dhtml.addElement(dhtml.getElementById("meetingrequest"), "span", "menubutton icon icon_removefromcalendar" , "removefromcalendar", _("Remove from Calendar"));
+	var proposenewtime = dhtml.addElement(dhtml.getElementById("meetingrequest"), "span", "menubutton icon icon_proposenewtime" , "proposenewtime", _("Propose New Time"));
+	var notcurrent = dhtml.addElement(dhtml.getElementById("meetingrequest"), "span", "menubutton icon icon_not_current", "notcurrent", _("Not Current"));
 	
 	dhtml.addEvent(this, accept, "click", eventPreviewItemAcceptClick);
 	dhtml.addEvent(this, tentative, "click", eventPreviewItemTentativeClick);
@@ -322,6 +322,11 @@ previewreadmailitemmodule.prototype.item = function(action)
 					
 					var textMeetingResponseText = _("This meeting request was updated after this message was sent. You should open the latest update or open the item from the calendar.");
 					this.showextrainfo(textMeetingResponseText, true);
+				} else if(dhtml.getXMLValue(action, 'sent_representing_email_address', "").trim() == dhtml.getXMLValue(action, 'received_by_email_address', "").trim()){
+					//If the meeting is created and organiser is set as attendee, inbox of the organizer do not require meeting request bar in the response msg
+					dhtml.getElementById("meetingrequest").style.display = "none";
+					
+					this.showextrainfo(_("As the meeting organizer, you do not need to respond to the meeting"));
 				} else {
 					dhtml.getElementById("notcurrent").style.display = "none";
 				}
@@ -538,9 +543,17 @@ previewreadmailitemmodule.prototype.setReadFlag = function(flag)
 	// prevent request if message was already marked as read
 	if ((this.itemMessageFlags & MSGFLAG_READ) != MSGFLAG_READ){
 		var data = new Object();
-		data["store"] = this.storeid;
-		data["parententryid"] = this.parententryid;
-		data["entryid"] = this.messageentryid;
+
+		// Since we are directly opening task item from Task folder in previewpane, we need to access taskrequest entry ids here.
+		if (typeof this.itemProps.taskrequest != "undefined") {
+			data["store"] = this.itemProps.taskrequest.storeid;
+			data["parententryid"] = this.itemProps.taskrequest.parententryid;
+			data["entryid"] = this.itemProps.taskrequest.entryid;
+		} else {
+			data["store"] = this.storeid;
+			data["parententryid"] = this.parententryid;
+			data["entryid"] = this.messageentryid;
+		}
 
 		if(flag) {
 			data["flag"] = flag;
@@ -593,20 +606,6 @@ previewreadmailitemmodule.prototype.sendReadReceipt = function()
 	return result;
 }
 
-/**
- * Function will show an error message returned by server.
- * @param XMLNode action the action tag
- */
-previewreadmailitemmodule.prototype.handleError = function(action)
-{
-	// show error message to user
-	var errorMessage = dhtml.getXMLValue(action, "message", false);
-
-	if(errorMessage) {
-		alert(errorMessage);
-	}
-}
-
 function eventPreviewLoaded(moduleID)
 {
 	// Remove contextmenu and other elements onmousedown and onscroll in iFrame.
@@ -703,8 +702,8 @@ function eventPreviewItemProposeNewTimeClick(moduleObject, element, event)
 	webclient.openModalDialog(-1, 'previewreadmailitem_proposenewtimedialog', DIALOG_URL+'task=advprompt_modal', 325,250, previewreadmailitemProposenewtime_dialog_callback, {
 			moduleObject: moduleObject
 		}, {
-			windowname: _("Propose new time"),
-			dialogtitle: _("Propose new time"),
+			windowname: _("Propose New Time"),
+			dialogtitle: _("Propose New Time"),
 			fields: [{
 				name: "combineddatetimepicker",
 				label_start: _("Start time"),
