@@ -291,6 +291,8 @@ readmailitemmodule.prototype.setMeetingrequest = function(message)
 {
 	var isCounterProposal = (dhtml.getXMLValue(message,"counter_proposal", 0) > 0)?true:false;
 	var isRecurring = (dhtml.getXMLValue(message,"recurring", 0) > 0)?true:false;
+	var sentemailAddress = dhtml.getXMLValue(message, "sent_representing_email_address", "").trim();
+	var receivedemailAddress = dhtml.getXMLValue(message, "received_by_email_address", "").trim();
 	/**
 	 * Message class types:
 	 * - IPM.Schedule.Meeting
@@ -320,6 +322,19 @@ readmailitemmodule.prototype.setMeetingrequest = function(message)
 				var elemExtraInfo = dhtml.getElementById("extrainfo");
 				dhtml.addElement(elemExtraInfo, "p", false, false, textMeetingResponseText);
 				elemExtraInfo.style.display = "block";
+			}else if(sentemailAddress == receivedemailAddress){
+				//Hide accept/ decline/ tentative/ notcurrent buttons when request is out-of-date
+				hideMeetingElements.push("accept");
+				hideMeetingElements.push("tentative");
+				hideMeetingElements.push("decline");
+				hideMeetingElements.push("proposenewtime");
+				hideMeetingElements.push("not_current");
+				
+				//If the meeting is created and organiser is set as attendee, inbox of the organizer do not require meeting request bar in the response msg
+				var textMeetingResponseText = _("As the meeting organizer, you do not need to respond to the meeting");
+				var elemExtraInfo = dhtml.getElementById("extrainfo");
+				dhtml.addElement(elemExtraInfo, "p", false, false, textMeetingResponseText);
+				elemExtraInfo.style.display = "block";
 			} else {
 				hideMeetingElements.push("not_current");
 				
@@ -595,7 +610,7 @@ readmailitemmodule.prototype.openMeeting = function(viewAllProposals){
 		extraParams += "&counterproposal=1";
 		extraParams += "&proposedstartdate="+ this.itemProps.proposed_start_whole;
 		extraParams += "&proposedenddate="+ this.itemProps.proposed_end_whole;
-		if(typeof this.itemProps.appointment.basedate != "undefined") {
+		if(this.itemProps.appointment.basedate != "" && typeof this.itemProps.appointment.basedate != "undefined") {
 			extraParams += "&basedate="+ this.itemProps.appointment.basedate;
 		}
 
