@@ -221,6 +221,7 @@ tasklistmodule.prototype.SubmitMessage = function (moduleObject, element, event)
 			props["status"] = "2";
 			props["complete"] = "1";
 			props["datecompleted"] = parseInt((new Date()).getTime()/1000);
+			props["reminder"] = "0";
 		}else if(percent > 0){
 			props["status"] = "1";
 			props["complete"] = "-1";
@@ -395,7 +396,7 @@ function getProps(element, properties, entryid)
 }
 
 /**
-* functions for spinner buttons of precent_complete field
+* functions for spinner buttons of percent_complete field
 */
 function completeSpinnerUp(text_percent, statusid)
 {		
@@ -443,8 +444,10 @@ function completeSpinnerUp(text_percent, statusid)
 		if (statusElement) {
 			if(percent == 100) {
 				statusElement.value = 2;
+				statusElement.checked = true;
 			} else if(percent < 100 ) {
 				statusElement.value = 1;			
+				statusElement.checked = false;
 			}
 		}
 	}
@@ -495,6 +498,7 @@ function completeSpinnerDown(text_percent,statusid)
 		text_percent_complete.value = percent + "%";
 		
 		if (percent < 100 && statusElement) {
+			statusElement.checked = false;
 			statusElement.value = 0;
 		}
 	}
@@ -562,4 +566,4 @@ function eventTaskListContextMenuMessageAssignTask(moduleObject, element, event)
 	var messages = moduleObject.getSelectedMessages();
 
 	webclient.openWindow(moduleObject, "task", DIALOG_URL+"task=task_standard&storeid=" + moduleObject.storeid +"&parententryid="+ moduleObject.entryid +"&entryid="+ moduleObject.entryids[messages[0]] +"&taskrequest=true");
-}
\ No newline at end of file
+}
