@@ -218,7 +218,7 @@ CalendarDatePickerView.prototype.addList = function(items)
 		var startdate = items[i].getElementsByTagName("startdate")[0];
 		var duedate = items[i].getElementsByTagName("duedate")[0];
 		var entryID = items[i].getElementsByTagName("entryid")[0].firstChild.nodeValue;
-		var subject = (items[i].getElementsByTagName("subject")[0].firstChild?items[i].getElementsByTagName("subject")[0].firstChild.nodeValue:NBSP);
+		var subject = dhtml.getXMLValue(items[i], "subject", NBSP);
 		var busystatus = dhtml.getXMLValue(items[i], "busystatus", 0);
 
 		//here appointments busystatus are checked to highlight the date in datepicker
