@@ -224,13 +224,16 @@ CalendarDayView.prototype.initView = function()
 		for(var j = 0; j < this.numberOfHours; j++){
 			// create the elements for one hour
 			for (var n=0;n<this.numberOfCellsInOneHour;n++){
+				var cellOffsetStartTime = (j*60)+(n*this.cellDefaultTime);
+				var cellOffsetEndTime = cellOffsetStartTime + this.cellDefaultTime;
 				var brightness = "light";
-				if(i==5 || i==6 || j * 60 < workdayStart || j * 60 >= workdayEnd) brightness = "dark";
+				if(i > 4 || cellOffsetEndTime <= workdayStart || cellOffsetEndTime > workdayEnd) brightness = "dark";
+
 				var classPrefix = "top";
 				if(n%this.numberOfCellsInOneHour > 0) classPrefix = "bottom";
 
-				var cellElement = dhtml.addElement(dayElement, "div", classPrefix + brightness, "day_" + i + "_time" + ((j*60)+(n*this.cellDefaultTime)));
-				cellElement.offsetTime = (j*60)+(n*this.cellDefaultTime);
+				var cellElement = dhtml.addElement(dayElement, "div", classPrefix + brightness, "day_" + i + "_time" + cellOffsetStartTime);
+				cellElement.offsetTime = cellOffsetStartTime;
 				cellElement.offsetDay = i;
 				cellElement.style.height = this.cellHeight;
 
@@ -275,7 +278,8 @@ CalendarDayView.prototype.setDayHeaders = function()
 	for(var i = 0; i < days.length; i++) {
 		var date = new Date(this.days[i]);
 		var dayOfWeek = date.getDay();
-		days[i].innerHTML = DAYS_SHORT[dayOfWeek] + " " + date.getDate() + " " + MONTHS_SHORT[date.getMonth()];
+		// Translation string shows "abbreviated day of the week name, day number in the month, abbreviated month name
+		days[i].innerHTML = date.strftime(_("%a %e %h"));
 		// select today in view.
 		var todayCount = (new Date().getDay()== 0) ? 7 : new Date().getDay();
 		if((todayCount-1 == i  && date.isSameDay(new Date())) || (this.data["days"]==1 && date.isSameDay(new Date()))){
@@ -673,8 +677,10 @@ CalendarDayView.prototype.createAppointmentElement = function(daysElement, appoi
 			dhtml.addElement(appointment, "span", "private", false, NBSP);
 		}
 	}
-	if (itemData["reminderSet"] && itemData["reminderSet"].firstChild && itemData["reminderSet"].firstChild.nodeValue == "1"){
+	if (itemData["reminderSet"] == "1"){
 		dhtml.addElement(appointment, "span", "reminder", false, NBSP);
+		appointment.reminderMinutes = itemData["reminderMinutes"];
+		appointment.reminderSet = true;
 	}
 	if(itemData["requestsent"]) {
 		appointment.requestsent = itemData["requestsent"];
@@ -705,7 +711,7 @@ CalendarDayView.prototype.createAppointmentElement = function(daysElement, appoi
 	}
 	
 	if(itemData["subject"] && itemData["subject"].firstChild) {
-		dhtml.addElement(appointment, "span", false, false, itemData["subject"].firstChild.nodeValue);
+		appointment.innerHTML += itemData["subject"].firstChild.nodeValue;
 		appointment.subject = itemData["subject"].firstChild.nodeValue;
 	}else{
 		appointment.innerHTML += "&nbsp;";
@@ -713,7 +719,7 @@ CalendarDayView.prototype.createAppointmentElement = function(daysElement, appoi
 	}
 	
 	if(itemData["location"] && itemData["location"].firstChild) {
-		dhtml.addElement(appointment, "div", false, false, "(" + itemData["location"].firstChild.nodeValue + ")");
+		appointment.innerHTML += " (" + itemData["location"].firstChild.nodeValue + ")";
 		appointment.location = itemData["location"].firstChild.nodeValue;
 	}
 	
@@ -989,6 +995,7 @@ CalendarDayView.prototype.createAllDayItem = function(appointElement, itemData)
 	appointElement.start = startUnixtime;
 	appointElement.end = endUnixtime;
 	appointElement.meetingrequest = itemData["responseStatus"]; // store responseStatus in DOM tree
+	appointElement.requestsent = itemData["requestsent"]; // store requestSent in DOM tree
 
 	//style
 	var className = "ipm_appointment allday_appointment";
@@ -1415,7 +1422,8 @@ CalendarDayView.prototype.fetchDataForApptObjectFromXML = function(item){
 			dataObj["privateAppointment"] = item.getElementsByTagName("private")[0];
 			dataObj["privateSensitivity"] = item.getElementsByTagName("sensitivity")[0];
 			
-			dataObj["reminderSet"] = item.getElementsByTagName("reminder")[0];
+			dataObj["reminderSet"] = dhtml.getXMLValue(item, "reminder");
+			dataObj["reminderMinutes"] = dhtml.getXMLValue(item, "reminder_minutes", "");
 			// get MeetingRequestWasSent property and check that is MR really sent or not.
 			dataObj["requestsent"] = dhtml.getTextNode(item.getElementsByTagName("requestsent")[0]);
 			dataObj["meeting"] = item.getElementsByTagName("meeting")[0];
@@ -1729,17 +1737,18 @@ CalendarDayView.prototype.getStartEndTimeOfSelection = function(contextMenuFlag)
 			var startOffsetTime = elements[0].offsetTime;
 
 			var endOffsetDay = elements[elements.length-1].offsetDay;
-			var endOffsetTime = elements[elements.length-1].offsetTime;
+			var endOffsetTime = elements[elements.length-1].offsetTime + this.cellDefaultTime;
 		}//check if selection on all day timeline then find the required data
 		else{
 			var startOffsetDay = elements[0].offsetDay;
 			var startOffsetTime = 0;
 			
 			var endOffsetDay = parseInt(elements[elements.length-1].offsetDay);
-			var endOffsetTime = (contextMenuFlag) ? 0 : 1410;
+			//as this item is selected from allday timeline so add 1440 minutes to the endTime timestamp 
+			var endOffsetTime = (contextMenuFlag) ? this.cellDefaultTime : 1440;
 		}
 		var starttime = addHoursToUnixTimeStamp(this.days[startOffsetDay]/1000 , (startOffsetTime / 60));
-		var endtime = addHoursToUnixTimeStamp(this.days[endOffsetDay]/1000 , ((endOffsetTime+this.cellDefaultTime) / 60));
+		var endtime = addHoursToUnixTimeStamp(this.days[endOffsetDay]/1000 , (endOffsetTime / 60));
 
 		return [starttime, endtime];
 	}
@@ -1977,7 +1986,7 @@ function eventAppointmentListDragDropTarget(moduleObject, targetElement, element
 	 * If MR was sent to recpients then requestsent attribute (MeetingRequestWasSent Property) is set to '1'
 	 * so if request is not sent to recipients then dont ask to update them while saving MR.
 	 */
-	if(element && element.meetingrequest && element.meetingrequest == "3" && !(element.requestsent && element.requestsent != "1")) { // MR attendee
+	if(element && element.meetingrequest && element.meetingrequest == "3" && element.requestsent && element.requestsent == "1") { // MR attendee
 		if (!confirm(_("You are changing details for a meeting on your calendar while you are not the meeting organizer. If the organizer sends a meeting update, your changes will be lost. Do you want to continue?"))) {
 			moduleObject.list();
 			return;
@@ -2039,10 +2048,14 @@ function eventAppointmentListDragDropTarget(moduleObject, targetElement, element
 	props["parent_entryid"] = moduleObject.entryid;
 	props["entryid"] = moduleObject.entryids[element.id];
 
+	if(!props["entryid"])
+		props["entryid"] = element.id.substr(0,element.id.indexOf("_"));
+
 	if(starttime) {
 		props["startdate"] = parseInt(starttime.getTime()/1000, 10);
 		props["commonstart"] = props["startdate"];
 		props["remindertime"] = props["startdate"];
+		if (element.reminderSet) props["reminder_minutes"] = element.reminderMinutes;
 	} else if(element && element.positionStartTime) {
 		starttime = new Date(element.positionStartTime * 1000);
 		//starttime.setTime(element.positionStartTime * 1000)
@@ -2079,7 +2092,7 @@ function eventAppointmentListDragDropTarget(moduleObject, targetElement, element
 	var moveOccAllowFlag = true;
 	if (element.meetingrequest && parseInt(element.meetingrequest, 10) == 1) { // 1 = olResponseOrganized
 		// Check whether there are any recepients in MR or not.
-		if( endtime.getTime()>(new Date().getTime()) && !(element.requestsent && element.requestsent != "1")) {
+		if( endtime.getTime()>(new Date().getTime()) && element.requestsent && element.requestsent == "1") {
 			send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
 		}
 	}else if(basedate){
@@ -2366,9 +2379,14 @@ function eventCalendarDayViewSelectionKeyUp(moduleObject, element, event){
 		case 16: // Alt
 		case 17: // ctr key
 		case 18: // alt key
+			break;
 		case 37: // navigations keys
-		case 38: // navigations keys
+			eventDayViewClickPrev(moduleObject);
+			break;
 		case 39: // navigations keys
+			eventDayViewClickNext(moduleObject);
+			break;
+		case 38: // navigations keys
 		case 40: // navigations keys
 			break;
 		case 13: // ENTER
