@@ -519,7 +519,7 @@ PrintCalendarDayView.prototype.createAllDayItem = function(appointElement, item)
 PrintCalendarDayView.prototype.resizeView = function() {
 	var menubarHeight = dhtml.getElementById("menubar").offsetHeight + dhtml.getElementById("menubar").offsetTop;
 	var titleHeight = dhtml.getElementsByClassName("title")[0].offsetHeight;
-	var bodyHeight = document.getElementsByTagName("body")[0].offsetHeight;
+	var bodyHeight = dhtml.getBrowserInnerSize()["y"];
 
 	var dialogContentHeight = bodyHeight - (menubarHeight + titleHeight) + 12;
 	dhtml.getElementById("dialog_content").style.height = dialogContentHeight + "px";
