@@ -230,8 +230,8 @@ PrintCalendarMonthView.prototype.createItem = function(item) {
 			} else {
 				// normal event
 				appointmentElement.className = "event_item ipm_appointment";
-				appointmentElement.setAttribute("title", "[" + startDate.toTime() + " - " + dueDate.toTime() + "] " + subject);
-				dhtml.addElement(appointmentElement, "span", "event_time", "", startDate.toTime() + NBSP);
+				appointmentElement.setAttribute("title", "[" + startDate.strftime(_("%H:%M")) + " - " + dueDate.strftime(_("%H:%M")) + "] " + subject);
+				dhtml.addElement(appointmentElement, "span", "event_time", "", startDate.strftime(_("%H:%M")) + NBSP);
 
 				appointmentElementBack.className = "event_item_back";
 			}
