@@ -172,9 +172,9 @@ PrintView.prototype.createItem = function(item,element) {
 				}
 			} else {
 				if(this.view == "week") {
-					dhtml.addElement(appointmentElement, "span", "event_time", "", startDate.toTime()+" "+dueDate.toTime());
+					dhtml.addElement(appointmentElement, "span", "event_time", "", startDate.strftime(_("%H:%M"))+" "+dueDate.strftime(_("%H:%M")));
 				} else {				
-					dhtml.addElement(appointmentElement, "span", "event_time", "", startDate.toTime()+" - "+dueDate.toTime());
+					dhtml.addElement(appointmentElement, "span", "event_time", "", startDate.strftime(_("%H:%M"))+" - "+dueDate.strftime(_("%H:%M")));
 					dhtml.addElement(appointmentElement, "span", "spacer_list", "", NBSP);
 				}
 			}
