@@ -256,18 +256,18 @@ TableCompactView.prototype.renderRow = function(elemid, row)
 				case "ipm_schedule_meeting_canceled":
 				case "report_ipm_note_ipnnrn":
 				case "report_ipm_note_ipnrn":
-					messageClass = "ipm_readmail";
+					messageClass = "ipm_readmail read_unread";
 					
 					var messageUnsent = row.getElementsByTagName("message_unsent")[0];
 					if(messageUnsent && messageUnsent.firstChild) {
-						messageClass = "ipm_createmail";
+						messageClass = "ipm_createmail read_unread";
 					}
 					break;
 				case "ipm_taskrequest":
 				case "ipm_taskrequest_accept":
 				case "ipm_taskrequest_decline":
 				case "ipm_taskrequest_update":
-					messageClass = "ipm_task";
+					messageClass = "ipm_task read_unread";
 					break;
 			}
 		}
@@ -293,8 +293,9 @@ TableCompactView.prototype.renderRow = function(elemid, row)
 		
 		// Create row
 		rowData.push("<tr id='" + elemid + "' class='row " + messageUnread + " " + messageClass + "' " + messageflaghtml + " entryid='"+dhtml.getXMLValue(row, this.uniqueid)+"' >");
-		
-		var iconClass = iconIndexToClassName(dhtml.getXMLValue(row,"icon_index"), dhtml.getXMLValue(row, "message_class"), !messageUnread);
+
+		var isStub = dhtml.getXMLValue(row, "stubbed", false);
+		var iconClass = iconIndexToClassName(dhtml.getXMLValue(row,"icon_index"), dhtml.getXMLValue(row, "message_class"), !messageUnread, isStub);
 
 		var recvDate = dhtml.getXMLValue(row, "message_delivery_time");
 		var sentDate = dhtml.getXMLValue(row, "client_submit_time");
