@@ -450,7 +450,7 @@ TableView.prototype.renderInputColumn = function (renderOnlyinput, moduleID, tab
 	var unixtimestamp = "";
 	
 	if (title && title !="&nbsp"){
-		value=title;
+		value=title.htmlEntities();
 	}
 	
 	if (renderOnlyinput) {
@@ -608,13 +608,19 @@ TableView.prototype.addRows = function(rows)
 						case "ipm_schedule_meeting_canceled":
 						case "report_ipm_note_ipnnrn":
 						case "report_ipm_note_ipnrn":
-							messageClass = "ipm_readmail";
+							messageClass = "ipm_readmail read_unread";
 							
 							var messageUnsent = row.getElementsByTagName("message_unsent")[0];
 							if(messageUnsent && messageUnsent.firstChild) {
-								messageClass = "ipm_createmail";
+								messageClass = "ipm_createmail read_unread";
 							}
 							break;
+						case "ipm_taskrequest":
+						case "ipm_taskrequest_accept":
+						case "ipm_taskrequest_decline":
+						case "ipm_taskrequest_update":
+							messageClass = "ipm_task read_unread";
+							break;
 					}
 				}
 
@@ -870,11 +876,11 @@ TableView.prototype.addRow = function(row)
 					case "ipm_schedule_meeting_canceled":
 					case "report_ipm_note_ipnnrn":
 					case "report_ipm_note_ipnrn":
-						messageClass = "ipm_readmail";
+						messageClass = "ipm_readmail read_unread";
 						
 						var messageUnsent = row.getElementsByTagName("message_unsent")[0];
 						if(messageUnsent && messageUnsent.firstChild) {
-							messageClass = "ipm_createmail";
+							messageClass = "ipm_createmail read_unread";
 						}
 						break;
 				}
@@ -981,9 +987,10 @@ TableView.prototype.getRowColumnSettings = function(fieldname, type, length, val
 		case "icon_index":
 			className += " message_icon ";
 			var messageClass = dhtml.getTextNode(item.getElementsByTagName("message_class")[0],"IPM.Note");
+			var isStub = dhtml.getXMLValue(item, "stubbed", false);
 			var iconIndex = parseInt(value,10);
 
-			className += iconIndexToClassName(iconIndex, messageClass, !messageUnread);
+			className += iconIndexToClassName(iconIndex, messageClass, !messageUnread, isStub);
 			break;
 		case "display_type":
 			className += " message_icon ";
@@ -1164,18 +1171,18 @@ TableView.prototype.getRowColumnSettings = function(fieldname, type, length, val
 				break;	
 					
 				case 2:
-				elementValue = "<div class='rowcolumntext'>"+ _("Work")+"</div>";
+				elementValue = "<div class='rowcolumntext'>"+ _("Business")+"</div>";
 				break;	
 					
 				case 3:
 				elementValue = "<div class='rowcolumntext'>"+ _("Personal")+"</div>";
 				break;	
 				case 4:
-				elementValue = "<div class='rowcolumntext'>"+ _("Holiday")+"</div>";		
+				elementValue = "<div class='rowcolumntext'>"+ _("Vacation")+"</div>";		
 				break;
 					
 				case 5:
-				elementValue = "<div class='rowcolumntext'>"+ _("Required")+"</div>";
+				elementValue = "<div class='rowcolumntext'>"+ _("Must Attend")+"</div>";
 				break;	
 					
 				case 6:
@@ -1183,7 +1190,7 @@ TableView.prototype.getRowColumnSettings = function(fieldname, type, length, val
 				break;	
 					
 				case 7:
-				elementValue = "<div class='rowcolumntext'>"+ _("Prepare Required")+"</div>";
+				elementValue = "<div class='rowcolumntext'>"+ _("Needs Preparation")+"</div>";
 				break;	
 				
 				case 5:
@@ -1191,11 +1198,11 @@ TableView.prototype.getRowColumnSettings = function(fieldname, type, length, val
 				break;	
 					
 				case 8:
-				elementValue = "<div class='rowcolumntext'>"+ _("Special date")+"</div>";
+				elementValue = "<div class='rowcolumntext'>"+ _("Anniversary")+"</div>";
 				break;	
 					
 				case 9:
-				elementValue = "<div class='rowcolumntext'>"+ _("Phone Interview")+"</div>";
+				elementValue = "<div class='rowcolumntext'>"+ _("Phone Call")+"</div>";
 				break;
 				
 				default:
@@ -1626,8 +1633,10 @@ function eventTableViewKeyboard(moduleObject, element, event)
 								openItem = true;
 							break;
 						case 32: // SPACEBAR
-							selectElement = element;
-							openItem = true;
+							if (typeof moduleObject.editMessage == "undefined" || moduleObject.editMessage === false) {
+								selectElement = element;
+								openItem = true;
+							}
 							break;
 						case 34: // PAGE DOWN
 							var itemsPerPage = Math.floor(divElement.offsetHeight/element.offsetHeight);
