@@ -109,6 +109,7 @@
 <?php
 		includeFiles("js", array(
 							"client/core/constants.js", 
+							"client/core/fixedsettings.js", 
 							"client/core/utils.js", 
 							"client/widgets/widget.js", 
 							"client/views/view.js", 
@@ -150,6 +151,10 @@
 		}
 ?>
 		<script type="text/javascript">
+			// Setting the window name prevents an issue that the main window gets the same name
+			// as an opened modal dialog that reloads the main window.
+			window.name = 'Webaccess';
+
 			if(navigator.userAgent.toLowerCase().indexOf('chrome') > -1){
 				window.BROWSER_GOOGLECHROME = true;
 			}else if(navigator.userAgent.toLowerCase().indexOf('apple') > -1){
@@ -202,8 +207,16 @@
 					echo "\t\t\t\tplugindata.push({pluginname:\"".$singlePluginData['pluginname']."\"});\n";
 				}
 ?>
+				// IE has some issues with executing events that are not on his "allowed" list.
+				if(!window.BROWSER_IE){
+					// Firing the initialize drag message functionality event to notify the ZarafaDnd extension
+					dhtml.executeEvent(document.body, "ZarafaDnD:initDragMsgsToDesktop");
+				}
 
 				webclient.setUserInfo("<?=addslashes(windows1252_to_utf8($GLOBALS["mapisession"]->getUserName()))?>", "<?=addslashes(windows1252_to_utf8($GLOBALS["mapisession"]->getFullName()))?>", "<?=bin2hex($GLOBALS["mapisession"]->getUserEntryid())?>" , "<?=addslashes(windows1252_to_utf8($GLOBALS["mapisession"]->getEmail()))?>");
+
+				// Store current sessionid in sessionid variable
+				webclient.sessionid = "<?=session_id()?>";
 				webclient.init("<?=BASE_URL?>", "webclient", modules, settings, plugindata);
 				webclient.startClient();
 			}
