@@ -134,6 +134,18 @@ DragDrop.prototype.addDraggable = function(element, group, isFixed, resizable, m
 	}
 }
 
+/**
+ * This function de-registeres a draggable element, and cannot be dragged around the window.
+ * @param {HTMLElement} element the draggable element.
+ */
+DragDrop.prototype.removeDraggable = function(element){
+	// Remove draggable attributes.
+	element.removeAttribute("group");
+	element.removeAttribute("isFixed");
+	element.removeAttribute("resizable");
+	element.removeAttribute("moduleID");
+}
+
 DragDrop.prototype.registerHoverElement = function(element, callback, scope, data){
 	if(element){
 		element.hoverEvent = new Object();
@@ -248,13 +260,29 @@ DragDrop.prototype.moveElement = function(event)
 							event.clientY - dragdrop.relClickY + dragdrop.dragPointY >= (target["y"] - scrollElement.scrollTop) &&
 							event.clientY - dragdrop.relClickY + dragdrop.dragPointY <= (target["y"] + target["element"].offsetHeight - scrollElement.scrollTop)){
 							
-							if(isFixed) {
-								this.moveFixedDraggable(target, action, scrollElement);
+							/**
+							 * Get scrollelement hight and width and its left and top
+							 * to check whether mousemove event is fired on scrollelement or outside.
+							 */
+							var topleft = dhtml.getElementTopLeft(scrollElement);
+							var scrollWidth = scrollElement.clientWidth + topleft[0];
+							var scrollHeight = scrollElement.clientHeight + topleft[1];
+
+							var scrollTop = scrollHeight - scrollElement.clientHeight;
+							var scrollLeft = scrollWidth - scrollElement.clientWidth;
+
+							// If event is fired in the scrollelement then set the target otherwise clear the selection.
+							if(scrollHeight > event.clientY && scrollTop < event.clientY && scrollWidth > event.clientX && scrollLeft < event.clientX) {
+								if(isFixed) {
+									this.moveFixedDraggable(target, action, scrollElement);
+								} else {
+									this.moveDraggable(target);
+								}
+								this.targetover = target;
 							} else {
-								this.moveDraggable(target);
+								// Clear dragdrop target selection.
+								eventDragDropMouseOutDraggable();
 							}
-							
-							this.targetover = target;
 						}
 					}
 				}
@@ -339,6 +367,11 @@ function eventDragDropMouseDownDraggable(moduleObject, element, event)
 	}
 
 	var group = element.getAttribute("group");
+
+	// If no groups is there then item is not draggable, so skip dragging operation.
+	if(!group)
+		return false;
+
 	var isFixed = (element.getAttribute("isFixed") == undefined || element.getAttribute("isFixed")=="false"?false:true);
 
 	// Remember where the client clicked when the drag started so we can see how far the object has been dragged
@@ -407,8 +440,8 @@ function eventDragDropMouseDownDraggable(moduleObject, element, event)
 		// Because this is an icon, position the icon just next to the cursor. We're dragging the center.
 		dragdrop.relClickX = 8;
 		dragdrop.relClickY = 8;
-		dragdrop.dragPointX = 0;
-		dragdrop.dragPointY = 0;
+		dragdrop.dragPointX = 8;
+		dragdrop.dragPointY = 8;
 	}
 
 	dragdrop.draggable.moduleID = moduleObject.id;
@@ -496,6 +529,9 @@ function eventDragDropMouseUpDraggable(moduleObject, element, event)
 		var isFixed = (draggableElem.getAttribute("isFixed") == undefined || draggableElem.getAttribute("isFixed")=="false"?false:true);
 		if(!isFixed) {
 			dhtml.deleteElement(draggableElem);
+		} else if(dropped){
+			dragdrop.removeDraggable(draggableElem);
+			dhtml.addElement(draggableElem, 'span', 'message_loader');
 		}
 		
 		draggableElem = false;
