@@ -58,9 +58,9 @@ function Menu()
 	this.defaultMenuItems.push(this.createMenuItem("seperator", ""));
 	this.defaultMenuItems.push(this.createMenuItem("createmail", _("New"), _("Email Message")));
 	this.defaultMenuItems.push(this.createMenuItem("appointment", _("New"), _("Appointment")));
-	this.defaultMenuItems.push(this.createMenuItem("meetingrequest", _("New"), _("Meetingrequest")));
+	this.defaultMenuItems.push(this.createMenuItem("meetingrequest", _("New"), _("Meeting Request")));
 	this.defaultMenuItems.push(this.createMenuItem("contact", _("New"), _("Contact")));
-	this.defaultMenuItems.push(this.createMenuItem("distlist", _("New"), _("Distributionlist")));
+	this.defaultMenuItems.push(this.createMenuItem("distlist", _("New"), _("Distribution List")));
 	this.defaultMenuItems.push(this.createMenuItem("task", _("New"), _("Task")));
 	this.defaultMenuItems.push(this.createMenuItem("assigntask", _("New"), _("Task Request")));
 	this.defaultMenuItems.push(this.createMenuItem("stickynote", _("New"), _("Note")));
