@@ -110,7 +110,7 @@ Pagination.prototype.createPagingElement = function(contentElement, totalPages,
 	dhtml.addTextNode(pageField, _("Page"));
 	var inputField = dhtml.addElement(pageField, "input", "pageNavigation");
 	inputField.setAttribute('value', currentPage + 1);
-	dhtml.addTextNode(pageField, _(" of ") + totalPages);
+	dhtml.addTextNode(pageField, ' ' + _("of") + ' ' + totalPages);
 
 	// Attach events on input field
 	dhtml.addEvent(-1, inputField, 'click', eventPageFieldClick);
@@ -193,7 +193,7 @@ function eventPageFieldKeyDown(widgetObject, element, event)
 	 * so checking keyCode range if user is using NUM pad.
 	 */
 	} else if (!(event.keyCode >= 96 && event.keyCode <= 105) && (chars.indexOf(event.keyCode.fromCharCode()) != -1)) {
-		return false;
+		event.preventDefault();
 	}
 }
 
