@@ -214,6 +214,12 @@ suggestionList.prototype.selectSuggestion = function(selection){
 		var l_iCaretPos = this.caretPos || dhtml.getCaretPosAtTextField(this.inputfld);
 		// Get position of the last ; before the position of the cursor
 		var l_aEmailSegments = l_sEmailLine.substr(0, l_iCaretPos).split(";");
+
+		// Remove empty strings or strings with only spaces from the array.
+		for (var i = 0; i < l_aEmailSegments.length; i++) {
+			if (l_aEmailSegments[i].trim().length == 0) l_aEmailSegments.splice(i, 1);
+		}
+
 		var l_iPreStringChars = 0;
 		for(var i=0;i<(l_aEmailSegments.length-1);i++){
 			l_iPreStringChars += l_aEmailSegments[i].length + 1; // The +1 is to pass the ;
