@@ -83,6 +83,9 @@ TableWidget.prototype.init = function(element, multipleSelect, windowObj, noLoad
 	this.columnResizeListeners = new Array();
 	this.eventRowListeners = new Array();
 
+	this.sortColumn = false;
+	this.sortDirection = false;
+
 	if(!this.noLoader) {
 		// Show loader
 		this.showLoader();
@@ -132,6 +135,7 @@ TableWidget.prototype.resetWidget = function()
 	this.selected = new Object();
 	this.numSelected = 0;
 	this.eventRowListeners = new Array();
+	this.eventColumnListeners = new Array();
 	this.columnResizeListeners = new Array();
 	this.prevSelectedMessageID = false;
 }
@@ -170,11 +174,16 @@ Adding classnames for rows/cells when adding data
 	});
 }
 
-TableWidget.prototype.generateTable = function(data){
+TableWidget.prototype.generateTable = function(data, sort){
 	if(!this.noLoader) {
 		// Hide loader
 		this.hideLoader();
 	}
+	//get the sorting info from listmodule to set the sort in tableWidget
+	if(sort){
+		this.sortColumn = sort[0]["_content"];
+		this.sortDirection = sort[0]["attributes"]["direction"];
+	}
 
 	if(this.element){
 		// First clear the old table if this is not the initial generation
@@ -196,7 +205,13 @@ TableWidget.prototype.generateTable = function(data){
 		}
 
 		var availableWidth = this.element.offsetWidth;
-		var availableContentHeight = this.element.offsetHeight - 25;	// Minus header table
+		/*
+		 * When the element is not visible it is not given an offsetHeight. When this happens the 
+		 * list will not set a height and the vertical scrollbar will not show when the list is 
+		 * longer that can be shown in the available height.
+		 */
+		var height = this.element.offsetHeight || parseInt(this.element.style.height,10);
+		var availableContentHeight = height - 25;	// Minus header table
 		this.recalcColumnWidths(availableWidth);
 
 		var content = "";
@@ -237,6 +252,10 @@ TableWidget.prototype.generateTable = function(data){
 			}
 			content += '>';
 			content += '<span class="column_seperator">&nbsp;</span>'+this.columns[i]['name']+'';
+			// add sort icon to column 
+			if(this.columns[i]["id"] == this.sortColumn){
+				content += "&nbsp;<span class='sort_" + this.sortDirection + "'>&nbsp;</span>";
+			}
 			content += '</td>';
 		}
 
@@ -272,6 +291,16 @@ TableWidget.prototype.generateTable = function(data){
 			dhtml.addEvent(this, this.htmlrefs["contenttable"].rows[i], "dblclick", eventTableWidgetDblClickRow, this.windowObj);
 			dhtml.addEvent(this, this.htmlrefs["contenttable"].rows[i], "contextmenu", eventTableWidgetRowContextMenu, this.windowObj);
 		}
+	
+		if(this.htmlrefs["headertable"]){
+			var columnRow = this.htmlrefs["headertable"].rows[0];
+			if(columnRow) {
+				for(var i = 0; i < columnRow.cells.length - 1; i++)
+				{
+					dhtml.addEvent(this, columnRow.cells[i], "click", eventTableWidgetColumnSort, this.windowObj);
+				}
+			}
+		}
 	}
 }
 
@@ -312,6 +341,8 @@ TableWidget.prototype.generateRowColumnsHTML = function(rowData, addWidthData){
 	content += '<tr class="row" id="tablewidget_crow['+this.widgetID+']['+rowData["rowID"]+']" rowID="'+rowData["rowID"]+'">';
 	for(var i=0;i<this.columns.length;i++){
 		if(rowData[ this.columns[i]["id"] ]){
+			// Allowing custom css class to be set on the columns
+			var cellClassnames = rowData[ this.columns[i]["id"] ]['css'] || "";
 			if(rowData[ this.columns[i]["id"] ]['innerHTML']){
 
 				var columnWidth = "";
@@ -319,7 +350,7 @@ TableWidget.prototype.generateRowColumnsHTML = function(rowData, addWidthData){
 					columnWidth = ' width="'+this.widths[ this.columns[i]['id'] ]+'" ';
 				}
 
-				content += '<td class="rowcolumn" '+columnWidth+' columnID="'+this.columns[i]["id"]+'">'+rowData[ this.columns[i]["id"] ]['innerHTML']+'</td>';
+				content += '<td class="rowcolumn '+cellClassnames+'" '+columnWidth+' columnID="'+this.columns[i]["id"]+'">'+rowData[ this.columns[i]["id"] ]['innerHTML']+'</td>';
 			}else{
 				/**
 				 * if there is no data in a cell for first row then also we have to give
@@ -330,7 +361,7 @@ TableWidget.prototype.generateRowColumnsHTML = function(rowData, addWidthData){
 					columnWidth = ' width="'+this.widths[ this.columns[i]['id'] ]+'" ';
 				}
 
-				content += '<td class="rowcolumn" '+columnWidth+'></td>';
+				content += '<td class="rowcolumn '+cellClassnames+'" '+columnWidth+'></td>';
 			}
 		}else{
 			content += '<td></td>';
@@ -443,7 +474,7 @@ TableWidget.prototype.resize = function(){
 	var headerContainer = dhtml.getElementById("tablewidget["+this.widgetID+"][headercontainer]", "div", this.element);
 	var contentContainer = dhtml.getElementById("tablewidget["+this.widgetID+"][contentcontainer]", "div", this.element);
 	if(contentContainer != null) {
-		var contentContainerHeight = this.element.offsetHeight - headerContainer.offsetHeight;
+		var contentContainerHeight = this.element.offsetHeight - headerTbl.offsetHeight;
 		if(contentContainerHeight > 0) {
 			contentContainer.style.height = contentContainerHeight + "px";
 		}
@@ -704,7 +735,6 @@ TableWidget.prototype.isRowIDSelected = function(rowID){
 }
 
 
-
 /**
  * RowListener methods
  */
@@ -715,6 +745,22 @@ TableWidget.prototype.addRowListener = function(func, type, scope){
 	listenerObj["scope"] = scope || this;
 	this.eventRowListeners.push(listenerObj);
 }
+
+/**
+  * Checks to see if this object has any listeners for a specified row event
+  * @param {String} eventName The name of the event to check for
+  * @return {Boolean} True if the event is being listened for, else false
+  */
+TableWidget.prototype.hasRowListener = function(eventName){
+	for(var i in this.eventRowListeners){
+		if(this.eventRowListeners[i]['type'] == eventName.toLowerCase()){
+			return typeof this.eventRowListeners[i]['func'] == 'function';
+		}else{
+			return false;
+		}
+	}
+}
+
 TableWidget.prototype.callRowListener = function(type, data){
 	var args = new Array();
 	args[0] = this;			// ref to table widget
@@ -752,6 +798,62 @@ TableWidget.prototype.callRowListener = function(type, data){
 	}
 }
 
+/**
+ * Function which adds listener to columns
+ * @param		object		func		event which will listen to the event fires
+ * @param		String		type		type of event registered
+ * @param		String		scope		scope for the event 
+ */
+TableWidget.prototype.addColumnListener = function(func, type, scope){
+	var listenerObj = new Object();
+	listenerObj["type"] = type || "all";
+	listenerObj["func"] = func;
+	listenerObj["scope"] = scope || this;
+	this.eventColumnListeners.push(listenerObj);
+}
+
+ /**
+  * Checks to see if this object has any listeners for a specified column event
+  * @param {String} eventName The name of the event to check for
+  * @return {Boolean} True if the event is being listened for, else false
+  */
+TableWidget.prototype.hasColumnListener = function(eventName){
+	for(var i in this.eventColumnListeners){
+		if(this.eventColumnListeners[i]['type'] == eventName.toLowerCase()){
+			return typeof this.eventColumnListeners[i]['func'] == 'function';
+		}else{
+			return false;
+		}
+	}
+}
+
+/**
+ * Function will is called on columns events
+ * @param		String		type		type of event registered
+ * @param		Object		data		contains the columns Id and event registered
+ */
+TableWidget.prototype.callColumnListener = function(type, data){
+	var args = new Array();
+	args[0] = this;			// ref to table widget
+	switch(type){
+		case "click":
+			args[1] = "click";			// type
+			args[2] = data.columnID || false;	// columnID of clicked column
+			args[3] = data.event || false;	// event object
+			break;
+	}
+	for(var i in this.eventColumnListeners){
+		if(this.eventColumnListeners[i]['type'] == 'all' || this.eventColumnListeners[i]['type'] == type){
+			try {
+				this.eventColumnListeners[i]["func"].apply(this.eventColumnListeners[i]["scope"], args);
+			}
+			catch (e){
+				alert(e);
+			}
+		}
+	}
+}
+
 
 /**
  * Event functions
@@ -900,6 +1002,7 @@ function eventTableWidgetRowContextMenu(moduleObject, element, event){
 		moduleObject.callRowListener("contextmenu", {rowID: rowID, event: event});
 	}
 }
+
 /**
  * Function which shows loader.
  */
@@ -938,4 +1041,17 @@ TableWidget.prototype.hideZeroResultMessage = function ()
 	if(msgElement) {
 		dhtml.deleteElement(msgElement);
 	}
+}
+
+/**
+ * Global event function
+ * this function is registered with click event of table column for table widget,
+ * and it will call external event that is registered with table widget 
+ * for click handling
+ */
+function eventTableWidgetColumnSort(moduleObject, element, event){
+	if(typeof moduleObject == "undefined")
+		return false;
+
+	moduleObject.callColumnListener("click", {columnID: element, event: event});
 }
\ No newline at end of file
