@@ -60,17 +60,17 @@ if(!defined('UPLOADED_ATTACHMENT_MAX_LIFETIME')) define('UPLOADED_ATTACHMENT_MAX
 if(!defined('DISABLE_FULL_CONTACTLIST_THRESHOLD')) define('DISABLE_FULL_CONTACTLIST_THRESHOLD', -1);
 if(!defined('ENABLE_PUBLIC_FOLDERS')) define('ENABLE_PUBLIC_FOLDERS', true);
 if(!defined('FILE_UPLOAD_LIMIT')) define('FILE_UPLOAD_LIMIT', 50);
-if(!defined('FILE_QUEUE_LIMIT')) define('FILE_QUEUE_LIMIT', 50);
+if(!defined('FILE_QUEUE_LIMIT')) define('FILE_QUEUE_LIMIT', 20);
 
 /**
  * When set to true this disables the fitlering of the HTML body.
  */
 if(!defined('DISABLE_HTMLBODY_FILTER')) define('DISABLE_HTMLBODY_FILTER', false);
-if(!defined('DISABLE_DELETE_IN_RESTORE_ITEMS')) define('DISABLE_DELETE_IN_RESTORE_ITEMS', false);
 /**
  * When set to true this disables the login with the REMOTE_USER set by apache.
  */
 if(!defined('DISABLE_REMOTE_USER_LOGIN')) define('DISABLE_REMOTE_USER_LOGIN', false);
+if(!defined('DISABLE_DELETE_IN_RESTORE_ITEMS')) define('DISABLE_DELETE_IN_RESTORE_ITEMS', false);
 
 /**
  * When set to true, enable the multi-upload feature of the attachment dialog. This has the following caveats:
@@ -81,4 +81,12 @@ if(!defined('DISABLE_REMOTE_USER_LOGIN')) define('DISABLE_REMOTE_USER_LOGIN', fa
  * - In Windows, upload fails if the internet status is 'offline' - open internet explorer to reconnect
  */
 if(!defined('ENABLE_MULTI_UPLOAD')) define('ENABLE_MULTI_UPLOAD', false);
-?>
\ No newline at end of file
+
+/**
+ * Limit the amount of members shown in the addressbook details dialog for a distlist. If the list 
+ * is too great the browser will hang loading and rendereing all the items. By default set to 0 
+ * which means it loads all members.
+ */
+if(!defined('ABITEMDETAILS_MAX_NUM_DISTLIST_MEMBERS')) define('ABITEMDETAILS_MAX_NUM_DISTLIST_MEMBERS', 0);
+
+?>
