@@ -100,6 +100,11 @@
 			}
 
 			if(isset($this->messageprops[$this->proptags["recurring_data"]]))
+				// There is a possibility that recurr blob can be more than 255 bytes so get full blob through stream interface
+				if (strlen($this->messageprops[$this->proptags["recurring_data"]]) >= 255) {
+					$this->getFullRecurrenceBlob();
+				}
+
 				$this->recur = $this->parseRecurrence($this->messageprops[$this->proptags["recurring_data"]]);
 			if(isset($this->proptags["timezone_data"]) && isset($this->messageprops[$this->proptags["timezone_data"]]))
 				$this->tz = $this->parseTimezone($this->messageprops[$this->proptags["timezone_data"]]);
@@ -110,6 +115,20 @@
 			return $this->recur;
 		}
 
+		function getFullRecurrenceBlob()
+		{
+			$message = mapi_msgstore_openentry($this->store, $this->messageprops[PR_ENTRYID]);
+
+			$recurrBlob = '';
+			$stream = mapi_openproperty($message, $this->proptags["recurring_data"], IID_IStream, 0, 0);
+			$stat = mapi_stream_stat($stream);
+
+			for ($i = 0; $i < $stat['cb']; $i += 1024)
+				$recurrBlob .= mapi_stream_read($stream, 1024);
+
+			if (!empty($recurrBlob)) $this->messageprops[$this->proptags["recurring_data"]] = $recurrBlob;
+		}
+
 		/**
 		* Function for parsing the Recurrence value of a Calendar item.
 		*
@@ -289,11 +308,21 @@
 			$exc_base_dates = array();
 			for($i = 0; $i < $ret["numexcept"]; $i++)
 			{
+                if (strlen($rdata) < 4) {
+					// We shouldn't arrive here, because that implies
+					// numexcept does not match the amount of data
+					// which is available for the exceptions.
+					return $ret;
+				}
 				$data = unpack("Vbasedate", $rdata);
 				$rdata = substr($rdata, 4);
 				$exc_base_dates[] = $this->recurDataToUnixData($data["basedate"]);
 			}
-			
+
+			if (strlen($rdata) < 4) {
+				return $ret;
+			}
+
 			$data = unpack("Vnumexceptmod", $rdata);
 			$rdata = substr($rdata, 4);
 			
@@ -304,6 +333,12 @@
 			$exc_changed = array();
 			for($i = 0; $i < $ret["numexceptmod"]; $i++)
 			{
+                if (strlen($rdata) < 4) {
+					// We shouldn't arrive here, because that implies
+					// numexceptmod does not match the amount of data
+					// which is available for the exceptions.
+					return $ret;
+				}
 				$data = unpack("Vstartdate", $rdata);
 				$rdata = substr($rdata, 4);
 				$exc_changed[] = $this->recurDataToUnixData($data["startdate"]);
@@ -319,15 +354,18 @@
 			$ret["start"] = $this->recurDataToUnixData($data["start"]);
 			$ret["end"] = $this->recurDataToUnixData($data["end"]);
 
+			// this is where task recurrence stop
 			if (strlen($rdata) < 16) {
 				return $ret;
 			}
 			
-			$data = unpack("Vconst1/Cversion/C3const2/Vstartmin/Vendmin", $rdata);
+			$data = unpack("Vreaderversion/Vwriterversion/Vstartmin/Vendmin", $rdata);
 			$rdata = substr($rdata, 16); 
 
 			$ret["startocc"] = $data["startmin"];
 			$ret["endocc"] = $data["endmin"];
+			$readerversion = $data["readerversion"];
+			$writerversion = $data["writerversion"];
 
 			$data = unpack("vnumber", $rdata);
 			$rdata = substr($rdata, 2);
@@ -356,16 +394,19 @@
 
 				$data = unpack("vbitmask", $rdata);
 				$rdata = substr($rdata, 2);
+				$item["bitmask"] = $data["bitmask"]; // save bitmask for extended exceptions
 
 				// Bitmask to verify what properties are changed
 				$bitmask = $data["bitmask"];
 
+				// ARO_SUBJECT: 0x0001
+				// Look for field: SubjectLength (2b), SubjectLength2 (2b) and Subject
 				if(($bitmask &(1 << 0))) {
 					$data = unpack("vnull_length/vlength", $rdata);
 					$rdata = substr($rdata, 4);
 
 					$length = $data["length"];
-					$item["subject"] = "";
+					$item["subject"] = ""; // Normalized subject
 					for($j = 0; $j < $length && strlen($rdata); $j++)
 					{
 						$data = unpack("Cchar", $rdata);
@@ -375,10 +416,14 @@
 					}
 				}
 
+				// ARO_MEETINGTYPE: 0x0002
 				if(($bitmask &(1 << 1))) {
+					$rdata = substr($rdata, 4);
 					// Attendees modified: no data here (only in attachment)
 				}
 
+				// ARO_REMINDERDELTA: 0x0004
+				// Look for field: ReminderDelta (4b)
 				if(($bitmask &(1 << 2))) {
 					$data = unpack("Vremind_before", $rdata);
 					$rdata = substr($rdata, 4);
@@ -386,6 +431,8 @@
 					$item["remind_before"] = $data["remind_before"];
 				}
 
+				// ARO_REMINDER: 0x0008
+				// Look field: ReminderSet (4b)
 				if(($bitmask &(1 << 3))) {
 					$data = unpack("Vreminder_set", $rdata);
 					$rdata = substr($rdata, 4);
@@ -393,6 +440,9 @@
 					$item["reminder_set"] = $data["reminder_set"];
 				}
 
+				// ARO_LOCATION: 0x0010
+				// Look for fields: LocationLength (2b), LocationLength2 (2b) and Location
+				// Similar to ARO_SUBJECT above.
 				if(($bitmask &(1 << 4))) {
 					$data = unpack("vnull_length/vlength", $rdata);
 					$rdata = substr($rdata, 4);
@@ -406,6 +456,8 @@
 					$item["location"] .= $data;
 				}
 
+				// ARO_BUSYSTATUS: 0x0020
+				// Look for field: BusyStatus (4b)
 				if(($bitmask &(1 << 5))) {
 					$data = unpack("Vbusystatus", $rdata);
 					$rdata = substr($rdata, 4);
@@ -413,10 +465,14 @@
 					$item["busystatus"] = $data["busystatus"];
 				}
 
+				// ARO_ATTACHMENT: 0x0040
 				if(($bitmask &(1 << 6))) {
 					// no data: RESERVED
+					$rdata = substr($rdata, 4);
 				}
 
+				// ARO_SUBTYPE: 0x0080
+				// Look for field: SubType (4b). Determines whether it is an allday event.
 				if(($bitmask &(1 << 7))) {
 					$data = unpack("Vallday", $rdata);
 					$rdata = substr($rdata, 4);
@@ -424,6 +480,8 @@
 					$item["alldayevent"] = $data["allday"];
 				}
 
+				// ARO_APPTCOLOR: 0x0100
+				// Look for field: AppointmentColor (4b)
 				if(($bitmask &(1 << 8))) {
 					$data = unpack("Vlabel", $rdata);
 					$rdata = substr($rdata, 4);
@@ -431,6 +489,7 @@
 					$item["label"] = $data["label"];
 				}
 
+				// ARO_EXCEPTIONAL_BODY: 0x0200
 				if(($bitmask &(1 << 9))) {
 					// Notes or Attachments modified: no data here (only in attachment)
 				}
@@ -466,6 +525,71 @@
 			$ret["deleted_occurences"] = $deleted_occurences;
 			$ret["changed_occurences"] = $exc_changed_details;
 
+			// enough data for normal exception (no extended data)
+			if (strlen($rdata) < 16) {
+				return $ret;
+			}
+
+			$data = unpack("Vreservedsize", $rdata);
+			$rdata = substr($rdata, 4 + $data["reservedsize"]);
+
+			for($i=0;$i<$nexceptions;$i++) 
+			{
+				// subject and location in ucs-2 to utf-8
+				if ($writerversion >= 0x3009) {
+					$data = unpack("Vsize/Vvalue", $rdata); // size includes sizeof(value)==4
+					$rdata = substr($rdata, 4 + $data["size"]);
+				}
+
+				$data = unpack("Vreservedsize", $rdata);
+				$rdata = substr($rdata, 4 + $data["reservedsize"]);
+
+				// ARO_SUBJECT(0x01) | ARO_LOCATION(0x10)
+				if ($exc_changed_details[$i]["bitmask"] & 0x11) {
+					$data = unpack("Vstart/Vend/Vorig", $rdata);
+					$rdata = substr($rdata, 4 * 3);
+
+					$exc_changed_details[$i]["ex_start_datetime"] = $data["start"];
+					$exc_changed_details[$i]["ex_end_datetime"] = $data["end"];
+					$exc_changed_details[$i]["ex_orig_date"] = $data["orig"];
+				}
+
+				// ARO_SUBJECT
+				if ($exc_changed_details[$i]["bitmask"] & 0x01) {
+					// decode ucs2 string to utf-8
+					$data = unpack("vlength", $rdata);
+					$rdata = substr($rdata, 2);
+					$length = $data["length"];
+					$data = substr($rdata, 0, $length * 2);
+					$rdata = substr($rdata, $length * 2);
+					$subject = iconv("UCS-2LE", "UTF-8", $data);
+					// replace subject with unicode subject
+					$exc_changed_details[$i]["subject"] = $subject;
+				}
+
+				// ARO_LOCATION
+				if ($exc_changed_details[$i]["bitmask"] & 0x10) {
+					// decode ucs2 string to utf-8
+					$data = unpack("vlength", $rdata);
+					$rdata = substr($rdata, 2);
+					$length = $data["length"];
+					$data = substr($rdata, 0, $length * 2);
+					$rdata = substr($rdata, $length * 2);
+					$location = iconv("UCS-2LE", "UTF-8", $data);
+					// replace subject with unicode subject
+					$exc_changed_details[$i]["location"] = $location;
+				}
+
+				// ARO_SUBJECT(0x01) | ARO_LOCATION(0x10)
+				if ($exc_changed_details[$i]["bitmask"] & 0x11) {
+					$data = unpack("Vreservedsize", $rdata);
+					$rdata = substr($rdata, 4 + $data["reservedsize"]);
+				}
+			}
+
+			// update with extended data
+			$ret["changed_occurences"] = $exc_changed_details;
+
 			return $ret;
 		}
 
@@ -1080,12 +1204,19 @@
 			}
 
 			// FlagDueBy is datetime of the first reminder occurrence. Outlook gives on this time a reminder popup dialog
-			$reminderprops = mapi_getprops($this->message, array($this->proptags["reminder_minutes"]) );
+			$reminderprops = mapi_getprops($this->message, array($this->proptags["reminder_minutes"], $this->proptags["flagdueby"]) );
 			if(isset($reminderprops[$this->proptags["reminder_minutes"]]) ) {
-				//TODO: $utcfirstoccstartdatetime must the first upcomming occurrence, so you need the current 
-				//      client time. When you create a recurrent before the current date, the FlagDueBy must be the 
-				//      first upcomming occurrence after the current date.
-				mapi_setprops($this->message, Array($this->proptags["flagdueby"] => $utcfirstoccstartdatetime - ($reminderprops[$this->proptags["reminder_minutes"]] * 60) ));
+				/**
+				 * TODO: $utcfirstoccstartdatetime must the first upcomming occurrence, so you need the current 
+-				 * client time. When you create a recurrent before the current date, the FlagDueBy must be the 
+-				 * first upcomming occurrence after the current date.
+				 * 
+				 * Get the next occurrence after the current flagdueby i.e. reminder and set that occurrence's
+				 * reminder time to the flagdueby property.
+				 */
+				$items = $this->getItems($reminderprops[$this->proptags["flagdueby"]], 0x7ff00000, 1, true);
+				$tempnextreminder = $items[0][$this->proptags["startdate"]] - ( $items[0][$this->proptags["reminder_minutes"]] * 60 );
+				mapi_setprops($this->message, Array($this->proptags["flagdueby"] => $tempnextreminder ));
 			}
 			
 			// Default data
@@ -1103,7 +1234,6 @@
 				
 			$rdata .= pack("v", count($changed_items));
 			
-			$string_changed = false;
 			foreach($changed_items as $changed_item)
 			{
 				// Set start and end time of exception
@@ -1119,6 +1249,10 @@
 					$bitmask |= 1 << 0;
 				}
 
+				if(isset($changed_item["remind_before"])) {
+					$bitmask |= 1 << 2;
+				}
+
 				if(isset($changed_item["reminder_set"])) {
 					$bitmask |= 1 << 3;
 				}
@@ -1143,16 +1277,15 @@
 
 				// Set "subject"
 				if(isset($changed_item["subject"]))	{
-					$length = strlen($changed_item["subject"]);
+					// convert utf-8 to non-unicode blob string (us-ascii?)
+					$subject = iconv("UTF-8", "windows-1252//TRANSLIT", $changed_item["subject"]);
+					$length = strlen($subject);
 					$rdata .= pack("vv", $length + 1, $length);
+					$rdata .= pack("a".$length, $subject);
+				}
 
-					$chars = preg_split('//', $changed_item["subject"], -1, PREG_SPLIT_NO_EMPTY);
-					for($j = 0; $j < $length; $j++)
-					{
-						$rdata .= pack("C", ord($chars[$j]));
-					}
-
-					$string_changed = true;
+				if(isset($changed_item["remind_before"])) {
+					$rdata .= pack("V", $changed_item["remind_before"]);
 				}
 
 				if(isset($changed_item["reminder_set"])) {
@@ -1160,16 +1293,10 @@
 				}
 
 				if(isset($changed_item["location"])) {
-					$length = strlen($changed_item["location"]);
+					$location = iconv("UTF-8", "windows-1252//TRANSLIT", $changed_item["location"]);
+					$length = strlen($location);
 					$rdata .= pack("vv", $length + 1, $length);
-
-					$chars = preg_split('//', $changed_item["location"], -1, PREG_SPLIT_NO_EMPTY);
-					for($j = 0; $j < $length; $j++)
-					{
-						$rdata .= pack("C", ord($chars[$j]));
-					}
-
-					$string_changed = true;
+					$rdata .= pack("a".$length, $location);
 				}
 
 				if(isset($changed_item["busystatus"])) {
@@ -1187,6 +1314,7 @@
 
 			$rdata .= pack("V", 0);
 
+			// write extended data
 			foreach($changed_items as $changed_item)
 			{
 				$rdata .= pack("V", 0);
@@ -1197,25 +1325,17 @@
 				}
 
 				if(isset($changed_item["subject"])) {
-					$rdata .= pack("v", strlen($changed_item["subject"]));
-					$chars = preg_split('//', $changed_item["subject"], -1, PREG_SPLIT_NO_EMPTY);
-
-					//Pack Unicode Char: convert to ascii and pack it like a short
-					for($j = 0; $j < count($chars); $j++)
-					{
-						$rdata .= pack("v", ord($chars[$j]));
-					}
+					$subject = iconv("UTF-8", "UCS-2LE", $changed_item["subject"]);
+					$length = iconv_strlen($subject, "UCS-2LE");
+					$rdata .= pack("v", $length);
+					$rdata .= pack("a".$length*2, $subject);
 				}
 
 				if(isset($changed_item["location"])) {
-					$rdata .= pack("v", strlen($changed_item["location"]));
-					$chars = preg_split('//', $changed_item["location"], -1, PREG_SPLIT_NO_EMPTY);
-
-					//Pack Unicode Char: convert to ascii and pack it like a short
-					for($j = 0; $j < count($chars); $j++)
-					{
-						$rdata .= pack("v", ord($chars[$j]));
-					}
+					$location = iconv("UTF-8", "UCS-2LE", $changed_item["location"]);
+					$length = iconv_strlen($location, "UCS-2LE");
+					$rdata .= pack("v", $length);
+					$rdata .= pack("a".$length*2, $location);
 				}
 
 				if(isset($changed_item["subject"]) || isset($changed_item["location"])) {
@@ -1751,7 +1871,7 @@
 			}
 
 			// sort items on starttime
-			uasort($items, array($this, "sortStarttime"));
+			usort($items, array($this, "sortStarttime"));
 
 			// Return the MAPI-compatible list of items for this object
 			return $items;
@@ -1803,4 +1923,4 @@
 		    return $a["start"] == $b["start"] ? 0 : ($a["start"]  > $b["start"] ? 1 : -1 );
 		}
 	}
-?>
\ No newline at end of file
+?>
