@@ -49,7 +49,7 @@
  */
 
 ?>
-<?
+<?php
 
 include_once('class.recurrence.php');
 
@@ -339,7 +339,7 @@ class FreeBusyPublish {
     		$timestamps[] = $ts;
     	} 
 
-    	usort($timestamps, Array("FreeBusyPublish", "cmp"));
+    	usort($timestamps, Array($this, "cmp"));
 
     	foreach($timestamps as $ts)
     	{
