@@ -158,7 +158,7 @@
 				
 				// Basedate in the exception attachment is the GMT time at which the original occurrence would have been
 				$props[$this->proptags["basedate"]] = $this->toGMT($this->tz, $basetime);
-
+				
 				// Save the data into an attachment
 				$this->createExceptionAttachment($props, $exception_recips, $copy_attach_from);
 				
@@ -169,7 +169,7 @@
                 
                 $changed_item["basedate"] = $baseday;
                 $changed_item["start"] = $this->fromGMT($this->tz, $exception_props[$this->proptags["startdate"]]);
-                $changed_item["end"] =   $this->fromGMT($this->tz, $exception_props[$this->proptags["duedate"]]);
+                $changed_item["end"] = $this->fromGMT($this->tz, $exception_props[$this->proptags["duedate"]]);
 
                 if(array_key_exists($this->proptags["subject"], $exception_props)) {
                     $changed_item["subject"] = $exception_props[$this->proptags["subject"]];
@@ -185,7 +185,11 @@
                 
                 if(array_key_exists($this->proptags["reminder"], $exception_props)) {
                     $changed_item["reminder_set"] = $exception_props[$this->proptags["reminder"]];
-                }
+				}
+
+				if(array_key_exists($this->proptags["reminder_minutes"], $exception_props)) {
+					$changed_item["remind_before"] = $exception_props[$this->proptags["reminder_minutes"]];
+				}
                 
                 if(array_key_exists($this->proptags["alldayevent"], $exception_props)) {
                     $changed_item["alldayevent"] = $exception_props[$this->proptags["alldayevent"]];
@@ -215,7 +219,7 @@
 		 * Modifies an existing exception, but only updates the given properties
 		 * NOTE: You can't remove properites from an exception, only add new ones
 		 */
-		function modifyException($exception_props, $base_date, $exception_recips = array(), $copy_attach_from)
+		function modifyException($exception_props, $base_date, $exception_recips = array(), $copy_attach_from = false)
 		{
 		    if(!$this->isValidExceptionDate($base_date, $this->fromGMT($this->tz, $exception_props[$this->proptags["startdate"]]))) {
 		        return false;
@@ -225,7 +229,7 @@
 			$basetime = $baseday + $this->recur["startocc"] * 60;
 			$extomodify = false;
 
-			for($i=0;$i<count($this->recur["changed_occurences"]);$i++) {			
+			for($i=0;$i<count($this->recur["changed_occurences"]);$i++) {
 		    	if($this->isSameDay($this->recur["changed_occurences"][$i]["basedate"], $baseday))
 		    		$extomodify = &$this->recur["changed_occurences"][$i];
 		    }
@@ -233,9 +237,6 @@
 			if(!$extomodify)
 				return false;
 
-			$startdate = $this->gmtime($exception_props[$this->proptags["startdate"]]);
-			$enddate = $this->gmtime($exception_props[$this->proptags["duedate"]]);
-
 			// remove basedate property as we want to preserver the old value
 			// client will send basedate with time part as zero, so discard that value
 			unset($exception_props[$this->proptags["basedate"]]);
@@ -263,7 +264,11 @@
 			if(array_key_exists($this->proptags["reminder"], $exception_props)) {
 				$extomodify["reminder_set"] = $exception_props[$this->proptags["reminder"]];
 			}
-			
+
+			if(array_key_exists($this->proptags["reminder_minutes"], $exception_props)) {
+				$extomodify["remind_before"] = $exception_props[$this->proptags["reminder_minutes"]];
+			}
+
 			if(array_key_exists($this->proptags["alldayevent"], $exception_props)) {
 				$extomodify["alldayevent"] = $exception_props[$this->proptags["alldayevent"]];
 			}
@@ -285,13 +290,22 @@
 			} else {
 				$message = mapi_attach_openobj($attach, MAPI_MODIFY);
 
+				// Set exception properties on embedded message and save
 				mapi_setprops($message, $exception_props);
 				$this->setExceptionRecipients($message, $exception_recips);
 				mapi_savechanges($message);
+
+
+				// Set new values for 'PR_EXCEPTION_STARTTIME' and 'PR_EXCEPTION_ENDTIME' on attachment which holds the embedded msg and save
+				$props = array();
+				$props[PR_EXCEPTION_STARTTIME] = $this->fromGMT($this->tz, $exception_props[$this->proptags["startdate"]]);
+				$props[PR_EXCEPTION_ENDTIME] = $this->fromGMT($this->tz, $exception_props[$this->proptags["duedate"]]);
+
+				mapi_setprops($attach, $props);
 				mapi_savechanges($attach);
 			}
 
-			// Save recurrence data to message			
+			// Save recurrence data to message
 			$this->saveRecurrence();
 
 			return true;
@@ -330,6 +344,65 @@
             return count($items) == 1;
 		}
 
+		/**
+		 * Check to see reminder time does not exceed the starttime
+		 * of the previous recurring item
+		 *
+		 * @param date $basedate the base date of the exception (LOCAL time of non-exception occurrence)
+		 * @param string $reminderminutes reminder minutes which is set of the item
+		 * @param date $startdate the startdate of the selected item
+		 * @returns boolean if the reminder minutes value valid.
+		 */
+		function isValidReminderTime($basedate, $reminderminutes, $startdate)
+		{
+			$isreminderrangeset = false;
+			
+			// get all occurence items before the seleceted items occurence starttime
+			$occitems = $this->getItems($this->messageprops[$this->proptags["startdate"]], $basedate);
+			$len = count($occitems);
+			
+			// as occitems array is sorted in ascending order of startdate so, to get the previous occurence we take the second last items in occitems .
+			$previousitem_basedate = $occitems[$len - 1]["basedate"];	//previous basedate in local format
+			$previousitem_startdate = $this->toGMT($this->tz, ($previousitem_basedate + ($this->recur["startocc"] * 60)));	//previous startdate in GMT timezone
+
+			if(count($this->recur["changed_occurences"] > 0)){
+				
+				for($i=0 ;$i<count($this->recur["changed_occurences"]); $i++) {
+					//check that whether the previous occurence is already a exceptions
+					if($this->isSameDay($this->recur["changed_occurences"][$i]["basedate"], $previousitem_basedate)){
+						$previousitem_startdate = $this->toGMT($this->tz, $this->recur["changed_occurences"][$i]["start"]);	// in GMT timezone
+						
+						$reminderrange = ($startdate - $previousitem_startdate)/60;
+						$isreminderrangeset = true;
+					}
+				}
+			}else{
+				$reminderrange = ($startdate - $previousitem_startdate)/60;
+				$isreminderrangeset = true;
+			}
+
+			if(!$isreminderrangeset)	
+				$reminderrange = ($startdate - $previousitem_startdate)/60;
+
+			// Get the endtime of the current occurrence and find the next occurrence of the current moved occurrence.
+			$currentOcc = $this->getItems($basedate, 0x7ff00000, 1, true);
+			$currentOccEnd = $currentOcc[0][$this->proptags["duedate"]];
+			$nextOcc = $this->getItems($currentOccEnd, 0x7ff00000, 1, true);
+
+			if(count($nextOcc) > 0) {
+				// Get reminder time of the next occurrence.
+				$nextOccReminderTime = $nextOcc[0][$this->proptags["startdate"]] - ($nextOcc[0][$this->proptags["reminder_minutes"]] * 60);
+				// Check that the occurrence doesn't start after the next occurrence reminder.
+				if($nextOccReminderTime < $startdate)
+					return false;
+			}
+
+			if($reminderminutes >= $reminderrange)
+				return false;
+			else
+				return true;
+		}
+		
 		function setRecurrence($tz, $recur) 
 		{
 			// only reset timezone if specified
@@ -491,7 +564,6 @@
 
                     // GetItems guarantees that the item overlaps the interval <$viewstart, $viewend>                    
                     $occurrences = $rec->getItems($viewstart, $viewend);
-                    
                     foreach($occurrences as $occurrence) {
                         // The occurrence takes all properties from the main row, but overrides some properties (like start and end obviously)
                         $item = $row;
