@@ -144,18 +144,26 @@
 			return $this->moveToNextOccurrence();
 		}
 
+		/**
+		 * Sets task object to first occurrence if startdate/duedate of task object is different from first occurrence
+		 */
 		function setFirstOccurrence()
 		{
-			$items = $this->getNextOccurrence();
+			// Check if it is already the first occurrence
+			if($this->action['start'] == $this->recur["start"]){
+				return;
+			}else{
+				$items = $this->getNextOccurrence();
 
-			$props = array();
-			$props[$this->proptags['startdate']] = $items[$this->proptags['startdate']];
-			$props[$this->proptags['commonstart']] = $items[$this->proptags['startdate']];
+				$props = array();
+				$props[$this->proptags['startdate']] = $items[$this->proptags['startdate']];
+				$props[$this->proptags['commonstart']] = $items[$this->proptags['startdate']];
 
-			$props[$this->proptags['duedate']] = $items[$this->proptags['duedate']];
-			$props[$this->proptags['commonend']] = $items[$this->proptags['duedate']];
+				$props[$this->proptags['duedate']] = $items[$this->proptags['duedate']];
+				$props[$this->proptags['commonend']] = $items[$this->proptags['duedate']];
 
-			mapi_setprops($this->message, $props);
+				mapi_setprops($this->message, $props);
+			}
 		}
 
 		/**
