@@ -49,7 +49,7 @@
  */
 
 ?>
-<?
+<?php
 	/*
 	* In general
 	*
@@ -484,7 +484,9 @@
 			
 			mapi_savechanges($this->message);
 			
-			return $this->sendResponse(tdmtTaskDec, $prefix);
+			$this->sendResponse(tdmtTaskDec, $prefix);
+
+			return $this->deleteReceivedTR();
 		}
 
 		/* Send an update of the task if requested, and send the Status-On-Completion report if complete and requested
@@ -924,43 +926,43 @@
 			$msgProps = mapi_getprops($this->message);
 			$body = "";
 
-			if (isset($msgProps[PR_SUBJECT])) $body .= "\nSubject:\t". $msgProps[PR_SUBJECT];
-			if (isset($msgProps[$this->props['startdate']])) $body .= "\nStart Date:\t". strftime("%A, %B %d, %Y",$msgProps[$this->props['startdate']]);
-			if (isset($msgProps[$this->props['duedate']])) $body .= "\nDue Date:\t". strftime("%A, %B %d, %Y",$msgProps[$this->props['duedate']]);
+			if (isset($msgProps[PR_SUBJECT])) $body .= "\n" . _("Subject") . ":\t". $msgProps[PR_SUBJECT];
+			if (isset($msgProps[$this->props['startdate']])) $body .= "\n" . _("Start Date") . ":\t". strftime("%A, %B %d, %Y",$msgProps[$this->props['startdate']]);
+			if (isset($msgProps[$this->props['duedate']])) $body .= "\n" . _("Due Date") . ":\t". strftime("%A, %B %d, %Y",$msgProps[$this->props['duedate']]);
 			$body .= "\n";
 
 			if (isset($msgProps[$this->props['status']])) {
-				$body .= "\nStatus:\t";
-				if ($msgProps[$this->props['status']] == 0) $body .= "Not Started";
-				else if ($msgProps[$this->props['status']] == 1) $body .= "In Progress";
-				else if ($msgProps[$this->props['status']] == 2) $body .= "Complete";
-				else if ($msgProps[$this->props['status']] == 3) $body .= "Wait for other person";
-				else if ($msgProps[$this->props['status']] == 4) $body .= "Deferred";
+				$body .= "\n" . _("Status") . ":\t";
+				if ($msgProps[$this->props['status']] == 0) $body .= _("Not Started");
+				else if ($msgProps[$this->props['status']] == 1) $body .= _("In Progress");
+				else if ($msgProps[$this->props['status']] == 2) $body .= _("Complete");
+				else if ($msgProps[$this->props['status']] == 3) $body .= _("Wait for other person");
+				else if ($msgProps[$this->props['status']] == 4) $body .= _("Deferred");
 			}
 
 			if (isset($msgProps[$this->props['percent_complete']])) {
-				$body .= "\nPercent Complete:\t". ($msgProps[$this->props['percent_complete']] * 100).'%';
+				$body .= "\n" . _("Percent Complete") . ":\t". ($msgProps[$this->props['percent_complete']] * 100).'%';
 
 				if ($msgProps[$this->props['percent_complete']] == 1 && isset($msgProps[$this->props['datecompleted']]))
-					$body .= "\nDate Completed:\t". strftime("%A, %B %d, %Y",$msgProps[$this->props['datecompleted']]);
+					$body .= "\n" . _("Date Completed") . ":\t". strftime("%A, %B %d, %Y",$msgProps[$this->props['datecompleted']]);
 			}
 			$body .= "\n";
 
-			if (isset($msgProps[$this->props['totalwork']])) $body .= "\nTotal Work:\t". ($msgProps[$this->props['totalwork']]/60) ." hours";
-			if (isset($msgProps[$this->props['actualwork']])) $body .= "\nActual Work:\t". ($msgProps[$this->props['actualwork']]/60) ." hours";
+			if (isset($msgProps[$this->props['totalwork']])) $body .= "\n" . _("Total Work") . ":\t". ($msgProps[$this->props['totalwork']]/60) ." " . _("hours");
+			if (isset($msgProps[$this->props['actualwork']])) $body .= "\n" . _("Actual Work") . ":\t". ($msgProps[$this->props['actualwork']]/60) ." " . _("hours");
 			$body .="\n";
 
-			if (isset($msgProps[$this->props['owner']])) $body .= "\nOwner:\t". $msgProps[$this->props['owner']];
+			if (isset($msgProps[$this->props['owner']])) $body .= "\n" . _("Owner") . ":\t". $msgProps[$this->props['owner']];
 			$body .="\n";
 
 			if (isset($msgProps[$this->props['categories']]) && count($msgProps[$this->props['categories']]) > 0) $body .= "\nCategories:\t". implode(', ', $msgProps[$this->props['categories']]);
 			if (isset($msgProps[$this->props['companies']]) && count($msgProps[$this->props['companies']]) > 0) $body .= "\nCompany:\t". implode(', ', $msgProps[$this->props['companies']]);
-			if (isset($msgProps[$this->props['billinginformation']])) $body .= "\nBilling Information:\t". $msgProps[$this->props['billinginformation']];
-			if (isset($msgProps[$this->props['mileage']])) $body .= "\nMileage:\t". $msgProps[$this->props['mileage']];
+			if (isset($msgProps[$this->props['billinginformation']])) $body .= "\n" . _("Billing Information") . ":\t". $msgProps[$this->props['billinginformation']];
+			if (isset($msgProps[$this->props['mileage']])) $body .= "\n" . _("Mileage") . ":\t". $msgProps[$this->props['mileage']];
 			$body .="\n";
 
 			$content = mapi_message_openproperty($this->message, PR_BODY);
-			$body .= "\n". trim(windows1252_to_utf8($content), "\0");
+			$body .= "\n". trim($content, "\0");
 
 			return $body;
 		}
