@@ -638,6 +638,7 @@ define('PR_CONTAINER_MODIFY_VERSION'                  ,mapi_prop_tag(PT_I8,
 define('PR_AB_PROVIDER_ID'                            ,mapi_prop_tag(PT_BINARY,      0x3615));
 define('PR_DEFAULT_VIEW_ENTRYID'                      ,mapi_prop_tag(PT_BINARY,      0x3616));
 define('PR_ASSOC_CONTENT_COUNT'                       ,mapi_prop_tag(PT_LONG,        0x3617));
+define('PR_EXTENDED_FOLDER_FLAGS'                     ,mapi_prop_tag(PT_BINARY,      0x36DA));
 
 define('PR_RIGHTS'                                    ,mapi_prop_tag(PT_LONG,        0x6639));
 
@@ -822,6 +823,7 @@ define('PR_BUSINESS_ADDRESS_COUNTRY_A'                ,PR_COUNTRY_A);
 define('PR_FLAG_STATUS'                               ,mapi_prop_tag(PT_LONG,        0x1090));
 define('PR_FLAG_COMPLETE_TIME'                        ,mapi_prop_tag(PT_SYSTIME,     0x1091));
 define('PR_FLAG_ICON'                                 ,mapi_prop_tag(PT_LONG,        0x1095));
+define('PR_BLOCK_STATUS'                              ,mapi_prop_tag(PT_LONG,        0x1096));
 
 define('PR_LOCALITY'                                  ,mapi_prop_tag(PT_TSTRING,     0x3A27));
 define('PR_LOCALITY_W'                                ,mapi_prop_tag(PT_UNICODE,     0x3A27));
@@ -1181,10 +1183,14 @@ define('PR_QUOTA_WARNING_THRESHOLD'                   ,mapi_prop_tag(PT_LONG,
 define('PR_QUOTA_SEND_THRESHOLD'                      ,mapi_prop_tag(PT_LONG,        PR_EC_BASE+0x22));
 define('PR_QUOTA_RECEIVE_THRESHOLD'                   ,mapi_prop_tag(PT_LONG,        PR_EC_BASE+0x23));
 
-/* storage for the settings for the ajax-webaccess */
+/* storage for the settings for the webaccess 6.xx */
 define('PR_EC_WEBACCESS_SETTINGS'                     ,mapi_prop_tag(PT_STRING8,     PR_EC_BASE+0x70));
 define('PR_EC_RECIPIENT_HISTORY'                      ,mapi_prop_tag(PT_STRING8,     PR_EC_BASE+0x71));
 
+/* storage for the settings for the webaccess 7.xx */
+define('PR_EC_WEBACCESS_SETTINGS_JSON'                ,mapi_prop_tag(PT_STRING8,     PR_EC_BASE+0x72));
+define('PR_EC_RECIPIENT_HISTORY_JSON'                 ,mapi_prop_tag(PT_STRING8,     PR_EC_BASE+0x73));
+
 /* statistics properties */
 define('PR_EC_STATSTABLE_SYSTEM'		, mapi_prop_tag(PT_OBJECT,		PR_EC_BASE+0x30));
 define('PR_EC_STATSTABLE_SESSIONS'		, mapi_prop_tag(PT_OBJECT,		PR_EC_BASE+0x31));
@@ -1249,4 +1255,20 @@ define('PR_INTERNET_MESSAGE_ID', mapi_prop_tag(PT_STRING8, 0x1035));
 
 // for hidden folders
 define('PR_ATTR_HIDDEN', mapi_prop_tag(PT_BOOLEAN, 0x10F4));
+
+/**
+ * Addressbook detail properties.
+ * It is not defined by MAPI, but to keep in sync with the interface of outlook we have to use these
+ * properties. Outlook actually uses these properties for it's addressbook details.
+ */
+define('PR_HOME2_TELEPHONE_NUMBER_MV'         ,mapi_prop_tag(PT_MV_TSTRING, 0x3A2F));
+define('PR_BUSINESS2_TELEPHONE_NUMBER_MV'     ,mapi_prop_tag(PT_MV_TSTRING, 0x3A1B));
+define('PR_EMS_AB_PROXY_ADDRESSES'            ,mapi_prop_tag(PT_TSTRING,    0x800F));
+define('PR_EMS_AB_PROXY_ADDRESSES_MV'         ,mapi_prop_tag(PT_MV_TSTRING, 0x800F));
+define('PR_EMS_AB_MANAGER'                    ,mapi_prop_tag(PT_BINARY,     0x8005));
+define('PR_EMS_AB_REPORTS'                    ,mapi_prop_tag(PT_BINARY,     0x800E));
+define('PR_EMS_AB_REPORTS_MV'                 ,mapi_prop_tag(PT_MV_BINARY,  0x800E));
+define('PR_EMS_AB_IS_MEMBER_OF_DL'            ,mapi_prop_tag(PT_MV_BINARY,  0x8008));
+define('PR_EMS_AB_OWNER'                      ,mapi_prop_tag(PT_BINARY,     0x800C));
+
 ?>
\ No newline at end of file
