@@ -67,6 +67,7 @@
 	define('MUC_AVAILABLE', (is_file('client/modules/multiusercalendarmodule.js')));
 	
 	ob_start();
+	setlocale(LC_CTYPE, "en_US.UTF-8");
 
 	// Start the session
 	session_name(COOKIE_NAME);
@@ -175,7 +176,6 @@
 		} else $lang = $GLOBALS["settings"]->get("global/language", LANG);
 		
 		$GLOBALS["language"]->setLanguage($lang);
-
 		if($_GET && array_key_exists("logon", $_GET)) {
 			$GLOBALS['PluginManager']->triggerHook("server.index.login.success");
 			if(isset($_POST) && isset($_POST["action_url"]) && $_POST["action_url"] != "") {
@@ -192,6 +192,8 @@
 
 		// add extra header
 		header("X-Zarafa: ".phpversion("mapi").(defined("SVN") ? "-".SVN:""));
+		// Temporary fix for Internet Explorer 9, will make it work under IE8 compatibility mode
+		header("X-UA-Compatible: IE=8");
 
 		// external files who need our login
 		if ($_GET && array_key_exists("load", $_GET)) {
@@ -202,7 +204,6 @@
 			$_SESSION['files'] = $attachment_state->read("files");
 			$_SESSION['deleteattachment'] = $attachment_state->read("deleteattachment");
 			$attachment_state->close();
-
 			switch ($_GET["load"]) {
 				case "translations.js":
 					$GLOBALS['PluginManager']->triggerHook("server.index.load.jstranslations.before");
@@ -210,6 +211,21 @@
 					$GLOBALS['PluginManager']->triggerHook("server.index.load.jstranslations.after");
 					break;
 				case "dialog":
+					// If the dialog is called with attachid in URL we want to call the upload attachment file 
+					// first to upload the files to the server, and add them to session files.
+					if($_GET && array_key_exists("attachment_id", $_GET)){
+						$GLOBALS['PluginManager']->triggerHook("server.index.load.upload_attachment.before");
+						include("server/upload_attachment.php");
+						$GLOBALS['PluginManager']->triggerHook("server.index.load.upload_attachment.after");
+						// Get Attachment data from $_SESSION and put it into the state
+						// Do it now before outputting the dialog.php data, so that zarafa.php cannot be called
+						// before we have written the data
+						$attachment_state = new State('attachments');
+						$attachment_state->open();
+						$attachment_state->write("files", $_SESSION['files']);
+						$attachment_state->write("deleteattachment", $_SESSION['deleteattachment']);
+						$attachment_state->close();
+					}
 					$GLOBALS['PluginManager']->triggerHook("server.index.load.dialog.before");
 					include("client/dialog.php");
 					$GLOBALS['PluginManager']->triggerHook("server.index.load.dialog.after");
@@ -224,6 +240,11 @@
 					include("client/download_attachment.php");
 					$GLOBALS['PluginManager']->triggerHook("server.index.load.download_attachment.after");
 					break;
+				case "download_message":
+					$GLOBALS['PluginManager']->triggerHook("server.index.load.download_message.before");
+					include("client/download_message.php");
+					$GLOBALS['PluginManager']->triggerHook("server.index.load.download_message.after");
+					break;
 				default:
 					// These hooks are defined twice (also when no "load" argument is supplied)
 					$GLOBALS['PluginManager']->triggerHook("server.index.load.main.before");
