@@ -86,11 +86,7 @@ class Conversion {
 	*/
 	function utf8_to_windows1252($string)
 	{
-		if (function_exists("iconv")){
-			return iconv("UTF-8", "Windows-1252//TRANSLIT", $string);
-		}else{
-			return utf8_decode($string); // no euro support here
-		}
+		return $string;
 	}
 
 	/**
@@ -105,11 +101,7 @@ class Conversion {
 	*/
 	function windows1252_to_utf8($string)
 	{
-		if (function_exists("iconv")){
-			return iconv("Windows-1252", "UTF-8//TRANSLIT", $string);
-		}else{
-			return utf8_encode($string); // no euro support here
-		}
+		return $string;
 	}
 
 	/**
@@ -257,6 +249,7 @@ class Conversion {
 						break;
 				}
 			} else if($key === "body") {
+				$properties[PR_INTERNET_CPID] = 65001; // always write UTF-8 codepage
 				if(isset($props["use_html"]) && $props["use_html"] == "true") {
 					$properties[PR_HTML] = $value;
 				}
@@ -326,7 +319,7 @@ class Conversion {
 
 			} else if($name == "body") {
 				if(isset($message_properties[$property])) {
-					$properties[$name] = windows1252_to_utf8($message_properties[$property]);
+					$properties[$name] = $message_properties[$property];
 				}
 			}
 		}
@@ -1144,6 +1137,83 @@ class Conversion {
 
 		return $propTag;
 	}
+	
+	/**
+	 * Get charset name from a codepage
+	 *
+	 * @see http://msdn.microsoft.com/en-us/library/dd317756(VS.85).aspx
+	 *
+	 * Table taken from common/codepage.cpp
+	 *
+	 * @param integer codepage Codepage
+	 * @return string iconv-compatible charset name
+	 */
+	function getCodepageCharset($codepage)
+	{
+		$codepages = array(
+			20106 => "DIN_66003",
+			20108 => "NS_4551-1",
+			20107 => "SEN_850200_B",
+			950 => "big5",
+			50221 => "csISO2022JP",
+			51932 => "euc-jp",
+			51936 => "euc-cn",
+			51949 => "euc-kr",
+			949 => "euc-kr",
+			936 => "gb18030",
+			52936 => "csgb2312",
+			852 => "ibm852",
+			866 => "ibm866",
+			50220 => "iso-2022-jp",
+			50222 => "iso-2022-jp",
+			50225 => "iso-2022-kr",
+			1252 => "windows-1252",
+			28591 => "iso-8859-1",
+			28592 => "iso-8859-2",
+			28593 => "iso-8859-3",
+			28594 => "iso-8859-4",
+			28595 => "iso-8859-5",
+			28596 => "iso-8859-6",
+			28597 => "iso-8859-7",
+			28598 => "iso-8859-8",
+			28599 => "iso-8859-9",
+			28603 => "iso-8859-13",
+			28605 => "iso-8859-15",
+			20866 => "koi8-r",
+			21866 => "koi8-u",
+			932 => "shift-jis",
+			1200 => "unicode",
+			1201 => "unicodebig",
+			65000 => "utf-7",
+			65001 => "utf-8",
+			1250 => "windows-1250",
+			1251 => "windows-1251",
+			1253 => "windows-1253",
+			1254 => "windows-1254",
+			1255 => "windows-1255",
+			1256 => "windows-1256",
+			1257 => "windows-1257",
+			1258 => "windows-1258",
+			874 => "windows-874",
+			20127 => "us-ascii"
+		);
+		
+		if(isset($codepages[$codepage])) {
+			return $codepages[$codepage];
+		} else {
+			// Defaulting to iso-8859-15 since it is more likely for someone to make a mistake in the codepage
+			// when using west-european charsets then when using other charsets since utf-8 is binary compatible
+			// with the bottom 7 bits of west-european
+			return "iso-8859-15";
+		}
+	}
+
+	function convertCodepageStringToUtf8($codepage, $string)
+	{	
+		$charset = Conversion::getCodepageCharset($codepage);
+		
+		return iconv($charset, "utf-8", $string);
+	}
 }
 
 /**
@@ -1160,7 +1230,7 @@ function hex2bin($data) {
 * @see Conversion::utf8_to_windows1252()
 */
 function u2w($string) {
-	return Conversion::utf8_to_windows1252($string);
+	return $string;
 }
 
 /**
@@ -1169,7 +1239,7 @@ function u2w($string) {
 * @deprecated Use u2w now
 */
 function utf8_to_windows1252($string) {
-	return Conversion::utf8_to_windows1252($string);
+	return $string;
 }
 
 /**
@@ -1177,7 +1247,7 @@ function utf8_to_windows1252($string) {
 * @see Conversion::windows1252_to_utf8()
 */
 function w2u($string){
-	return Conversion::windows1252_to_utf8($string);
+	return $string;
 }
 
 /**
@@ -1186,5 +1256,6 @@ function w2u($string){
 * @deprecated Use w2u now
 */
 function windows1252_to_utf8($string){
-	return Conversion::windows1252_to_utf8($string);
+	return $string;
 }
+
