@@ -97,7 +97,7 @@
 			$GLOBALS["preg_replace"]["entryid"] = $entryid;
 
 			// inline images can be specified without cid: tag also so replace that also, but exclude external link to images
-			$html = preg_replace_callback('/\s*<img[^>]*src\s*=\s*[\"\']([^\"\']*)[\"\']/msi', "inline_img_attachments", $html);
+			$html = preg_replace_callback('/<img[^>]*src\s*=\s*[\"\']([^\"\']*)[\"\'].*?>/msi', "inline_img_attachments", $html);
 
 			// all image tags will be processed by above line, still cid: can be specified with css also
 			// so this line will handle cid: in all tags
@@ -139,7 +139,55 @@
 		 */		 		
 		function filterScripts($str)
 		{
-			return magicHTML($str, 0);
+			/**
+			 * Here we perform two regular expressions to find the propper HREF attribute. We are doing two because the
+			 * value of an HTML attribute does not need to be in quotes. First we perform the quoted regex.
+			 * <base                    Start with the base tag
+			 * [^>]*                    The we have any character until the next statement which looks for a href 
+			 *                           attribute
+			 *  href=                   Now we continue with an href attribute preceeded by a space(!)
+			 * [\'\"]([^\'\">]*)[\'\"]  This part looks for a string inside the quoted value of the attribute. It 
+			 *                           searches for all characters except a quote or a tag-closing character. The 
+			 *                           latter is to prevent having an issue when dealing with dirty HTML (forgotten 
+			 *                           quotes).
+			 * [^>]*>                   End with any character until the end of the HTML tag
+			 * 
+			 * Now we continue with the non-quoted regex
+			 * <base      Same as above
+			 * [^>]*      Same as above
+			 *  href=     Same as above, again with space(!) preceeding the attribute name
+			 * ([^ >]*)   This part looks for any character right after the "href=" that is not a space or an tag-closing
+			 *             character. Again the latter is done too prevent getting weird results with dirty HTML.
+			 * [^>]*>     Same as above
+			 * 
+			 * If the quoted regex does not turn up any results we will use the non-quoted one. If there are multiple 
+			 * href attributes in the tag then the regex will take the last one. When looking at the following HTML 
+			 * <base href="test1" href=test2> the first one (11) will be used because the quoted regex is looked at 
+			 * first.
+			 */ 
+			$baseMatchQuoted    = preg_match('/<base[^>]* href=[\'\"]([^\'\">]*)[\'\"][^>]*>/msi',$str, $matchQuoted);
+			$baseMatchNonQuoted = preg_match('/<base[^>]* href=([^ >]*)[^>]*>/msi',$str, $matchNonQuoted);
+			$baseHref = false;
+			if($baseMatchQuoted === 1){
+				$baseHref = $matchQuoted[1];
+			}elseif($baseMatchNonQuoted === 1){
+				$baseHref = $baseMatchNonQuoted[1];
+			}
+
+			$str = magicHTML($str, 0);
+
+			// Check the url in the b$baseHref and see if it starts with a protocol to prevent JS injection.
+			if($baseHref && preg_match('/^[a-zA-Z0-9]+:\/\//', $baseHref) === 1){
+				$base = '<base href="'.$baseHref.'" />';
+				// Add 'base href' after the head-tag
+				$str = preg_replace("/<(head[^>]*)>/msi",('<$1>'.$base),$str);
+
+				// if no head-tag was found (no base href is then added), add the 'base href' above the file
+				if(strpos($str, $base)===false){
+					$str = $base . $str;
+				}
+			}
+			return $str;
 		} 
 	
 		/**
