@@ -199,6 +199,8 @@
 			$properties["creation_time"] = PR_CREATION_TIME;
 			$properties["remindertime"] = "PT_SYSTIME:PSETID_Common:0x8502";
 			$properties["requestsent"] = "PT_BOOLEAN:PSETID_Appointment:0x8229";
+			$properties["toattendeesstring"] = "PT_STRING8:PSETID_Appointment:0x823B";
+			$properties["ccattendeesstring"] = "PT_STRING8:PSETID_Appointment:0x823C";
 			$properties["body"] = PR_BODY;
 			// Conflict properties
 			$properties["conflictitems"] = PR_CONFLICT_ITEMS;
@@ -464,6 +466,110 @@
 			return getPropIdsFromStrings($this->store, $properties);
 		}
 
+		/**
+		 * Returns the details properties for a MAPI_MAILUSER in the addressbook.
+		 * @return array properties for an AB entry.
+		 */
+		function getAddressBookItemMailuserProperties()
+		{
+			$this->Init();
+			
+			$properties = array();
+			$properties["entryid"] = PR_ENTRYID;
+			$properties["object_type"] = PR_OBJECT_TYPE;
+			$properties["given_name"] = PR_GIVEN_NAME;
+			$properties["initials"] = PR_INITIALS;
+			$properties["surname"] = PR_SURNAME;
+			$properties["display_name"] = PR_DISPLAY_NAME;
+			$properties["account"] = PR_ACCOUNT;
+			$properties["street_address"] = PR_STREET_ADDRESS;
+			$properties["locality"] = PR_LOCALITY;
+			$properties["state_or_province"] = PR_STATE_OR_PROVINCE;
+			$properties["postal_code"] = PR_POSTAL_CODE;
+			$properties["country"] = PR_COUNTRY;
+			$properties["title"] = PR_TITLE;
+			$properties["company_name"] = PR_COMPANY_NAME;
+			$properties["department_name"] = PR_DEPARTMENT_NAME;
+			$properties["office_location"] = PR_OFFICE_LOCATION;
+			$properties["assistant"] = PR_ASSISTANT;
+			$properties["business_telephone_number"] = PR_BUSINESS_TELEPHONE_NUMBER;
+			$properties["business2_telephone_number"] = PR_BUSINESS2_TELEPHONE_NUMBER;
+			$properties["business2_telephone_number_mv"] = PR_BUSINESS2_TELEPHONE_NUMBER_MV;
+			$properties["primary_fax_number"] = PR_PRIMARY_FAX_NUMBER;
+			$properties["home_telephone_number"] = PR_HOME_TELEPHONE_NUMBER;
+			$properties["home2_telephone_number"] = PR_HOME2_TELEPHONE_NUMBER;
+			$properties["home2_telephone_number_mv"] = PR_HOME2_TELEPHONE_NUMBER_MV;
+			$properties["mobile_telephone_number"] = PR_MOBILE_TELEPHONE_NUMBER;
+			$properties["pager_telephone_number"] = PR_PAGER_TELEPHONE_NUMBER;
+			$properties["comment"] = PR_COMMENT;
+			$properties["ems_ab_manager"] = PR_EMS_AB_MANAGER;
+			$properties["ems_ab_reports"] = PR_EMS_AB_REPORTS;
+			$properties["ems_ab_reports_mv"] = PR_EMS_AB_REPORTS_MV;
+			$properties["ems_ab_is_member_of_dl"] = PR_EMS_AB_IS_MEMBER_OF_DL;
+			$properties["ems_ab_proxy_addresses"] = PR_EMS_AB_PROXY_ADDRESSES;
+			$properties["ems_ab_proxy_addresses_mv"] = PR_EMS_AB_PROXY_ADDRESSES_MV;
+
+			// Allowing to hook in and add more properties
+			$GLOBALS['PluginManager']->triggerHook("server.core.properties.addressbookitem.mailuser", array(
+				'properties' =>& $properties
+			));
+
+			return getPropIdsFromStrings($this->store, $properties);
+		}
+
+		/**
+		 * Returns the details properties for a MAPI_DISTLIST in the addressbook.
+		 * @return array properties for an AB entry.
+		 */
+		function getAddressBookItemDistlistProperties()
+		{
+			$this->Init();
+			
+			$properties = array();
+			$properties["entryid"] = PR_ENTRYID;
+			$properties["object_type"] = PR_OBJECT_TYPE;
+			$properties["display_name"] = PR_DISPLAY_NAME;
+			$properties["account"] = PR_ACCOUNT;
+			$properties["comment"] = PR_COMMENT;
+			$properties["ems_ab_owner"] = PR_EMS_AB_OWNER;
+			$properties["ems_ab_is_member_of_dl"] = PR_EMS_AB_IS_MEMBER_OF_DL;
+			$properties["ems_ab_proxy_addresses"] = PR_EMS_AB_PROXY_ADDRESSES;
+			$properties["ems_ab_proxy_addresses_mv"] = PR_EMS_AB_PROXY_ADDRESSES_MV;
+
+			// Allowing to hook in and add more properties
+			$GLOBALS['PluginManager']->triggerHook("server.core.properties.addressbookitem.distlist", array(
+				'properties' =>& $properties
+			));
+
+			return getPropIdsFromStrings($this->store, $properties);
+		}
+
+		/**
+		 * Returns the details properties for the manager AB entry in the addressbook.
+		 * @return array properties for an AB entry.
+		 */
+		function getAddressBookItemABObjectProperties()
+		{
+			$this->Init();
+			
+			$properties = array();
+			$properties["display_name"] = PR_DISPLAY_NAME;
+			$properties["entryid"] = PR_ENTRYID;
+			$properties["object_type"] = PR_OBJECT_TYPE;
+			$properties["instance_key"] = PR_INSTANCE_KEY;
+			$properties["display_type"] = PR_DISPLAY_TYPE;
+			$properties["smtp_address"] = PR_SMTP_ADDRESS;
+			$properties["account"] = PR_ACCOUNT;
+			$properties["rowid"] = PR_ROWID;
+
+			// Allowing to hook in and add more properties
+			$GLOBALS['PluginManager']->triggerHook("server.core.properties.addressbookitem.abobject", array(
+				'properties' =>& $properties
+			));
+
+			return getPropIdsFromStrings($this->store, $properties);
+		}
+
 		/**
 		 * Returns the properties for an email.
 		 * @return array properties for an email.		 
@@ -545,6 +651,9 @@
 			$properties["goid"] = "PT_BINARY:PSETID_Meeting:0x3";
 			$properties["goid2"] = "PT_BINARY:PSETID_Meeting:0x23";
 
+			// Archiver property
+			$properties["stubbed"] = "PT_BOOLEAN:PSETID_Archive:stubbed";
+
 			return getPropIdsFromStrings($this->store, $properties);
 		}
 		
@@ -765,39 +874,5 @@
 			
 			return $properties;
 		}
-
-		/**
-		 * Returns the properties for archived items
-		 * @return array properties for archived items
-		 */
-		function getArchiverStubProperties()
-		{
-			$this->Init();
-			
-			// Z-archiver properties
-			$properties["store_entryids"] = "PT_MV_BINARY:Z_ARCHIVER:store-entryids";
-			$properties["item_entryids"] = "PT_MV_BINARY:Z_ARCHIVER:item-entryids";
-			$properties["stubbed"] = "PT_BOOLEAN:Z_ARCHIVER:stubbed";
-			$properties["original_sourcekey"] = "PT_BINARY:Z_ARCHIVER:original-sourcekey";
-
-			return getPropIdsFromStrings($this->store, $properties);
-		}
-
-		/**
-		 * Returns the properties that have to be restored when destubbing the 
-		 * a message that is archived.
-		 * @return array properties for archived items
-		 */
-		function getArchiverRestoreProperties()
-		{
-			$this->Init();
-			
-			// These properties will be copied to the stub message
-			$properties["rtf_compressed"] = PR_RTF_COMPRESSED;
-			$properties["message_class"] = PR_MESSAGE_CLASS;
-			$properties["icon_index"] = PR_ICON_INDEX;
-
-			return getPropIdsFromStrings($this->store, $properties);
-		}
 }
 ?>
