@@ -206,6 +206,13 @@
 				$declare = true;
 			}
 			foreach ($current as $key=>$value) {
+				if (!preg_match("/^([1-9][0-9]*|0)$/", $key)){
+					// escape quotes and line ends
+					// We have to escape < as well. When they are loaded in the main window, a 
+					// </script>-tag will end the javascript block prematurely. Replaced to "\x3C".
+					$key = str_replace(array("\\","\"","\n", "\r", "<"),array("\\\\","\\\"","\\n", "\\r", "\\x3C"),$key);
+				}
+
 				if (is_array($value)) {
 					$output .= $this->getJavaScript($indenting, $value, $base."[\"".$key."\"]");
 				} else {
