@@ -66,19 +66,19 @@ class TableColumns {
 		$tableColumns = array();
 
 		$this->addColumn($tableColumns, "icon_index", true, 0, _("Icon Index"), _("Sort on Icon Index"));
-		$this->addColumn($tableColumns, "alldayevent", true, 0, _("All Day"), _("Sort On All Day Event"));		
+		$this->addColumn($tableColumns, "alldayevent", true, 0, _("All Day"), _("Sort on All Day Event"));		
 		$this->addColumn($tableColumns, "subject", true, 2, _("Subject"), _("Sort on Subject"),PERCENTAGE);
-		$this->addColumn($tableColumns, "startdate", true, 3, _("Startdate"), _("Sort on Startdate"));
-		$this->addColumn($tableColumns, "duedate", true, 4, _("Enddate"), _("Sort on Enddate"));
-		$this->addColumn($tableColumns, "location", true, 5, _("Location"), _("Sort On location"));
-		$this->addColumn($tableColumns, "meeting", true, 7, _("Meeting Status"), _("Sort On meeting status"));
-		$this->addColumn($tableColumns, "duration", true, 6, _("Duration"), _("Sort On Duration"), 60);
-		$this->addColumn($tableColumns, "body", false, 8, _("Message"), _("Sort On Message"), PERCENTAGE);
-		$this->addColumn($tableColumns, "creation_time", false, 5, _("Created on"), _("Sort On Created Date"));
+		$this->addColumn($tableColumns, "startdate", true, 3, _("Start date"), _("Sort on Startdate"));
+		$this->addColumn($tableColumns, "duedate", true, 4, _("End date"), _("Sort on Enddate"));
+		$this->addColumn($tableColumns, "location", true, 5, _("Location"), _("Sort on location"));
+		$this->addColumn($tableColumns, "meeting", true, 7, _("Meeting Status"), _("Sort on meeting status"));
+		$this->addColumn($tableColumns, "duration", true, 6, _("Duration"), _("Sort on Duration"), 60);
+		$this->addColumn($tableColumns, "body", false, 8, _("Message"), _("Sort on Message"), PERCENTAGE);
+		$this->addColumn($tableColumns, "creation_time", false, 5, _("Created on"), _("Sort on Created Date"));
 
 		// Columns for Reminder
-		$this->addColumn($tableColumns, "reminder", false, 3, _("Reminder"), _("Sort On Reminder"));
-		$this->addColumn($tableColumns, "flagdueby", false, 9, _("Due By"), _("Sort On due by"));
+		$this->addColumn($tableColumns, "reminder", false, 3, _("Reminder"), _("Sort on Reminder"));
+		$this->addColumn($tableColumns, "flagdueby", false, 9, _("Due By"), _("Sort on Due By"));
 
 		// Columns for Recurring Events
 		$this->addColumn($tableColumns, "recurring", true, 1, _("Recurring"), _("Sort on Recurring"));
@@ -86,15 +86,15 @@ class TableColumns {
 		$this->addColumn($tableColumns, "startdate_recurring", false, 5, _("Recurring Startdate"), _("Sort on Recurring"));
 		$this->addColumn($tableColumns, "enddate_recurring", false, 6, _("Recurring Enddate"), _("Sort on Recurring"));
 	
-		$this->addColumn($tableColumns, "categories", false, 9, _("Categories"), _("Sort On Categories"));
-		$this->addColumn($tableColumns, "sensitivity", false, 10, _("Sensitivity"), _("Sort On sensitivity"), 80);
-		$this->addColumn($tableColumns, "label", false, 9, _("Label"), _("Sort On label"), 90);
-		$this->addColumn($tableColumns, "contacts", false, 10, _("Contacts"), _("Sort On Contact"));
+		$this->addColumn($tableColumns, "categories", false, 9, _("Categories"), _("Sort on Categories"));
+		$this->addColumn($tableColumns, "sensitivity", false, 10, _("Sensitivity"), _("Sort on Sensitivity"), 80);
+		$this->addColumn($tableColumns, "label", false, 9, _("Label"), _("Sort on Label"), 90);
+		$this->addColumn($tableColumns, "contacts", false, 10, _("Contacts"), _("Sort on Contact"));
 
 		// Columns for Attendees
-		$this->addColumn($tableColumns, "required", false, 11, _("Required Attendee"), _("Sort On attendee"));
-		$this->addColumn($tableColumns, "optional", false, 12, _("Optional Attendee"), _("Sort On attendee"));
-		$this->addColumn($tableColumns, "resource", false, 13, _("Resource"), _("Sort On attendee"));
+		$this->addColumn($tableColumns, "required", false, 11, _("Required Attendee"), _("Sort on Attendee"));
+		$this->addColumn($tableColumns, "optional", false, 12, _("Optional Attendee"), _("Sort on Attendee"));
+		$this->addColumn($tableColumns, "resource", false, 13, _("Resource"), _("Sort on Attendee"));
 
 		$this->addColumn($tableColumns, "busystatus", false, 5, _("Busy Status"), _("Sort on Busy Status"));
 
@@ -108,45 +108,45 @@ class TableColumns {
 	function getContactListTableColumns() {
 		$tableColumns = array();
 
-		$this->addColumn($tableColumns, "icon_index", true, 0, _("Icon"), _("Sort On Icon"));
-		$this->addColumn($tableColumns, "fileas", true, 1, _("File As"), _("Sort On File As"));
-		$this->addColumn($tableColumns, "display_name", true, 2, _("Full Name"), _("Sort On Display Name"), PERCENTAGE);
-		$this->addColumn($tableColumns, "email_address_1", true, 3, _("Email Address 1"), _("Sort On Email Address 1"));
-		$this->addColumn($tableColumns, "email_address_2", false, 3, _("Email Address 2"), _("Sort On Email Address 2"));
-		$this->addColumn($tableColumns, "email_address_3", false, 3, _("Email Address 3"), _("Sort On Email Address 3"));
-		$this->addColumn($tableColumns, "home_telephone_number", true, 4, _("Home Telephonenumber"), _("Sort On Home Telephonenumber"));
-		$this->addColumn($tableColumns, "cellular_telephone_number", true, 5, _("Cellular Telephonenumber"), _("Sort On Cellular Telephonenumber"));
-		$this->addColumn($tableColumns, "categories", false, 4, _("Categories"), _("Sort On Categories"));
+		$this->addColumn($tableColumns, "icon_index", true, 0, _("Icon"), _("Sort on Icon"));
+		$this->addColumn($tableColumns, "fileas", true, 1, _("File As"), _("Sort on File As"));
+		$this->addColumn($tableColumns, "display_name", true, 2, _("Full Name"), _("Sort on Display Name"), PERCENTAGE);
+		$this->addColumn($tableColumns, "email_address_1", true, 3, _("Email Address 1"), _("Sort on Email Address 1"));
+		$this->addColumn($tableColumns, "email_address_2", false, 3, _("Email Address 2"), _("Sort on Email Address 2"));
+		$this->addColumn($tableColumns, "email_address_3", false, 3, _("Email Address 3"), _("Sort on Email Address 3"));
+		$this->addColumn($tableColumns, "home_telephone_number", true, 4, _("Home Telephone Number"), _("Sort on Home Telephone Number"));
+		$this->addColumn($tableColumns, "cellular_telephone_number", true, 5, _("Cellular Telephone Number"), _("Sort on Cellular Telephone Number"));
+		$this->addColumn($tableColumns, "categories", false, 4, _("Categories"), _("Sort on Categories"));
 
-		$this->addColumn($tableColumns, "business_telephone_number", false, 99, _("Business Telephonenumber"), _("Sort On Business Telephonenumber"));
-		$this->addColumn($tableColumns, "office_telephone_number", false, 99, _("Office Telephonenumber"), _("Sort On Office Telephonenumber"));
-		$this->addColumn($tableColumns, "business_fax_number", false, 99, _("Business Faxnumber"), _("Sort On Business Faxnumber"));
-		$this->addColumn($tableColumns, "title", false, 99, _("Function"), _("Sort On Function Name"));
-		$this->addColumn($tableColumns, "company_name", false, 99, _("Company Name"), _("Sort On Company Name"));
-		$this->addColumn($tableColumns, "department_name", false, 99, _("Department Name"), _("Sort On Department Name"));
-		$this->addColumn($tableColumns, "office_location", false, 99, _("Office Location"), _("Sort On Office Location"));
-		$this->addColumn($tableColumns, "profession", false, 99, _("Profession"), _("Sort On Profession"));
-		$this->addColumn($tableColumns, "manager_name", false, 99, _("Manager name"), _("Sort On Manager Name"));
-		$this->addColumn($tableColumns, "assistant", false, 99, _("Assistant"), _("Sort On Assistant"));
-		$this->addColumn($tableColumns, "nickname", false, 99, _("Nickname"), _("Sort On Nickname"));
-		$this->addColumn($tableColumns, "spouse_name", false, 99, _("Spouse Name"), _("Sort On Spouse Name"));
-		$this->addColumn($tableColumns, "birthday", false, 99, _("Birthday"), _("Sort On Birthday"));
-		$this->addColumn($tableColumns, "business_address", false, 99, _("Business Address"), _("Sort On Business Address"));
-		$this->addColumn($tableColumns, "home_address", false, 99, _("Home Address"), _("Sort On Home Address"));
-		$this->addColumn($tableColumns, "other_address", false, 99, _("Office Address"), _("Sort On Other Address"));
-		$this->addColumn($tableColumns, "mailing_address", false, 99, _("Mailing Address"), _("Sort On Mailing Address"));
-		$this->addColumn($tableColumns, "im", false, 99, _("IM"), _("Sort On IM"));
-		$this->addColumn($tableColumns, "webpage", false, 99, _("Webpage"), _("Sort On Webpage"));
-		$this->addColumn($tableColumns, "assistant_telephone_number", false, 99, _("Assistant Telephonenumber"), _("Sort On Assistant Telephonenumber"));
-		$this->addColumn($tableColumns, "business2_telephone_number", false, 99, _("Business Telephonenumber 2"), _("Sort On Business Telephonenumber 2"));
-		$this->addColumn($tableColumns, "callback_telephone_number", false, 99, _("Callback Telephonenumber"), _("Sort On Callback Telephonenumber"));
-		$this->addColumn($tableColumns, "car_telephone_number", false, 99, _("Car Telephonenumber"), _("Sort On Car Telephonenumber"));
-		$this->addColumn($tableColumns, "company_telephone_number", false, 99, _("Company Telephonenumber"), _("Sort On Company Telephonenumber"));
-		$this->addColumn($tableColumns, "home2_telephone_number", false, 99, _("Home Telephonenumber 2"), _("Sort On Home Telephonenumber 2"));
-		$this->addColumn($tableColumns, "home_fax_number", false, 99, _("Home Faxnumber"), _("Sort On Home Faxnumber"));
+		$this->addColumn($tableColumns, "business_telephone_number", false, 99, _("Business Telephone Number"), _("Sort on Business Telephone Number"));
+		$this->addColumn($tableColumns, "office_telephone_number", false, 99, _("Office Telephone Number"), _("Sort on Office Telephone Number"));
+		$this->addColumn($tableColumns, "business_fax_number", false, 99, _("Business Fax Number"), _("Sort on Business Fax Number"));
+		$this->addColumn($tableColumns, "title", false, 99, _("Function"), _("Sort on Function Name"));
+		$this->addColumn($tableColumns, "company_name", false, 99, _("Company Name"), _("Sort on Company Name"));
+		$this->addColumn($tableColumns, "department_name", false, 99, _("Department Name"), _("Sort on Department Name"));
+		$this->addColumn($tableColumns, "office_location", false, 99, _("Office Location"), _("Sort on Office Location"));
+		$this->addColumn($tableColumns, "profession", false, 99, _("Profession"), _("Sort on Profession"));
+		$this->addColumn($tableColumns, "manager_name", false, 99, _("Manager name"), _("Sort on Manager Name"));
+		$this->addColumn($tableColumns, "assistant", false, 99, _("Assistant"), _("Sort on Assistant"));
+		$this->addColumn($tableColumns, "nickname", false, 99, _("Nickname"), _("Sort on Nickname"));
+		$this->addColumn($tableColumns, "spouse_name", false, 99, _("Spouse Name"), _("Sort on Spouse Name"));
+		$this->addColumn($tableColumns, "birthday", false, 99, _("Birthday"), _("Sort on Birthday"));
+		$this->addColumn($tableColumns, "business_address", false, 99, _("Business Address"), _("Sort on Business Address"));
+		$this->addColumn($tableColumns, "home_address", false, 99, _("Home Address"), _("Sort on Home Address"));
+		$this->addColumn($tableColumns, "other_address", false, 99, _("Office Address"), _("Sort on Other Address"));
+		$this->addColumn($tableColumns, "mailing_address", false, 99, _("Mailing Address"), _("Sort on Mailing Address"));
+		$this->addColumn($tableColumns, "im", false, 99, _("IM"), _("Sort on IM"));
+		$this->addColumn($tableColumns, "webpage", false, 99, _("Webpage"), _("Sort on Webpage"));
+		$this->addColumn($tableColumns, "assistant_telephone_number", false, 99, _("Assistant Telephone Number"), _("Sort On Assistant Telephone Number"));
+		$this->addColumn($tableColumns, "business2_telephone_number", false, 99, _("Business Telephone Number 2"), _("Sort On Business Telephone Number 2"));
+		$this->addColumn($tableColumns, "callback_telephone_number", false, 99, _("Callback Telephone Number"), _("Sort On Callback Telephone Number"));
+		$this->addColumn($tableColumns, "car_telephone_number", false, 99, _("Car Telephone Number"), _("Sort On Car Telephone Number"));
+		$this->addColumn($tableColumns, "company_telephone_number", false, 99, _("Company Telephone Number"), _("Sort On Company Telephone Number"));
+		$this->addColumn($tableColumns, "home2_telephone_number", false, 99, _("Home Telephone Number 2"), _("Sort On Home Telephone Number 2"));
+		$this->addColumn($tableColumns, "home_fax_number", false, 99, _("Home Fax Number"), _("Sort On Home Fax Number"));
 		$this->addColumn($tableColumns, "isdn_number", false, 99, _("ISDN Number"), _("Sort On ISDN number"));
-		$this->addColumn($tableColumns, "other_telephone_number", false, 99, _("Other Telephonenumber"), _("Sort On Other Telephonenumber"));
-		$this->addColumn($tableColumns, "pager_telephone_number", false, 99, _("Pager Telephonenumber"), _("Sort On Pager Telephonenumber"));
+		$this->addColumn($tableColumns, "other_telephone_number", false, 99, _("Other Telephone Number"), _("Sort On Other Telephone Number"));
+		$this->addColumn($tableColumns, "pager_telephone_number", false, 99, _("Pager Number"), _("Sort On Pager Number"));
 
 		return $tableColumns;
 	}
@@ -159,9 +159,9 @@ class TableColumns {
 		$tableColumns = array();
 
 		$this->addColumn($tableColumns, "icon_index", true, 0, _("Icon"), _("Sort on Icon"), 25);
-		$this->addColumn($tableColumns, "fileas", true, 1, _("File as"), _("Sort on File As"), "30%");
-		$this->addColumn($tableColumns, "display_name", true, 2, _("Display Name"), _("Sort on Display Name"), "35%");
-		$this->addColumn($tableColumns, "email_address", true, 3, _("Email Address"), _("Sort on Email Address"), PERCENTAGE);
+		$this->addColumn($tableColumns, "display_name", true, 1, _("Display Name"), _("Sort on Display Name"), "35%");
+		$this->addColumn($tableColumns, "email_address", true, 2, _("Email Address"), _("Sort on Email Address"), PERCENTAGE);
+		$this->addColumn($tableColumns, "fileas", true, 3, _("File as"), _("Sort on File As"), "30%");
 		$this->addColumn($tableColumns, "entryid", false);
 		$this->addColumn($tableColumns, "email_address_display_name_1", false);
 		$this->addColumn($tableColumns, "email_address_2", false);
@@ -181,13 +181,13 @@ class TableColumns {
 		$tableColumns = array();
 
 		$this->addColumn($tableColumns, "display_type", true, 0, _("Icon"), _("Sort on Icon"), 25);
-		$this->addColumn($tableColumns, "fileas", true, 1, _("File as"), _("Sort on File As"), "15%");
-		$this->addColumn($tableColumns, "display_name", true, 2, _("Display Name"), _("Sort on Display Name"), "15%");
-		$this->addColumn($tableColumns, "smtp_address", true, 3, _("Email Address"), _("Sort on Email Address"), PERCENTAGE);
+		$this->addColumn($tableColumns, "display_name", true, 1, _("Display Name"), _("Sort on Display Name"), "15%");
+		$this->addColumn($tableColumns, "smtp_address", true, 2, _("Email Address"), _("Sort on Email Address"), PERCENTAGE);
+		$this->addColumn($tableColumns, "fileas", true, 3, _("File as"), _("Sort on File As"), "15%");
 		$this->addColumn($tableColumns, "department", true, 4, _("Department"), _("Sort on Department"), "10%");
-		$this->addColumn($tableColumns, "office_phone", true, 3, _("Business Phone"), _("Sort on Business Phone"), "13%");
-		$this->addColumn($tableColumns, "location", true, 3, _("Location"), _("Sort on Location"), "10%");
-		$this->addColumn($tableColumns, "fax", true, 3, _("Fax"), _("Sort on Fax"), "10%");
+		$this->addColumn($tableColumns, "office_phone", true, 5, _("Business Phone"), _("Sort on Business Phone"), "13%");
+		$this->addColumn($tableColumns, "location", true, 6, _("Location"), _("Sort on Location"), "10%");
+		$this->addColumn($tableColumns, "fax", true, 7, _("Fax"), _("Sort on Fax"), "10%");
 		$this->addColumn($tableColumns, "entryid", false);
 		$this->addColumn($tableColumns, "message_class", false);
 
@@ -203,7 +203,7 @@ class TableColumns {
 
 		$this->addColumn($tableColumns, "icon_index", true, 0, _("Icon"), _("Sort on Icon"));
 		$this->addColumn($tableColumns, "subject", true, 1, _("Subject"), _("Sort on subject"));
-		$this->addColumn($tableColumns, "remindertime", true, 2, _("Due in"), _("Sort on Due in"));
+		$this->addColumn($tableColumns, "remindertime", true, 2, _("Due in"), _("Sort on Due In"));
 
 		return $tableColumns;
 	}
@@ -215,17 +215,17 @@ class TableColumns {
 	function getJournalListTableColumns() {
 		$tableColumns = array();
 
-		$this->addColumn($tableColumns, "importance", false, 0, _("Priority"), _("Sort On Priority"));
-		$this->addColumn($tableColumns, "icon_index", true, 1, _("Icon"), _("Sort On Icon"));
-		$this->addColumn($tableColumns, "hasattach", true, 2, _("Attachments"), _("Sort On Attachments"));
-		$this->addColumn($tableColumns, "subject", true, 4, _("Subject"), _("Sort On Subject"), PERCENTAGE);
-		$this->addColumn($tableColumns, "message_size", false, 6, _("Size"), _("Sort On Size"), 80);
-		$this->addColumn($tableColumns, "flag_status", false, 7, _("Flag Status"), _("Sort On Flag Status"));
-		$this->addColumn($tableColumns, "categories", false, 8, _("Categories"), _("Sort On Categories"));
-		$this->addColumn($tableColumns, "sent_representing_name", true, 3, _("From"), _("Sort On Sender"));
-		$this->addColumn($tableColumns, "message_delivery_time", true, 5, _("Received"), _("Sort On Received Date"));
-		$this->addColumn($tableColumns, "display_to", false, 3, _("To"), _("Sort On Recipient"));
-		$this->addColumn($tableColumns, "client_submit_time", false, 5, _("Sent"), _("Sort On Sent Date"));
+		$this->addColumn($tableColumns, "importance", false, 0, _("Priority"), _("Sort on Priority"));
+		$this->addColumn($tableColumns, "icon_index", true, 1, _("Icon"), _("Sort on Icon"));
+		$this->addColumn($tableColumns, "hasattach", true, 2, _("Attachments"), _("Sort on Attachments"));
+		$this->addColumn($tableColumns, "subject", true, 4, _("Subject"), _("Sort on Subject"), PERCENTAGE);
+		$this->addColumn($tableColumns, "message_size", false, 6, _("Size"), _("Sort on Size"), 80);
+		$this->addColumn($tableColumns, "flag_status", false, 7, _("Flag Status"), _("Sort on Flag Status"));
+		$this->addColumn($tableColumns, "categories", false, 8, _("Categories"), _("Sort on Categories"));
+		$this->addColumn($tableColumns, "sent_representing_name", true, 3, _("From"), _("Sort on Sender"));
+		$this->addColumn($tableColumns, "message_delivery_time", true, 5, _("Received"), _("Sort on Received Date"));
+		$this->addColumn($tableColumns, "display_to", false, 3, _("To"), _("Sort on Recipient"));
+		$this->addColumn($tableColumns, "client_submit_time", false, 5, _("Sent"), _("Sort on Sent Date"));
 
 		return $tableColumns;
 	}
@@ -237,22 +237,22 @@ class TableColumns {
 	function getMailListTableColumns() {
 		$tableColumns = array();
 
-		$this->addColumn($tableColumns, "importance", true, 0, _("Priority"), _("Sort On Priority"));
-		$this->addColumn($tableColumns, "icon_index", true, 1, _("Icon"), _("Sort On Icon"));
-		$this->addColumn($tableColumns, "hasattach", true, 2, _("Attachments"), _("Sort On Attachments"));
-		$this->addColumn($tableColumns, "subject", true, 4, _("Subject"), _("Sort On Subject"), PERCENTAGE);
-		$this->addColumn($tableColumns, "message_size", true, 6, _("Size"), _("Sort On Size"), 80);
-		$this->addColumn($tableColumns, "flag_icon", true, 7, _("Flag Status"), _("Sort On Flag Status"));
-		$this->addColumn($tableColumns, "categories", false, 8, _("Categories"), _("Sort On Categories"));
+		$this->addColumn($tableColumns, "importance", true, 0, _("Priority"), _("Sort on Priority"));
+		$this->addColumn($tableColumns, "icon_index", true, 1, _("Icon"), _("Sort on Icon"));
+		$this->addColumn($tableColumns, "hasattach", true, 2, _("Attachments"), _("Sort on Attachments"));
+		$this->addColumn($tableColumns, "subject", true, 4, _("Subject"), _("Sort on Subject"), PERCENTAGE);
+		$this->addColumn($tableColumns, "message_size", true, 6, _("Size"), _("Sort on Size"), 80);
+		$this->addColumn($tableColumns, "flag_icon", true, 7, _("Flag Status"), _("Sort on Flag Status"));
+		$this->addColumn($tableColumns, "categories", false, 8, _("Categories"), _("Sort on Categories"));
 
 		// Columns & Sort: Mail Folders
-		$this->addColumn($tableColumns, "sent_representing_name", false, 3, _("From"), _("Sort On Sender"));
-		$this->addColumn($tableColumns, "message_delivery_time", false, 5, _("Received"), _("Sort On Received Date"));
+		$this->addColumn($tableColumns, "sent_representing_name", false, 3, _("From"), _("Sort on Sender"));
+		$this->addColumn($tableColumns, "message_delivery_time", false, 5, _("Received"), _("Sort on Received Date"));
 		
 		// Columns & Sort: Outbox & Sent Items
-		$this->addColumn($tableColumns, "display_to", false, 3, _("To"), _("Sort On Recipient"));
-		$this->addColumn($tableColumns, "client_submit_time", false, 5, _("Sent"), _("Sort On Sent Date"));
-		$this->addColumn($tableColumns, "last_modification_time", false, 5, _("Modification"), _("Sort On Modification Date"));
+		$this->addColumn($tableColumns, "display_to", false, 3, _("To"), _("Sort on Recipient"));
+		$this->addColumn($tableColumns, "client_submit_time", false, 5, _("Sent"), _("Sort on Sent Date"));
+		$this->addColumn($tableColumns, "last_modification_time", false, 5, _("Modification"), _("Sort on Modification Date"));
 
 		return $tableColumns;
 	}
@@ -264,16 +264,16 @@ class TableColumns {
 	function getTaskListTableColumns() {
 		$tableColumns = array();
 
-		$this->addColumn($tableColumns, "icon_index", true, 0, _("Icon"), _("Sort On Icon"), 25);
-		$this->addColumn($tableColumns, "complete", true, 1, _("Complete"), _("Sort On Complete"), 25);
-		$this->addColumn($tableColumns, "importance", true, 2, _("Priority"), _("Sort On Priority"));
-		$this->addColumn($tableColumns, "subject", true, 3, _("Subject"), _("Sort On Subject"), PERCENTAGE);
-		$this->addColumn($tableColumns, "duedate", true, 4, _("Due Date"), _("Sort On Due Date"));
-		$this->addColumn($tableColumns, "owner", true, 5, _("Owner"), _("Sort On Owner"));
-		$this->addColumn($tableColumns, "categories", false, 6, _("Categories"), _("Sort On Categories"));
-		$this->addColumn($tableColumns, "percent_complete", false, 7, _("% Completed"), _("Sort On Percent Completed"), 100);
+		$this->addColumn($tableColumns, "icon_index", true, 0, _("Icon"), _("Sort on Icon"), 25);
+		$this->addColumn($tableColumns, "complete", true, 1, _("Complete"), _("Sort on Complete"), 25);
+		$this->addColumn($tableColumns, "importance", true, 2, _("Priority"), _("Sort on Priority"));
+		$this->addColumn($tableColumns, "subject", true, 3, _("Subject"), _("Sort on Subject"), PERCENTAGE);
+		$this->addColumn($tableColumns, "duedate", true, 4, _("Due Date"), _("Sort on Due Date"));
+		$this->addColumn($tableColumns, "owner", true, 5, _("Owner"), _("Sort on Owner"));
+		$this->addColumn($tableColumns, "categories", false, 6, _("Categories"), _("Sort on Categories"));
+		$this->addColumn($tableColumns, "percent_complete", false, 7, _("% Completed"), _("Sort on Percent Completed"), 100);
 		$this->addColumn($tableColumns, "hidden_column", true, 8);
-		$this->addColumn($tableColumns, "startdate", true, 9, _("Start Date"), _("Sort On Start Date"));
+		$this->addColumn($tableColumns, "startdate", true, 9, _("Start Date"), _("Sort on Start Date"));
 		$this->addColumn($tableColumns, "recurring", false, 10, _("Recurring"), _("Sort on Recurring"));
 
 		return $tableColumns;
@@ -322,11 +322,11 @@ class TableColumns {
 	function getStickyNoteListTableColumns() {
 		$tableColumns = array();
 
-		$this->addColumn($tableColumns, "icon_index", true, 0, _("Icon"), _("Sort On Icon"));
-		$this->addColumn($tableColumns, "subject", true, 2, _("Subject"), _("Sort On Subject"), PERCENTAGE);
-		$this->addColumn($tableColumns, "body", false, 2, _("Body"), _("Sort On Body"));
-		$this->addColumn($tableColumns, "creation_time", true, 3, _("Created"), _("Sort On Created"));
-		$this->addColumn($tableColumns, "categories", false, 4, _("Categories"), _("Sort On Categories"));
+		$this->addColumn($tableColumns, "icon_index", true, 0, _("Icon"), _("Sort on Icon"));
+		$this->addColumn($tableColumns, "subject", false, 1, _("Subject"), _("Sort on Subject"), PERCENTAGE);
+		$this->addColumn($tableColumns, "body", true, 2, _("Body"), _("Sort on Body"), PERCENTAGE);
+		$this->addColumn($tableColumns, "creation_time", true, 3, _("Created"), _("Sort on Created"));
+		$this->addColumn($tableColumns, "categories", false, 4, _("Categories"), _("Sort on Categories"));
 
 		return $tableColumns;
 	}
