@@ -189,6 +189,16 @@
 		{
 		    if($this->indent)
     			$this->xml .= str_repeat("\t",$this->depth);
+
+			/**
+			 * When converting a float value into a string PHP replaces the decimal point into a 
+			 * comma if the language settings are set to a language that uses the comma as a decimal
+			 * separator. This check makes sure only a decimal point is used in the XML.
+			 */
+			if(is_float($value)){
+				$value = str_replace(',','.',strval($value));
+			}
+
 			$this->xml .= "<" . $tagName . ">" . xmlentities($value) . "</" . $tagName . ">";
 			if($this->indent)
 			    $this->xml .= "\n";
