@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -82,12 +84,12 @@
 
 	// used by distribution lists
 	define("DL_GUID",    pack("H*", "C091ADD3519DCF11A4A900AA0047FAA4"));
-	define("DL_USER",    0xC3);
-	define("DL_USER2",   0xD3);
-	define("DL_USER3",   0xE3);
-	define("DL_DIST",    0xB4);
-	define("DL_USER_AB", 0xB5);
-	define("DL_DIST_AB", 0xB6);
+	define("DL_USER",    0xC3);		//	195
+	define("DL_USER2",   0xD3);		//	211
+	define("DL_USER3",   0xE3);		//	227
+	define("DL_DIST",    0xB4);		//	180
+	define("DL_USER_AB", 0xB5);		//	181
+	define("DL_DIST_AB", 0xB6);		//	182
 
 				
 
