@@ -602,10 +602,15 @@ function sq_deent(&$attvalue, $regex, $hex=false){
             if ($hex){
                 $numval = hexdec($numval);
             }
-            $repl{$matches[0][$i]} = chr($numval);
+            if($numval < 128)
+                $repl{$matches[0][$i]} = chr($numval);
+        }
+        if(count($repl) > 0) {
+            $attvalue = strtr($attvalue, $repl);
+            return true;
+        } else {
+            return false;
         }
-        $attvalue = strtr($attvalue, $repl);
-        return true;
     } else {
         return false;
     }
@@ -737,7 +742,6 @@ function sq_fixatts($tagname,
  * @param  $sQuote          quoting characters around url's
  */
 function sq_fix_url($attname, &$attvalue, $message, $id, $mailbox,$sQuote = '"') {
-    return $attvalue;
 }
 
 /**
@@ -796,7 +800,10 @@ function sq_fixstyle($body, $pos, $message, $id, $mailbox){
                         $i = strpos($body,'-->',$i+3);
                         if ($i === false) { // no end comment
                             $i = strlen($body);
-                        }
+                        } else {
+							// add length of '-->'
+							$i = $i + 2;
+						}
                         $sToken = '';
                     }
                 } else {
