@@ -377,7 +377,7 @@
 			$data["column"] = $this->ab_tablecolumns;
 
 			$this->sort = array();
-			$this->sort[$this->ab_properties['account']] = TABLE_SORT_ASCEND;
+			$this->sort[$this->ab_properties['display_name']] = TABLE_SORT_ASCEND;
 			
 			$firstSortColumn = array_shift(array_keys($this->sort));
 
@@ -525,7 +525,7 @@
 							$item["search_key"] = bin2hex($user_data[$this->ab_properties["search_key"]]);
 
 							// Contacts from the GAL have email-address saved in smtp_address property.
-							if($item["email_address"].trim() == "") {
+							if(trim($item["email_address"]) == "") {
 								$item["email_address"] = $item["smtp_address"];
 							}
                             break;
