@@ -84,10 +84,6 @@
 						case "search":
 							// get properties and column info
 							$this->getColumnsAndPropertiesForMessageType($store, $entryid, $action);
-							// @TODO:	get the sort data from sort settings
-							//			not working now, as of sorting is not suppported by table widget.
-							$this->sort[$this->properties["subject"]] = TABLE_SORT_ASCEND;
-	
 							$result = $this->search($store, $entryid, $action);
 							break;
 						case "updatesearch":
@@ -149,7 +145,7 @@
 					} else {
 						// no JSON extension installed
 						$errorInfo = array();
-						$errorInfo["error_message"] = _("Install JSON extension for PHP to use this feature") . ".";
+						$errorInfo["error_message"] = _("The JSON extention for PHP is required to use this feature. Please inform your system administrator.") . ".";
 						$errorInfo["original_error_message"] = "JSON extension for PHP is not installed.";
 						$this->searchRestriction = false;
 
