@@ -100,8 +100,20 @@
 					if(strlen($exceptionProps['body']) == 0){
 						unset($exceptionProps['body'], $exceptionProps['isHTML']);
 					}
+
+					/**
+					 * If recurring item has set reminder to true then
+					 * all occurrences before the 'flagdueby' value(of recurring item)
+					 * should not show that reminder is set.
+					 */
+					if ($data['item']['reminder'] == 1 && !(isset($exceptionProps['reminder']) && $exceptionProps['reminder'] == 0)) {
+						$flagDueByDay = $recur->dayStartOf($data['item']['flagdueby']['attributes']['unixtime']);
+
+						if ($flagDueByDay > $basedate)	$exceptionProps['reminder'] = false;
+					}
+
 					$data["item"] = array_merge($data['item'], $exceptionProps);
-                
+
             	    // The entryid should be the entryid of the main message, not that of the attachment
             	    $data["item"]["entryid"] = bin2hex($entryid);
                     
@@ -128,7 +140,18 @@
 				$data["item"]["commonstart"] = $data["item"]["startdate"];
 				$data["item"]["commonend"] = $data["item"]["duedate"];
 				unset($data["item"]["reminder_time"]);
-				
+
+				/**
+				 * If recurring item has set reminder to true then
+				 * all occurrences before the 'flagdueby' value(of recurring item)
+				 * should not show that reminder is set.
+				 */
+				if ($data['item']['reminder'] == 1) {
+					$flagDueByDay = $recur->dayStartOf($data['item']['flagdueby']['attributes']['unixtime']);
+
+					if ($flagDueByDay > $basedate)	$data["item"]['reminder'] = false;
+				}
+
 				array_push($this->responseData["action"], $data);
 				$GLOBALS["bus"]->addData($this->responseData);
 				return;
@@ -170,20 +193,32 @@
 			$messageProps = $GLOBALS["operations"]->saveAppointment($store, $parententryid, $action);
 
 			// Notify the bus if the save was OK
-			if($messageProps && !(is_array($messageProps) && isset($messageProps['error'])) ){
+			if($messageProps && !(is_array($messageProps) && isset($messageProps['error'])) && !isset($messageProps["remindertimeerror"]) ){
 				$GLOBALS["bus"]->notify(bin2hex($parententryid), TABLE_SAVE, $messageProps);
 				$result = true;
 			}
 
-
-			// Recurring but non-existing exception (same as normal open, but add basedate, startdate and enddate)
-			$data = array();
-			$data["attributes"] = array("type" => "saved");
-			$data["meeting_request_saved"] = ($result) ? '1' : '0';
-			$data["sent_meetingrequest"] = ($result && !empty($action['send'])) ? '1' : '0';
-			if(is_array($messageProps) && isset($messageProps['error'])){
-				$data["errorcode"] = $messageProps['error'];
-				$data["displayname"] = $messageProps['displayname'];
+			//for reminder time
+			if(!$result && isset($messageProps['remindertimeerror']) && !$messageProps["remindertimeerror"]){
+				$data = array();
+				$data["attributes"] = array("type" => "saved");
+				$data["remindertime"] = "remindertime";
+				$data["error_message"] = _("Cannot set a reminder to appear before the previous occurence. Reset reminder to save the change");
+			}else if (isset($messageProps['isexceptionallowed']) && $messageProps["isexceptionallowed"] === 'false'){
+				$data = array();
+				$data["attributes"] = array("type" => "saved");
+				$data["proposetime"] = "proposetime";
+				$data["error_message"] = _("Two occurrences cannot occur on the same day");
+			}else{
+				// Recurring but non-existing exception (same as normal open, but add basedate, startdate and enddate)
+				$data = array();
+				$data["attributes"] = array("type" => "saved");
+				$data["meeting_request_saved"] = ($result) ? '1' : '0';
+				$data["sent_meetingrequest"] = ($result && !empty($action['send'])) ? '1' : '0';
+				if(is_array($messageProps) && isset($messageProps['error'])){
+					$data["errorcode"] = $messageProps['error'];
+					$data["displayname"] = $messageProps['displayname'];
+				}
 			}
 			
 			array_push($this->responseData["action"], $data);
