@@ -151,6 +151,7 @@
 					$data["attributes"] = array("type" => "list");
 					$data["column"] = $this->tablecolumns;
 					$data["item"] = $this->getCalendarItems($store, $entryid, $this->startdate, $this->enddate);
+					$data["restriction"] = $action["restriction"];	// Send restriction back to client
 	
 					array_push($this->responseData["action"], $data);
 					$GLOBALS["bus"]->addData($this->responseData);
@@ -261,26 +262,21 @@
 			if(isset($item["private"]) && $item["private"] == true) {
 				// check for delegate permissions
 				if($this->storeProviderGuid[PR_MDB_PROVIDER] == ZARAFA_STORE_DELEGATE_GUID) {
-					$hideItemData = false;
-
-					if($this->localFreeBusyFolder === false) {
-						$hideItemData = true;
-					}
+					$hideItemData = true;
 
 					// find delegate properties
 					if($this->localFreeBusyFolder !== false) {
 						$localFreeBusyFolderProps = mapi_getprops($this->localFreeBusyFolder, array(PR_SCHDINFO_DELEGATE_ENTRYIDS, PR_DELEGATES_SEE_PRIVATE));
-						if(mapi_last_hresult() !== NOERROR) {
-							// no delegate properties exists
-							$hideItemData = true;
-						} else {
-							// if more then one delegates info is stored then find index of 
-							// current user
-							$userEntryId = $GLOBALS["mapisession"]->getUserEntryID();
-							$userIndex = array_search($userEntryId, $localFreeBusyFolderProps[PR_SCHDINFO_DELEGATE_ENTRYIDS]);
+						if(mapi_last_hresult() === NOERROR) {
+							if(isset($localFreeBusyFolderProps[PR_SCHDINFO_DELEGATE_ENTRYIDS]) && isset($localFreeBusyFolderProps[PR_DELEGATES_SEE_PRIVATE])) {
+								// if more then one delegates info is stored then find index of 
+								// current user
+								$userEntryId = $GLOBALS["mapisession"]->getUserEntryID();
+								$userIndex = array_search($userEntryId, $localFreeBusyFolderProps[PR_SCHDINFO_DELEGATE_ENTRYIDS]);
 
-							if($userIndex === false || $localFreeBusyFolderProps[PR_DELEGATES_SEE_PRIVATE][$userIndex] === 0) {
-								$hideItemData = true;
+								if($userIndex !== false && $localFreeBusyFolderProps[PR_DELEGATES_SEE_PRIVATE][$userIndex] === 1) {
+									$hideItemData = false;
+								}
 							}
 						}
 					}
@@ -321,7 +317,7 @@
 				
 				if($messageProps["isexceptionallowed"] === "false"){
 					$data["action_type"] = "moveoccurence";
-					$data["error_message"] = _("Unable to reschedule occurrence: Either the new occurrence skips over an existing occurrence, or an occurrence is already present on this day");
+					$data["error_message"] = _("Unable to reschedule occurrence: either the new occurrence skips over an existing occurrence, or an occurrence is already present on this day.");
 				}
  				array_push($this->responseData["action"],$data);
  				$GLOBALS["bus"]->addData($this->responseData);
@@ -335,7 +331,17 @@
 
 				array_push($this->responseData["action"], $data);
 				$GLOBALS["bus"]->addData($this->responseData);
-			}
+			} else if(isset($messageProps["remindertimeerror"])) {
+				$data = array();
+				$data["attributes"] = array("type" => "failed");
+				
+				if(!$messageProps["remindertimeerror"]){
+					$data["action_type"] = "remindertime";
+					$data["error_message"] = _("Cannot set a reminder to appear before the previous occurence. Reset reminder to save the change");
+				}
+ 				array_push($this->responseData["action"],$data);
+ 				$GLOBALS["bus"]->addData($this->responseData);
+ 			}
 
 			// Send notifications that this object has changed
 			if($messageProps){
