@@ -120,6 +120,9 @@
 						case "copy":
 							$result = $this->copy($store, $parententryid, $entryid, $action);
 							break;
+						case "convert_contact":
+							$result = $this->getContactData($store, $entryid, $action);
+							break;
 					}
 				}
 			}
@@ -127,6 +130,61 @@
 			return $result;
 		}
 
+
+		/**
+		 * Function which get data of selected contacts to send as response
+		 * @param object $store MAPI Message Store Object
+		 * @param string $parententryid entryid of the message
+		 * @param array $action the action data, sent by the client
+		 * @return boolean true on success or false on failure 
+		 */
+		function getContactData($store, $parententryid, $action)
+		{
+			$result = false;
+			if($store){
+				if(isset($action["messages"]["message"]) && is_array($action["messages"]["message"])){
+
+					if (!isset($action["messages"]["message"][0])){
+						$msg = array($action["messages"]["message"]);
+					}else{
+						$msg = $action["messages"]["message"];
+					}
+
+					$data = array();
+					$data["attributes"] = array("type" => "convert_contact");
+					$data["item"] = array();
+					$data["targetfolder"] = $action["targetfolder"];
+					$data["targetfolderentryid"] = $action["parententryid"];
+
+					foreach($msg as $messageItem){
+						$items = array();
+						$message = mapi_msgstore_openentry($store, hex2bin($messageItem['id']));
+						// check the message type to get respective properties
+						if($messageItem['type'] == DistList){
+							$props = mapi_getprops($message, array(PR_DISPLAY_NAME, PR_MESSAGE_CLASS, PR_BODY, PR_OBJECT_TYPE));
+
+							$memberItem = $GLOBALS["operations"]->expandDistributionList($store, hex2bin($messageItem['id']), false, $GLOBALS["properties"]->getContactABProperties(), $GLOBALS["properties"]->getAddressBookProperties());
+							
+							$items["dl_name"] = w2u($props[PR_DISPLAY_NAME]);
+							$items["message_class"] = w2u($props[PR_MESSAGE_CLASS]);
+							$items["body"] = w2u($props[PR_BODY]);
+							$items["objecttype"] = $props[PR_OBJECT_TYPE];
+							$items["addrtype"] = "ZARAFA";
+							$items["members"] = array("member"=>$memberItem);
+						}else{
+							$items = $GLOBALS["operations"]->getMessageProps($store, $message, $this->properties, true);
+						}
+						array_push($data["item"], $items);
+					}
+
+					array_push($this->responseData["action"], $data);
+					$GLOBALS["bus"]->addData($this->responseData);
+					$result = true;
+				}
+			}
+			return $result;
+		}
+
 		/**
 		 * Function which retrieves a list of contacts in a contact folder.
 		 * search restriction if present then it will overwrite character restriction
@@ -370,4 +428,4 @@
 			}
 		}
 	}
-?>
+?>
\ No newline at end of file
