@@ -182,7 +182,7 @@
 						// Open store (this => $GLOBALS['mapisession'])
 						$copyAttachmentsStore = $GLOBALS['mapisession']->openMessageStore($copyAttachmentsStore);
 							
-						if ($action["message_action"]["action_type"] == "reply" || $action["message_action"]["action_type"] == "replyall") {
+						if ($action["message_action"]["action_type"] == "reply" || $action["message_action"]["action_type"] == "replyall" || $action["message_action"]["action_type"] == "edit") {
 							$copy_only_inline_attachments = true;
 							$replyOrigMessageDetails = array(
 								"entryid"=>$action["message_action"]["entryid"],
@@ -345,9 +345,7 @@
 						
 						// Use the storeid of that belongs to the message_action entryid.
 						// This is in case the message is on another store.
-						if(isset($action["store"])) {
-							$storeOrigMsg = $GLOBALS["mapisession"]->openMessageStore(hex2bin($action["message_action"]["storeid"]));
-						}
+						$storeOrigMsg = $GLOBALS["mapisession"]->openMessageStore(hex2bin($action["message_action"]["storeid"]));
 
 						$message_action_props = array();
 						$message_action_result = $GLOBALS["operations"]->saveMessage($storeOrigMsg, $parententryid, $props, false, array(), $message_action_props);
