@@ -101,8 +101,6 @@
 					switch($action["attributes"]["type"])
 					{
 						case "open":
-							// Before opening restore the archived message if it is a stub
-							$this->destub($store, bin2hex($parententryid), $entryid);
 							$result = $this->open($store, $entryid, $action);
 							break;
 						case "save":
@@ -149,12 +147,18 @@
 							$originalMessageProps = mapi_getprops($message, array(PR_MESSAGE_CLASS));
 							$req = new Meetingrequest($store, $message, $GLOBALS["mapisession"]->getSession());
 
+							// Update extra body information
+							if(isset($action['meetingTimeInfo']) && strlen($action['meetingTimeInfo'])) {
+								$req->setMeetingTimeInfo($action['meetingTimeInfo']);
+								unset($action['meetingTimeInfo']);
+							}
+							
 							// sendResponse flag if it is set then send the mail response to the organzer.
 							$sendResponse = true;
 							if(isset($action["noResponse"]) && $action["noResponse"] == "true") {
 								$sendResponse = false;
 							}
-							$body = isset($action["body"]) ? $action["body"] : false;
+							$body = isset($action["body"]) ? u2w($action["body"]) : false;
 
 							if($action["attributes"]["type"] == 'acceptMeetingRequest') {
 								$tentative = isset($action["tentative"]) ? $action["tentative"] : false;
@@ -163,7 +167,6 @@
 
 								// We are accepting MR from preview-read-mail so set delete the actual mail flag.
 								$delete = (stristr($originalMessageProps[PR_MESSAGE_CLASS], 'IPM.Schedule.Meeting') !== false) ? true : false;
-
 								$req->doAccept($tentative, $sendResponse, $delete, $newProposedStartTime, $newProposedEndTime, $body, true, $store, $basedate);
 							} else {
 								$delete = $req->doDecline($sendResponse, $store, $basedate, $body);
@@ -201,14 +204,14 @@
 							$result = $this->resolveConflict($store, $parententryid, $entryid, $action);
 							break;
 
+						case "attach_items":
+							$result = $this->forwardMultipleItems($store, $parententryid, $action);
+							break;
+
 						//this will convert selected message into message of particular target folder.
 						case "convert_item":
 							$result = $this->getItemData($store, $parententryid, $action);
 							break;
-
-						case "attach_items":
-							$result = $this->forwardMultipleItems($store, $parententryid, $action);
-							break;
 							
 						case "getAttachments":
 							// Get list of uploaded attachments.
@@ -229,12 +232,13 @@
 							if ($action["attributes"]["type"] == "acceptTaskRequest") {
 								$result = $tr->doAccept(_("Task Accepted:") . " ");
 							} else {
-								$tr->doDecline(_("Task Declined:") . " ");
+								$result = $tr->doDecline(_("Task Declined:") . " ");
 							}
+
 							// Notify Inbox that task request has been deleted
-							if (isset($result) && $result) {
+							if (is_array($result))
 								$GLOBALS["bus"]->notify(bin2hex($result[PR_PARENT_ENTRYID]), TABLE_DELETE, $result);
-							}
+
 							mapi_savechanges($message);
 							$result = true;
 							break;
@@ -245,6 +249,41 @@
 			return $result;
 		}
 
+		/**
+		 * Function which sets selected messages as attachment to the item
+		 * @param object $store MAPI Message Store Object
+		 * @param string $parententryid entryid of the message
+		 * @param array $action the action data, sent by the client
+		 * @return boolean true on success or false on failure 
+		 */
+		function forwardMultipleItems($store, $parententryid, $action)
+		{
+			$result = false;
+			
+			if($store){
+				if(isset($action["entryids"]) && $action["entryids"]){
+					
+					if(!is_array($action["entryids"])){
+						$action["entryids"] = array($action["entryids"]);
+					}
+
+					//add attach items to session variables
+					$attachments = $GLOBALS["operations"]->setAttachmentInSession($store, $action["entryids"], $action["dialog_attachments"]);
+				}
+
+				$data = array();
+				$data["attributes"] = array("type" => "attach_items");
+				$data["item"] = array();
+				$data["item"]["parententryid"] = bin2hex($parententryid);
+				$data["item"]["attachments"] = $attachments;
+				array_push($this->responseData["action"], $data);
+				$GLOBALS["bus"]->addData($this->responseData);
+				$result = true;
+			}
+			return $result;
+		}
+
+
 		/**
 		 * Function which get data of selected messages to send as response
 		 * @param object $store MAPI Message Store Object
@@ -320,41 +359,6 @@
 			}
 			return $result;
 		}
-
-		/**
-		 * Function which sets selected messages as attachment to the item
-		 * @param object $store MAPI Message Store Object
-		 * @param string $parententryid entryid of the message
-		 * @param array $action the action data, sent by the client
-		 * @return boolean true on success or false on failure 
-		 */
-		function forwardMultipleItems($store, $parententryid, $action)
-		{
-			$result = false;
-			
-			if($store){
-				if(isset($action["entryids"]) && $action["entryids"]){
-					
-					if(!is_array($action["entryids"])){
-						$action["entryids"] = array($action["entryids"]);
-					}
-
-					//add attach items to session variables
-					$attachments = $GLOBALS["operations"]->setAttachmentInSession($store, $action["entryids"], $action["dialog_attachments"]);
-				}
-
-				$data = array();
-				$data["attributes"] = array("type" => "attach_items");
-				$data["item"] = array();
-				$data["item"]["parententryid"] = bin2hex($parententryid);
-				$data["item"]["attachments"] = $attachments;
-				array_push($this->responseData["action"], $data);
-				$GLOBALS["bus"]->addData($this->responseData);
-				$result = true;
-			}
-
-			return $result;
-		}
 		
 		/**
 		 * Function which opens an item.
@@ -508,24 +512,16 @@
 							if (is_bool($meetingConflicts) && $meetingConflicts) {
 								$data["item"]["meetingconflicting"] = _('Conflicts with another appointment on your Calendar.');
 							} else if ($meetingConflicts) {
-								if ($meetingConflicts > 1) $data["item"]["meetingconflicting"] = $meetingConflicts .' '._('instances of this recurring appointment conflicts with other appointments on your Calendar.');
-								else $data["item"]["meetingconflicting"] = $meetingConflicts .' '._('instance of this recurring appointment conflicts with other appointment on your Calendar.');
+								if ($meetingConflicts > 1) $data["item"]["meetingconflicting"] = sprintf(_('%s occurrences of this recurring appointment conflict with other appointments on your Calendar.'), $meetingConflicts);
+								else $data["item"]["meetingconflicting"] = sprintf(_('%s occurrence of this recurring appointment conflicts with other appointment on your Calendar.'), $meetingConflicts);
 							}
 						}
-
-						// We received a meeting request, show it to the user
-						$data["item"]["ismeetingrequest"] = 1;
-						// Show user whether meeting request conflict with other appointment or not.
-						$meetingConflicts = $req->isMeetingConflicting();
-						/**
-						 * if $meetingConflicts is boolean and true then its a normal meeting.
-						 * if $meetingConflictis is integer then it indicates no of instances of a recurring meeting which conflicts with Calendar.
-						 */
-						if (is_bool($meetingConflicts) && $meetingConflicts) {
-							$data["item"]["meetingconflicting"] = _('Conflicts with another appointment on your Calendar.');
-						} else if ($meetingConflicts) {
-							if ($meetingConflicts > 1) $data["item"]["meetingconflicting"] = $meetingConflicts .' '._('instances of this recurring appointment conflicts with other appointments on your Calendar.');
-							else $data["item"]["meetingconflicting"] = $meetingConflicts .' '._('instance of this recurring appointment conflicts with other appointment on your Calendar.');
+					} else if($req->isMeetingCancellation()) {
+						if(!$req->isLocalOrganiser()) {
+							// Let's do some processing of this Meeting Cancellation Object we received
+							$req->processMeetingCancellation();
+							// We received a cancellation request, show it to the user
+							$data["item"]["ismeetingcancel"] = 1;
 						}
 					}
 				}
@@ -876,45 +872,5 @@
 			array_push($this->responseData["action"], $data);
 			$GLOBALS["bus"]->addData($this->responseData);
 		}
-
-		/**
-		 * Function which destubs an archived item.
-		 * @param object $store MAPI Message Store Object
-		 * @param string $entryid list of entryids which will be copied or moved
-		 * @param string $parententryid entryid of the folder
-		 * @return boolean true on success or false on failure
-		 */
-		function destub($store, $parententryid, $entryid)
-		{
-			$result = false;
-			
-			if($store && $parententryid && $entryid) {
-				// Check if this message is an archived stub message
-				if($GLOBALS["zArchiverOperations"]->isStubbed($store, $entryid)){
-					// Destub the message
-					$result = $GLOBALS["zArchiverOperations"]->destub($store, $entryid);
-					if($result){
-						$storeProps = mapi_getprops($store, Array(PR_STORE_ENTRYID));
-						$props = Array(
-							PR_STORE_ENTRYID => $storeProps[PR_STORE_ENTRYID],
-							PR_PARENT_ENTRYID => hex2bin($parententryid),
-							PR_ENTRYID => $entryid
-						);
-						// Notify the other modules about the updated message
-						$GLOBALS["bus"]->notify($parententryid, TABLE_SAVE, $props);
-					}else{
-						// Destubbing message did not succeed
-						$errorMessage = _("Unable to restore archived message") . ".";
-						/**
-						 * The third argument set to false will mean the responsedata of the 
-						 * feedback will not be added to the Bus just yet. This will happen when the
-						 * open call is done and adds theirs.
-						 */
-						$this->sendFeedback(false, $errorMessage, false);
-					}
-				}
-			}
-			return $result;
-		}
 	}
 ?>
\ No newline at end of file
