@@ -273,18 +273,19 @@
 				$data["sort"] = array();
 				$data["sort"]["attributes"] = array();
 				$data["sort"]["attributes"]["direction"] = (isset($this->sort[$firstSortColumn]) && $this->sort[$firstSortColumn] == TABLE_SORT_ASCEND) ? "asc" : "desc";
-				$data["sort"]["_content"] = array_search($firstSortColumn, $this->properties);
-				
+				/**
+				 * If MV_INSTANCE flag is set then remove it,
+				 * It is added in parseSortOrder function to allow multiple instances.
+				 */
+				$data["sort"]["_content"] = array_search($firstSortColumn &~ MV_INSTANCE, $this->properties);
+
 				// Get the table and merge the arrays
 				$items = $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, $this->start, false, $this->searchRestriction, $this->generateRecipient);
 
-				// if disablePrivateItem is available in listmodule then disable private appointments.
-				if(method_exists($this, disablePrivateItem)) {
-					foreach ($items["item"] as &$value)
-					{
-						// Disable private items
-						$value = $this->disablePrivateItem($value);
-					}
+				for($i=0; $i<count($items["item"]); $i++)
+				{
+					// Disable private items
+					$items["item"][$i] = $this->disablePrivateItem($items["item"][$i]);
 				}
 
 				$data = array_merge($data, $items);
@@ -394,8 +395,8 @@
 
 			// Generate output sort
 			$data["sort"] = array();
-			$data["sort"] = $this->generateSortOrder(array());		// we don't want any custom mapping of properties
-																	// so pass empty array in parameter
+			$data["sort"] = $this->generateSortOrder(array());		// we don't want any custom mapping of properties so pass empty array in parameter
+			$data["has_sorted_results"] = $action["sort_result"];	// we use this as a flag; to keep difference between default search request and a sorting request
 
 			// Wait until we have some data, no point in returning before we have data. Stop waiting after 10 seconds
 			$start = time();
@@ -479,10 +480,10 @@
 			}
 
 			$rowCount = $GLOBALS["settings"]->get("global/rowcount", 50);
-			$numberOfResults = count($this->searchResults);		// searchResults contains entryids of messages
-																// that are already sent to the server
+			// searchResults contains entryids of messages
+			// that are already sent to the server
+			$numberOfResults = count($this->searchResults);
 
-			$data = array();
 			if($numberOfResults < $rowCount) {
 				$items = mapi_table_queryallrows($table, array(PR_ENTRYID, PR_LAST_MODIFICATION_TIME));
 
@@ -505,12 +506,14 @@
 					}
 
 					if($sendItemToClient) {
-						$data = array();
-						$data["attributes"] = array("type" => "item", "searchfolder" => $this->searchFolderEntryId);
-						$data["item"] = $GLOBALS["operations"]->getMessageProps($store, $GLOBALS["operations"]->openMessage($store, $props[PR_ENTRYID]), $this->properties);
+						$itemData = array();
+						$itemData["attributes"] = array("type" => "item", "searchfolder" => $this->searchFolderEntryId);
+						// only get primitive properties, no need to get body, attachments or recipient information
+						$itemData["item"] = $GLOBALS["operations"]->getProps($store, $GLOBALS["operations"]->openMessage($store, $props[PR_ENTRYID]), $this->properties);
 						// store entryid => last_modification_time mapping
 						$this->searchResults[bin2hex($props[PR_ENTRYID])] = $props[PR_LAST_MODIFICATION_TIME];
-						array_push($this->responseData["action"], $data);
+
+						array_push($this->responseData["action"], $itemData);
 					}
 
 					// when we have more results then fit in the client, we break here,
@@ -522,18 +525,18 @@
 				}
 			}
 
-			$numberOfResults = mapi_table_getrowcount($table);
+			$totalRowCount = mapi_table_getrowcount($table);
 
 			$data = array();
 			$data["attributes"] = array("type" => "search");
 			$data["searchfolderentryid"] = array("attributes" => array("type" => "binary"), "_content" => $this->searchFolderEntryId);
 			$data["searchstate"] = $searchState;
-			$data["results"] = $numberOfResults;
+			$data["results"] = $numberOfResults;		// actual number of items that we are sending to client
 
 			$data["page"] = array();
 			$data["page"]["start"] = 0;
 			$data["page"]["rowcount"] = $rowCount;
-			$data["page"]["totalrowcount"] = $numberOfResults;
+			$data["page"]["totalrowcount"] = $totalRowCount;	// total number of items
 
 			array_push($this->responseData["action"], $data);
 			$GLOBALS["bus"]->addData($this->responseData);
@@ -865,13 +868,14 @@
 				$userstore = mapi_openmsgstore($GLOBALS["mapisession"]->getSession(),$inboxprops[PR_STORE_ENTRYID]);
 				$userstoreprops = mapi_getprops($userstore, Array(PR_MAILBOX_OWNER_NAME));
 
-				// open the mail to fetch the subject and body.
+				// open the mail to fetch the subject, body and importance.
 				$message = mapi_msgstore_openentry($store, $entryid);
-				$msgprops= mapi_getprops($message, Array(PR_SUBJECT, PR_BODY));
+				$msgprops= mapi_getprops($message, Array(PR_SUBJECT, PR_BODY, PR_IMPORTANCE));
 
 				$props = array ('message_class' => 'IPM.Task',
 								'icon_index' => '1280',
 								'subject' => w2u($msgprops[PR_SUBJECT]),
+								'importance' => $msgprops[PR_IMPORTANCE],
 								'body' => w2u($msgprops[PR_BODY]),
 								'owner' => w2u($userstoreprops[PR_MAILBOX_OWNER_NAME]),
 								'complete' => "false",
@@ -1089,5 +1093,18 @@
 			
 			$GLOBALS["bus"]->addData($this->responseData);
 		}
+
+		/**
+		 * Placeholder function
+		 * This function will be overridden by child classes
+		 * Basically, function will to remove some properties when the item is private
+		 * and it will also check for delegate permissions.
+		 * @param object $item item properties
+		 * @return object $item item with modified properties
+		 */
+		function disablePrivateItem($item) 
+		{
+			return $item;
+		}
 	}
 ?>
