@@ -377,7 +377,7 @@
 			$this->parseSearchRestriction($action);
 
 			// Sort
-			$this->parseSortOrder($action);
+			$this->parseSortOrder($action, null, true);
 				
 			// List columns visible
 			$GLOBALS["TableColumns"]->parseVisibleColumns($this->tablecolumns, $action);
@@ -391,7 +391,12 @@
 			$data["sort"] = array();
 			$data["sort"]["attributes"] = array();
 			$data["sort"]["attributes"]["direction"] = (isset($this->sort[$firstSortColumn]) && $this->sort[$firstSortColumn] == TABLE_SORT_ASCEND) ? "asc":"desc";
-			$data["sort"]["_content"] = array_search($firstSortColumn, $this->properties);
+
+			/**
+			 * If MV_INSTANCE flag is set then remove it,
+			 * It is added in parseSortOrder function to allow multiple instances.
+			 */
+			$data["sort"]["_content"] = array_search($firstSortColumn &~ MV_INSTANCE, $this->properties);
 				
             // Return some information about the folder. The entryid and storeid may be unknown to the client if it passed
             // an empty storeid and folder entryid.
