@@ -121,6 +121,12 @@
 					$data["item"]["message_class"] = $msgClass;
 					$data["item"]["message_flags"] = $msgFlags;
 
+					// Also send taskrequest entryids
+					$data["item"]['taskrequest'] = array();
+					$data["item"]['taskrequest']['entryid'] = $action['entryid'];
+					$data["item"]['taskrequest']['parententryid'] = $action['parententryid'];
+					$data["item"]['taskrequest']['storeid'] = $action['store'];
+
 					array_push($this->responseData["action"], $data);
 					$GLOBALS["bus"]->addData($this->responseData);
 
