@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -62,15 +64,9 @@
 		function PrintListModule($id, $data)
 		{
 			$this->properties = $GLOBALS["properties"]->getAppointmentProperties();
-			
-			$this->tablecolumns = array();
-			$this->addColumn($this->tablecolumns, "icon_index", true, 0, _("Icon Index"), _("Sort on Icon Index"));
-			$this->addColumn($this->tablecolumns, "subject", true, 1, _("Subject"), _("Sort on Subject"), PERCENTAGE);
-			$this->addColumn($this->tablecolumns, "start", true, 2, _("Startdate"), _("Sort on Startdate"));
-			$this->addColumn($this->tablecolumns, "end", true, 3, _("Enddate"), _("Sort on Enddate"));
-			$this->addColumn($this->tablecolumns, "recurring", true, 4, _("Recurring"), _("Sort on Recurring"));
-			$this->addColumn($this->tablecolumns, "busystatus", true, 5, _("Busy Status"), _("Sort on Busy Status")); 
-			$this->addColumn($this->tablecolumns, "categories", false, 4, _("Categories"), _("Sort On Categories"));
+
+			// tablecolumns of appointmentlistmodule is used here
+			$this->tablecolumns = $GLOBALS["TableColumns"]->getAppointmentListTableColumns();
 
 			parent::ListModule($id, $data);
 
@@ -152,82 +148,38 @@
 														 )
 												   )
 											 ),
-									   // OR
-									   Array(RES_OR,
-											 Array(
-												   // OR
-												   // (EXIST(recurrence_enddate_property) && item[isRecurring] == true && (item[end] < item[start] || item[end] >= start))
-												   Array(RES_AND,
-														 Array(
-															   Array(RES_EXIST,
-																	 Array(ULPROPTAG => $this->properties["enddate_recurring"],
-																		   )
-																	 ),
-															   Array(RES_PROPERTY,
-																	 Array(RELOP => RELOP_EQ,
-																		   ULPROPTAG => $this->properties["recurring"],
-																		   VALUE => true
-																		   )
-																	 ),
-															   Array(RES_OR,
-															   		// This is a hack. If we can see that the enddate_recurring is BEFORE the startdate, 
-															   		// then the enddate_recurring is bogus and we should ignore it!
-															   		Array(
-																		Array(RES_COMPAREPROPS,
-																			Array(RELOP => RELOP_LT,
-																				ULPROPTAG1 => $this->properties["enddate_recurring"],
-																				ULPROPTAG2 => $this->properties["startdate"]
-																			)
-																		),
-																	
-																		
-																	   Array(RES_PROPERTY,
-																			 Array(RELOP => RELOP_GE,
-																				   ULPROPTAG => $this->properties["enddate_recurring"],
-																				   VALUE => $start
-																				   )
-																			 )
-																		)
-																	)
-															   )
-														 ),
-												   // OR
-												   // (!EXIST(recurrence_enddate_property) && item[isRecurring] == true && item[start] <= end)
-
-												   Array(RES_AND,
-														 Array(
-															   Array(RES_NOT,
-																	 Array(
-																		   Array(RES_EXIST,
-																				 Array(ULPROPTAG => $this->properties["enddate_recurring"]
-																					   )
-																				 )
-																		   )
-																	 ),
-															   Array(RES_PROPERTY,
-																	 Array(RELOP => RELOP_LE,
-																		   ULPROPTAG => $this->properties["startdate"],
-																		   VALUE => $end
-																		   )
-																	 ),
-															   Array(RES_PROPERTY,
-																	 Array(RELOP => RELOP_EQ,
-																		   ULPROPTAG => $this->properties["recurring"],
-																		   VALUE => true
-																		   )
-																	 )
-															   )
-														 )
-												   )
-											 ) // EXISTS OR
-									   )
-								 );		// global OR
+										//OR
+										//(item[isRecurring] == true)
+										Array(RES_PROPERTY,
+											Array(RELOP => RELOP_EQ,
+												ULPROPTAG => $this->properties["recurring"],
+												VALUE => true
+													)
+											)		
+									)
+							);// global OR
 
 			$folder = mapi_msgstore_openentry($store, $entryid);
 			$table = mapi_folder_getcontentstable($folder);
 			$calendaritems = mapi_table_queryallrows($table, $this->properties, $restriction);
 			$storeProviderGuid = mapi_getprops($store, array(PR_MDB_PROVIDER));
 			
+			// open localfreebusy folder for delegate permissions
+			$rootFolder = mapi_msgstore_openentry($store, null);
+			$rootFolderProps = mapi_getprops($rootFolder, array(PR_FREEBUSY_ENTRYIDS));
+			/**
+			 *	PR_FREEBUSY_ENTRYIDS contains 4 entryids
+			 *	PR_FREEBUSY_ENTRYIDS[0] gives associated freebusy folder in calendar
+			 *	PR_FREEBUSY_ENTRYIDS[1] Localfreebusy (used for delegate properties)
+			 *	PR_FREEBUSY_ENTRYIDS[2] global Freebusydata in public store
+			 *	PR_FREEBUSY_ENTRYIDS[3] Freebusydata in IPM_SUBTREE
+			 */
+			// get localfreebusy folder
+			$localFreeBusyFolder = mapi_msgstore_openentry($store, $rootFolderProps[PR_FREEBUSY_ENTRYIDS][1]);
+			if(mapi_last_hresult() !== NOERROR) {
+				$localFreeBusyFolder = false;
+			}
+
 			foreach($calendaritems as $calendaritem)
 			{
 				$item = null;
@@ -248,12 +200,12 @@
 							$item["basedate"]["attributes"]["unixtime"] = $recuritem["basedate"];
 							$item["basedate"]["_content"] = strftime("%a %d-%m-%Y %H:%M", $recuritem["basedate"]);
 						}
-						$item = $this->disablePrivateItem($storeProviderGuid[PR_MDB_PROVIDER], $item);
+						$item = $this->disablePrivateItem($localFreeBusyFolder, $storeProviderGuid[PR_MDB_PROVIDER], $item);
 						array_push($items, $item);
 					}
 				} else {
 					$item = Conversion::mapMAPI2XML($this->properties, $calendaritem);
-					$item = $this->disablePrivateItem($storeProviderGuid[PR_MDB_PROVIDER], $item);
+					$item = $this->disablePrivateItem($localFreeBusyFolder, $storeProviderGuid[PR_MDB_PROVIDER], $item);
 					array_push($items,$item);
 				}
 
@@ -264,23 +216,53 @@
 		}
 
 		/**
-		* Function to remove some properties when the item is private
-		* returns the item;
-		*/
-		function disablePrivateItem($storeProviderGuid, $item)
+		 * Function to remove some properties when the item is private
+		 * and it will also check for delegate permissions
+		 * @param object $localFreeBusyFolder localfreebusy folder
+		 * @param object $storeproviderguid type of store
+		 * @param object $item item properties
+		 * @return object $item item with modified properties
+		 */
+		function disablePrivateItem($localFreeBusyFolder, $storeProviderGuid, $item)
 		{
-			// if this is a private item and not in our own store we need to censor it ;)
-			if (isset($item["sensitivity"]) && $item["sensitivity"] != SENSITIVITY_NONE){
-				if ($storeProviderGuid==ZARAFA_STORE_DELEGATE_GUID){		
-					$item["subject"] = _("Private Appointment");
-					$item["location"] = "";
-					$item["reminder"] = 0;
-					$item["disabled_item"] = 1;
+			if(isset($item["private"]) && $item["private"] == true) {
+				// check for delegate permissions
+				if($storeProviderGuid == ZARAFA_STORE_DELEGATE_GUID) {
+					$hideItemData = false;
+
+					if($localFreeBusyFolder === false) {
+						$hideItemData = true;
+					}
+
+					// find delegate properties
+					if($localFreeBusyFolder !== false) {
+						$localFreeBusyFolderProps = mapi_getprops($localFreeBusyFolder, array(PR_SCHDINFO_DELEGATE_ENTRYIDS, PR_DELEGATES_SEE_PRIVATE));
+						if(mapi_last_hresult() !== NOERROR) {
+							// no delegate properties exists
+							$hideItemData = true;
+						} else {
+							// if more then one delegates info is stored then find index of 
+							// current user
+							$userEntryId = $GLOBALS["mapisession"]->getUserEntryID();
+							$userIndex = array_search($userEntryId, $localFreeBusyFolderProps[PR_SCHDINFO_DELEGATE_ENTRYIDS]);
+
+							if($userIndex === false || $localFreeBusyFolderProps[PR_DELEGATES_SEE_PRIVATE][$userIndex] === 0) {
+								$hideItemData = true;
+							}
+						}
+					}
+
+					if($hideItemData) {
+						$item["subject"] = _("Private Appointment");
+						$item["location"] = "";
+						$item["reminder"] = 0;
+						$item["disabled_item"] = 1;
+					}
 				}
 			}
 			return $item;
 		}
-		
+
 		/**
 		 * Function will sort items for the month view
 		 * small startdate->attributes->unixtime on top	 
