@@ -328,11 +328,12 @@
 				}
 			}
 
+			// $freebusy is only set when the calendar folder permissions is updated
 			if (isset($freebusy)){
 				// set permissions on free/busy message
-				foreach($acls as $acl) {
-					if( $acl["type"] == ACCESS_TYPE_GRANT && ($acl["rights"] & ecRightsEditOwned))
-						$acl["rights"] |= ecRightsEditAny;
+				foreach($acls as $key=>$value) {
+					if( $acls[$key]["type"] == ACCESS_TYPE_GRANT && ($acls[$key]["rights"] & ecRightsEditOwned))
+						$acls[$key]["rights"] |= ecRightsEditAny;
 				}
 				mapi_zarafa_setpermissionrules($freebusy, $acls);
 				if(mapi_last_hresult() != NOERROR) {
