@@ -309,9 +309,14 @@
 						
 					// Update the reminder time to show as the last occurrence since 'remindertime' until now
 					$lastocc = $occurrences[count($occurrences)-1];
-					$row[$this->properties["remindertime"]] = $lastocc[$this->properties["appointment_startdate"]];
-					$row[$this->properties["appointment_startdate"]] = $lastocc[$this->properties["appointment_startdate"]];
-					$row[$this->properties["appointment_enddate"]] = $lastocc[$this->properties["appointment_startdate"]];
+
+
+					// Bydefault, on occurrence reminder is true but if reminder value is set to false then we don't send popup reminder for this occurrence
+					if (!(isset($lastocc[$this->properties['reminder']]) && $lastocc[$this->properties['reminder']] == 0)) {
+						$row[$this->properties["remindertime"]] = $lastocc[$this->properties["appointment_startdate"]];
+						$row[$this->properties["appointment_startdate"]] = $lastocc[$this->properties["appointment_startdate"]];
+						$row[$this->properties["appointment_enddate"]] = $lastocc[$this->properties["appointment_startdate"]];
+					}
 				}
 
 				// Add the non-bogus rows
