@@ -100,40 +100,43 @@
 		function checkNames($store, $action)
 		{
 			$result = false;
-
+			
 			if(isset($action["name"])) {
 				$data = array();
 				$data["attributes"] = array("type" => "checknames");
 				$data["name"] = array();
+				$excludeusercontacts= $action["excludeusercontacts"];
 				
 				$names = $action["name"];
 				if(!is_array($names)) {
 					$names = array($names);
 				} 
-				
-				// get all contact folders from own store, exclude subfolders
-				$store = $GLOBALS["mapisession"]->getDefaultMessageStore();
-				$subtreeEntryid = mapi_getprops($store, array(PR_IPM_SUBTREE_ENTRYID));
-				$ipmSubtree = mapi_msgstore_openentry($store, $subtreeEntryid[PR_IPM_SUBTREE_ENTRYID]);
-				$hierarchyTable = mapi_folder_gethierarchytable($ipmSubtree, MAPI_DEFERRED_ERRORS);
+				// if excludeusercontacts is set to true, user Contact's folder will also be checked to resolve the given name
+				if(!$excludeusercontacts){
+					// get all contact folders from own store, exclude subfolders
+					$store = $GLOBALS["mapisession"]->getDefaultMessageStore();
+					$subtreeEntryid = mapi_getprops($store, array(PR_IPM_SUBTREE_ENTRYID));
+					$ipmSubtree = mapi_msgstore_openentry($store, $subtreeEntryid[PR_IPM_SUBTREE_ENTRYID]);
+					$hierarchyTable = mapi_folder_gethierarchytable($ipmSubtree, MAPI_DEFERRED_ERRORS);
 
-				$restriction = array(
-									RES_CONTENT,
-										array(
-											FUZZYLEVEL => FL_FULLSTRING,
-											ULPROPTAG => PR_CONTAINER_CLASS,
-											VALUE => array(
-														PR_CONTAINER_CLASS => "IPF.Contact"
-													)
-										)
-								);
+					$restriction = array(
+										RES_CONTENT,
+											array(
+												FUZZYLEVEL => FL_FULLSTRING,
+												ULPROPTAG => PR_CONTAINER_CLASS,
+												VALUE => array(
+															PR_CONTAINER_CLASS => "IPF.Contact"
+														)
+											)
+									);
 
-				mapi_table_restrict($hierarchyTable, $restriction, TBL_BATCH);
-				$contactFolderEntryIds = mapi_table_queryrows($hierarchyTable, array(PR_ENTRYID), 0, 0x7fffffff);
+					mapi_table_restrict($hierarchyTable, $restriction, TBL_BATCH);
+					$contactFolderEntryIds = mapi_table_queryrows($hierarchyTable, array(PR_ENTRYID), 0, 0x7fffffff);
 
-				$contactFolders = array();
-				for($index = 0; $index < count($contactFolderEntryIds); $index++) {
-					array_push($contactFolders, mapi_msgstore_openentry($store, $contactFolderEntryIds[$index][PR_ENTRYID]));
+					$contactFolders = array();
+					for($index = 0; $index < count($contactFolderEntryIds); $index++) {
+						array_push($contactFolders, mapi_msgstore_openentry($store, $contactFolderEntryIds[$index][PR_ENTRYID]));
+					}
 				}
 
 				// open addressbook
@@ -148,11 +151,20 @@
 						$type = $query["type"];
 
 						$result = $this->searchAddressBook($ab, $ab_dir, $id, $type);
-						$data["name"] = array_merge($data["name"], $result);
 
-						for($index = 0; $index < count($contactFolders); $index++) {
-							$result = $this->searchContactFolder($contactFolders[$index], $id, $type, $store);
+						if($excludeusercontacts){
+							foreach($result as $name){
+								// check only for users not for groups
+								if($name["objecttype"] == 6)
+									array_push($data["name"],$name);
+							}
+						}else{// will search user contact folder to resolve the give name
 							$data["name"] = array_merge($data["name"], $result);
+						
+							for($index = 0; $index < count($contactFolders); $index++) {
+								$result = $this->searchContactFolder($contactFolders[$index], $id, $type, $store);
+								$data["name"] = array_merge($data["name"], $result);
+							}
 						}
 					}
 				}
