@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -62,13 +64,8 @@
 		{
 			$this->properties = $GLOBALS["properties"]->getStickyNoteProperties();
 
-			$this->tablecolumns = array();
-			$this->addColumn($this->tablecolumns, "icon_index", true, 0, _("Icon"), _("Sort On Icon"));
-			$this->addColumn($this->tablecolumns, "subject", true, 2, _("Subject"), _("Sort On Subject"), PERCENTAGE);
-			$this->addColumn($this->tablecolumns, "body", false, 2, _("Body"), _("Sort On Body"));
-			$this->addColumn($this->tablecolumns, "creation_time", true, 3, _("Created"), _("Sort On Created"));
-			$this->addColumn($this->tablecolumns, "categories", false, 4, _("Categories"), _("Sort On Categories"));
-			
+			$this->tablecolumns = $GLOBALS["TableColumns"]->getStickyNoteListTableColumns();
+
 			parent::ListModule($id, $data, array(OBJECT_SAVE, TABLE_SAVE, TABLE_DELETE));
 
 			$this->sort = array();
