@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -161,10 +163,13 @@ class suggestEmailAddressModule extends Module
                                     // Check if the string is present in name or email fields
                                     if($l_ibPosName !== false || $l_ibPosEmail !== false){
                                         // Setup dispay name
-                                        $l_sDisplayName = $recipient_history['recipients']['recipient'][$i]['name'];
-                                        $l_sDisplayName .= ' <'.$recipient_history['recipients']['recipient'][$i]['email'].'>';
-                                        //$l_sDisplayName .= ' ['.$recipient_history['recipients']['recipient'][$i]['count'].']';
-
+                                        if(!isset($recipient_history['recipients']['recipient'][$i]['objecttype']) || $recipient_history['recipients']['recipient'][$i]['objecttype'] == MAPI_MAILUSER) {
+	                                        $l_sDisplayName = $recipient_history['recipients']['recipient'][$i]['name'];
+    	                                    $l_sDisplayName .= ' <'.$recipient_history['recipients']['recipient'][$i]['email'].'>';
+	                                        //$l_sDisplayName .= ' ['.$recipient_history['recipients']['recipient'][$i]['count'].']';
+										} else {
+	                                        $l_sDisplayName = '['.$recipient_history['recipients']['recipient'][$i]['name'].']';
+										}
                                         // Check if the found string matches from the start of the word
                                         if($l_ibPosName === 0 || substr($l_sName, ($l_ibPosName-1), 1) == ' ' || $l_ibPosEmail === 0 || substr($l_sEmail, ($l_ibPosEmail-1), 1) == ' '){
                                             array_push($l_aResult[0], Array(
