@@ -81,9 +81,9 @@
 			 * 			0 = array(
 			 * 				"entryid" = array()
 			 */
-			foreach ($data as &$action){
+			foreach ($data as $key => $action){
 				if (isset($action["selectedfolders"]) && isset($action["selectedfolders"]["entryids"])){
-					if (is_array($action["selectedfolders"]["entryids"])) $action["entryid"] = $action["selectedfolders"]["entryids"];
+					if (is_array($action["selectedfolders"]["entryids"])) $data[$key]["entryid"] = $action["selectedfolders"]["entryids"];
 				}
 			}
 
