@@ -61,7 +61,10 @@
 	// Check if dialog_attachments is set
 	if(isset($_POST["dialog_attachments"])) {
 		// Check if the file is uploaded correctly and is not above the MAX_FILE_SIZE
+		dump($_FILES["attachments"]);
 		if(isset($_FILES["attachments"]) && is_array($_FILES["attachments"])) {
+			$FILES = Array();
+			
 			if(isset($_FILES['attachments']['name']) && is_array($_FILES['attachments']['name'])){
 				foreach($_FILES['attachments']['name'] as $key => $name){
 					$FILE = Array(
@@ -71,7 +74,8 @@
 						'error'    => $_FILES['attachments']['error'][$key],
 						'size'     => $_FILES['attachments']['size'][$key]
 					);
-
+					
+					$FILES[] = $FILE;
 				}
 			} else if(isset($_FILES['attachments']['name'])){
 				// SWFUpload sends attachments array already in required format.
@@ -82,46 +86,49 @@
 				 * for more information -> http://swfupload.org/forum/generaldiscussion/166
 				 */
 				$FILE["type"] = getMIMEType($FILE["name"]);
+				$FILES[] = $FILE;
 			}
 
-			if (!empty($FILE["size"]) && !(isset($_POST["MAX_FILE_SIZE"]) && $FILE["size"] > $_POST["MAX_FILE_SIZE"])) {
-				// Create unique tmpname
-				$tmpname = tempnam(TMP_PATH, stripslashes($FILE["name"]));
+			foreach($FILES as $FILE) {
+				if (!empty($FILE["size"]) && !(isset($_POST["MAX_FILE_SIZE"]) && $FILE["size"] > $_POST["MAX_FILE_SIZE"])) {
+					// Create unique tmpname
+					$tmpname = tempnam(TMP_PATH, stripslashes($FILE["name"]));
 
-				// Move the uploaded file the the tmpname
-				$result = move_uploaded_file($FILE["tmp_name"], $tmpname);
+					// Move the uploaded file the the tmpname
+					$result = move_uploaded_file($FILE["tmp_name"], $tmpname);
 
-				if($FILE["type"] == "message/rfc822") {
-					/**
-					 * check content type that is send by browser because content type for
-					 * eml attachments will be message/rfc822, but this content type is used 
-					 * for message-in-message embedded objects, so we have to send it as 
-					 * application/octet-stream.
-					 */
-					$FILE["type"] = "application/octet-stream";
+					if($FILE["type"] == "message/rfc822") {
+						/**
+						 * check content type that is send by browser because content type for
+						 * eml attachments will be message/rfc822, but this content type is used 
+						 * for message-in-message embedded objects, so we have to send it as 
+						 * application/octet-stream.
+						 */
+						$FILE["type"] = "application/octet-stream";
+					}
+
+					// Check if there are no files uploaded
+					if(!isset($_SESSION["files"])) {
+						$_SESSION["files"] = array();
+					}
+					
+					// Check if no files are uploaded with this dialog_attachments
+					if(!isset($_SESSION["files"][$_POST["dialog_attachments"]])) {
+						$_SESSION["files"][$_POST["dialog_attachments"]] = array();
+					}
+
+					// stripping path details
+					$tmpname = basename($tmpname);
+
+					// Add file information to the session
+					$_SESSION["files"][$_POST["dialog_attachments"]][$tmpname] = Array(
+						"name"       => utf8_to_windows1252(stripslashes($FILE["name"])),
+						"size"       => $FILE["size"],
+						"type"       => $FILE["type"],
+						"sourcetype" => 'default'
+					);
 				}
 
-				// Check if there are no files uploaded
-				if(!isset($_SESSION["files"])) {
-					$_SESSION["files"] = array();
-				}
-				
-				// Check if no files are uploaded with this dialog_attachments
-				if(!isset($_SESSION["files"][$_POST["dialog_attachments"]])) {
-					$_SESSION["files"][$_POST["dialog_attachments"]] = array();
-				}
-
-				// stripping path details
-				$tmpname = basename($tmpname);
-
-				// Add file information to the session
-				$_SESSION["files"][$_POST["dialog_attachments"]][$tmpname] = Array(
-					"name"       => utf8_to_windows1252(stripslashes($FILE["name"])),
-					"size"       => $FILE["size"],
-					"type"       => $FILE["type"],
-					"sourcetype" => 'default'
-				);
-
 			}
 		} else if(isset($_POST["deleteattachment"]) && isset($_POST["type"])) { // Delete uploaded file
 			// Check if the delete file is an uploaded or an attachment of a MAPI iMessage
@@ -150,7 +157,39 @@
 				array_push($_SESSION["deleteattachment"][$_POST["dialog_attachments"]], $_POST["deleteattachment"]);
 			}
 		}
+} else if($_GET && isset($_GET["attachment_id"])) { // this is to upload the file to server when the doc is send via OOo
+	// check wheather the doc is already moved
+	if(file_exists("/tmp/".$_GET["attachment_id"])){
+		// Create unique tmpname	
+		$tmpname = tempnam(TMP_PATH, stripslashes($_GET["name"]));
+		// Move the uploaded file to tmpname loaction
+		rename("/tmp/".$_GET["attachment_id"], $tmpname);
+				
+		// Check if there are no files uploaded
+		if(!isset($_SESSION["files"])) {
+			$_SESSION["files"] = array();
+		}
+		
+		// Check if no files are uploaded with this attachmentid
+		if(!isset($_SESSION["files"][$_GET["attachment_id"]])) {
+			$_SESSION["files"][$_GET["attachment_id"]] = array();
+		}
+
+		// Add file information to the session
+		$_SESSION["files"][$_GET["attachment_id"]][basename($tmpname)] = Array(
+			"name"       => utf8_to_windows1252(stripslashes($_GET["name"])),
+			"size"       => filesize($tmpname),
+			"type"       => mime_content_type($tmpname),
+			"sourcetype" => 'default'
+		);
+	}else{
+		// Check if no files are uploaded with this attachmentid
+		if(isset($_SESSION["files"][$_GET["attachment_id"]])) {
+			$_SESSION["files"][$_GET["attachment_id"]] = array();
+		}
 	}
+}
+
 
 // Return the file data output when client has request this page through the load==upload_attachment
 if(get('load', false, false, STRING_REGEX) == 'upload_attachment'){
