@@ -219,15 +219,16 @@
 		// groups 1 contains value of src attribute
 		if (array_key_exists("1", $match)) {
 			// exclude external links to images
-			if(preg_match("/https{0,1}:\/\//msi", $match[1]) === 1) {
+			if(preg_match("/https{0,1}:\/\//msi", $match[1]) === 1 || strpos($match[1], "data:image") === 0) {
 				// return links as it is without changing anything
-				return "<img src=\"" . $match[1] . "\"";
+				return $match[0];
 			}
 
-			$match[1] = str_replace("cid:", "", $match[1]);
-			return "<img src=\"" . BASE_URL . "index.php?load=download_attachment&store=" . $GLOBALS["preg_replace"]["storeid"] . "&amp;entryid=" . $GLOBALS["preg_replace"]["entryid"] . "&amp;attachCid=" . $match[1] . "&amp;openType=inline\"";
+			$cid = str_replace("cid:", "", $match[1]);
+
+			return str_replace($match[1], BASE_URL . "index.php?load=download_attachment&store=" . $GLOBALS["preg_replace"]["storeid"] . "&amp;entryid=" . $GLOBALS["preg_replace"]["entryid"] . "&amp;attachCid=" . $cid . "&amp;openType=inline\"", $match[0]);
 		} else {
-			return "<img src=\"\"";
+			return $match[0];
 		}
 	}
 	
@@ -332,6 +333,21 @@
 		return $value;
 	}
 
+	/**
+	 * Get the maximum number of files allowed to be uploaded simultaneously.
+	 *
+	 * zero means unlimited
+	 */
+	function GetMaxFileUploads()
+	{
+		$maxfileuploads = intval(ini_get('max_file_uploads'));
+	
+		if ($maxfileuploads == 0 || $maxfileuploads > FILE_QUEUE_LIMIT)
+			$maxfileuploads = FILE_QUEUE_LIMIT;
+
+		return $maxfileuploads;
+	}
+
 	/**
 	 * cleanTemp
 	 * 
@@ -501,4 +517,20 @@
 		return $contentType;
 	}
 
+	/**
+	 * This function will encode the input string for the header based on the browser that makes the
+	 * HTTP request. MSIE has an issue with unicode filenames. All browsers do not seem to follow 
+	 * the RFC specification. Firefox requires an unencoded string in the HTTP header. MSIE will 
+	 * break on this and requires encoding. 
+	 * @param String $input Unencoded string
+	 * @return String Encoded string
+	 */
+	function browserDependingHTTPHeaderEncode($input){
+		if(strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') === false){
+			return $input;
+		}else{
+			return urlencode($input);
+		}
+	}
+
 ?>
