@@ -78,7 +78,6 @@
 	include("server/modules/class.listmodule.php");
 	include("server/modules/class.itemmodule.php");
 	include("server/core/class.operations.php");
-	include("server/core/class.zarchiver.php");
 	include("server/core/class.properties.php");
 	include("server/core/class.tablecolumns.php");
 	include("server/core/class.bus.php");
@@ -88,6 +87,7 @@
 	include("server/core/class.plugin.php");
 
 	ob_start();
+	setlocale(LC_CTYPE, "en_US.UTF-8");
 
 	// Get the available modules
 	$GLOBALS["availableModules"] = getAvailableModules();
@@ -145,8 +145,6 @@
 
 		// Create global operations object
 		$GLOBALS["operations"] = new Operations();
-		// Create global operations object
-		$GLOBALS["zArchiverOperations"] = new ZArchiverOperations();
 		// Create global properties object
 		$GLOBALS["properties"] = new Properties();
 		// Create global tablecolumns object
@@ -195,17 +193,20 @@
 		$attachment_state->open();
 		$_SESSION['files'] = $attachment_state->read("files");
 		$_SESSION['deleteattachment'] = $attachment_state->read("deleteattachment");
+		$checksum = md5(serialize($_SESSION['files']) . serialize($_SESSION['deleteattachment']));
 		$attachment_state->close();
 
 		// Execute the request
 		$xml = $request->execute($xml);
 
-		// Get Attachment data from $_SESSION and put it into the state
-		$attachment_state = new State('attachments');
-		$attachment_state->open();
-		$attachment_state->write("files", $_SESSION['files']);
-		$attachment_state->write("deleteattachment", $_SESSION['deleteattachment']);
-		$attachment_state->close();
+		// Get Attachment data from $_SESSION and put it into the state, but only if something has changed
+		if(md5(serialize($_SESSION['files']) . serialize($_SESSION['deleteattachment'])) != $checksum) {
+			$attachment_state = new State('attachments');
+			$attachment_state->open();
+			$attachment_state->write("files", $_SESSION['files']);
+			$attachment_state->write("deleteattachment", $_SESSION['deleteattachment']);
+			$attachment_state->close();
+		}
 		// Prevent the SESSION data to be stored elsewhere
 		unset($_SESSION['files'], $_SESSION['deleteattachment']);
 
